<?php

/**
 * New/Edit Topic
 *
 * @package bbPress
 * @subpackage Theme
 */

?>

<?php if ( bbp_is_topic_edit() ) : ?>

	<?php bbp_topic_tag_list( bbp_get_topic_id() ); ?>

	<?php bbp_single_topic_description( array( 'topic_id' => bbp_get_topic_id() ) ); ?>

<?php endif; ?>

<?php if ( bbp_current_user_can_publish_topics() ) : ?>

	<div id="new-topic-<?php bbp_topic_id(); ?>" class="bbp-topic-form">

		<form name="new-post" method="post" action="<?php echo esc_url( add_query_arg( array('new-topic' => 'true'), get_post_type_archive_link( 'forum' ) )); ?>">

				<?php 
					do_action( 'bbp_theme_before_topic_form' );
					echo '<h5>';
						if ( bbp_is_topic_edit() )
							printf( __( 'Now Editing &ldquo;%s&rdquo;', 'smk_theme' ), bbp_get_topic_title() );
						else
							bbp_is_single_forum() ? printf( __( 'Create New Topic in &ldquo;%s&rdquo;', 'smk_theme' ), bbp_get_forum_title() ) : _e( 'Create New Topic', 'smk_theme' );
					echo '</h5>';
					do_action( 'bbp_theme_before_topic_form_notices' );


					$top_notifications = array();

					if ( !bbp_is_topic_edit() && bbp_is_forum_closed() ){
						$top_notifications[] = __( 'This forum is marked as closed to new topics, however your posting capabilities still allow you to do so.', 'smk_theme' );
					}

					if ( current_user_can( 'unfiltered_html' ) ){
						$top_notifications[] = __( 'Your account has the ability to post unrestricted HTML content.', 'smk_theme' );
					}

					if( !empty($top_notifications) ){
						$total = count( $top_notifications );
						if( $total >= 1 ){
							echo '<div class="notification super-light blue">';
								if ( 1 < $total){
									foreach ($top_notifications as $note) {
										echo ' - '. $note . '<br />';
									}
								}
								else{
									echo $top_notifications[0];
								}
							echo '</div>';
						}
					}

					do_action( 'bbp_template_notices' ); 
				?>

				<div class="grid-container">

					<?php
						bbp_get_template_part( 'form', 'anonymous' );
						do_action( 'bbp_theme_before_topic_form_title' ); 
					?>

					<div>
						<div class="form-label"><?php printf( __( 'Topic Title (Maximum Length: %d):', 'smk_theme' ), bbp_get_title_max_length() ); ?></div>
						<input type="text" class="fullwidth" value="<?php bbp_form_topic_title(); ?>" name="bbp_topic_title" maxlength="<?php bbp_title_max_length(); ?>" />
					</div>

					<?php 
						do_action( 'bbp_theme_after_topic_form_title' );
						do_action( 'bbp_theme_before_topic_form_content' ); 

						echo '<div class="form-label">'. __( 'Content:', 'smk_theme' ) .'</div>';
						echo '<div class="recipe-editor-mce">';
							bbp_the_content( array( 'context' => 'topic' ) ); 
						echo '</div>';

						do_action( 'bbp_theme_after_topic_form_content' ); 
					?>

					<?php if ( ! ( bbp_use_wp_editor() || current_user_can( 'unfiltered_html' ) ) ) : ?>

						<p class="form-allowed-tags">
							<label><?php _e( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes:','smk_theme' ); ?></label><br />
							<code><?php bbp_allowed_tags(); ?></code>
						</p>

					<?php endif; ?>

					<?php if ( bbp_allow_topic_tags() && current_user_can( 'assign_topic_tags' ) ) : ?>

						<?php do_action( 'bbp_theme_before_topic_form_tags' ); ?>

						<div class="grid desk-5 alpha">
							<div class="form-label"><?php _e( 'Topic Tags:', 'smk_theme' ); ?></div>
							<input type="text" value="<?php bbp_form_topic_tags(); ?>" tabindex="<?php bbp_tab_index(); ?>" name="bbp_topic_tags" class="fullwidth" <?php disabled( bbp_is_topic_spam() ); ?> />
						</div>

						<?php do_action( 'bbp_theme_after_topic_form_tags' ); ?>

					<?php endif; ?>

					<?php if ( !bbp_is_single_forum() ) : ?>

						<?php do_action( 'bbp_theme_before_topic_form_forum' ); ?>

						<div class="grid desk-3">
							<div class="form-label"><?php _e( 'Forum:', 'smk_theme' ); ?></div>
							<?php
								bbp_dropdown( array(
									'selected'  => bbp_get_form_topic_forum()
								) );
							?>
						</div>

						<?php do_action( 'bbp_theme_after_topic_form_forum' ); ?>

					<?php endif; ?>

					<?php if ( current_user_can( 'moderate' ) ) : ?>

						<?php do_action( 'bbp_theme_before_topic_form_type' ); ?>

						<div class="grid desk-2">

							<div class="form-label"><?php _e( 'Topic Type:', 'smk_theme' ); ?></div>

							<?php bbp_form_topic_type_dropdown(); ?>

						</div>

						<?php do_action( 'bbp_theme_after_topic_form_type' ); ?>

						<?php do_action( 'bbp_theme_before_topic_form_status' ); ?>

						<div class="grid desk-2 omega">

							<div class="form-label"><?php _e( 'Topic Status:', 'smk_theme' ); ?></div>

							<?php bbp_form_topic_status_dropdown(); ?>

						</div>

						<?php do_action( 'bbp_theme_after_topic_form_status' ); ?>

					<?php endif; ?>

					<div class="clear"></div>

					<?php if ( bbp_is_subscriptions_active() && !bbp_is_anonymous() && ( !bbp_is_topic_edit() || ( bbp_is_topic_edit() && !bbp_is_topic_anonymous() ) ) ) : ?>

						<?php do_action( 'bbp_theme_before_topic_form_subscriptions' ); ?>

						<p>
							<input name="bbp_topic_subscription" id="bbp_topic_subscription" type="checkbox" value="bbp_subscribe" <?php bbp_form_topic_subscribed(); ?> tabindex="<?php bbp_tab_index(); ?>" />

							<?php if ( bbp_is_topic_edit() && ( bbp_get_topic_author_id() !== bbp_get_current_user_id() ) ) : ?>

								<label for="bbp_topic_subscription"><?php _e( 'Notify the author of follow-up replies via email', 'smk_theme' ); ?></label>

							<?php else : ?>

								<label for="bbp_topic_subscription"><?php _e( 'Notify me of follow-up replies via email', 'smk_theme' ); ?></label>

							<?php endif; ?>
						</p>

						<?php do_action( 'bbp_theme_after_topic_form_subscriptions' ); ?>

					<?php endif; ?>

					<?php if ( bbp_allow_revisions() && bbp_is_topic_edit() ) : ?>

						<?php do_action( 'bbp_theme_before_topic_form_revisions' ); ?>

						<fieldset class="bbp-form">
							<legend>
								<input name="bbp_log_topic_edit" id="bbp_log_topic_edit" type="checkbox" value="1" <?php bbp_form_topic_log_edit(); ?> tabindex="<?php bbp_tab_index(); ?>" />
								<label for="bbp_log_topic_edit"><?php _e( 'Keep a log of this edit:', 'smk_theme' ); ?></label><br />
							</legend>

							<div>
								<label for="bbp_topic_edit_reason"><?php printf( __( 'Optional reason for editing:', 'smk_theme' ), bbp_get_current_user_name() ); ?></label><br />
								<input type="text" value="<?php bbp_form_topic_edit_reason(); ?>" tabindex="<?php bbp_tab_index(); ?>" size="40" name="bbp_topic_edit_reason" id="bbp_topic_edit_reason" />
							</div>
						</fieldset>

						<?php do_action( 'bbp_theme_after_topic_form_revisions' ); ?>

					<?php endif; ?>

					<?php do_action( 'bbp_theme_before_topic_form_submit_wrapper' ); ?>

					<div>

						<?php do_action( 'bbp_theme_before_topic_form_submit_button' ); ?>

						<button type="submit" tabindex="<?php bbp_tab_index(); ?>"  name="bbp_topic_submit" class="button primary"><?php _e( 'Submit', 'smk_theme' ); ?></button>

						<?php do_action( 'bbp_theme_after_topic_form_submit_button' ); ?>

					</div>

					<?php do_action( 'bbp_theme_after_topic_form_submit_wrapper' ); ?>

				</div>

				<?php bbp_topic_form_fields(); ?>

			<?php do_action( 'bbp_theme_after_topic_form' ); ?>

		</form>
	</div>

<?php elseif ( bbp_is_forum_closed() ) : ?>

	<div class="notification light orange">
		<?php printf( __( 'The forum &#8216;%s&#8217; is closed to new topics and replies.', 'smk_theme' ), bbp_get_forum_title() ); ?>
	</div>

<?php else : ?>

	<div class="notification light red">
		<?php is_user_logged_in() ? _e( 'You cannot create new topics.', 'smk_theme' ) : _e( 'You must be logged in to create new topics.', 'smk_theme' ); ?>
	</div>

<?php endif; ?>
