<?php
/*
-------------------------------------------------------------------------------
User summary tabs
-------------------------------------------------------------------------------
*/
class Smk_User_Summary_Tab_User_Following_Feed extends Smk_User_Summary_Tab{
	public function content( $user ){
		Smk_Theme_User::currentProfileId();
		$users = get_user_meta($user->ID, 'st_following', true);
		smk_get_activity( $users );
	}

	public function returnTab(){
		$curauth = Smk_Theme_User::currentProfileId();
		$curuser = Smk_Theme_User::currentUser();

		if( $curauth == $curuser->ID ){
			return true;
		}
		else{
			return false;
		}
	}

}
new Smk_User_Summary_Tab_User_Following_Feed('feed', __('Feed', 'smk_theme'));

class Smk_User_Summary_Tab_Activity extends Smk_User_Summary_Tab{
	public function content( $user ){
		smk_get_activity( $user->ID );
	}
}
new Smk_User_Summary_Tab_Activity('activity', __('Activity', 'smk_theme'));


/* Recipes Tab
------------------------------------------------*/
class Smk_User_Summary_Tab_Recipes extends Smk_User_Summary_Tab{
	public function noResults( $user ){
		return sprintf( __('%1$s has not submitted any recipes.', 'smk_theme'), $user->display_name);
	}

	public function addToQuery( $user ){
		return array(
			'author' => $user->ID,
		);
	}

	public function querySettings( $user ){
		$def = array (
			'post_type'      => 'smk_recipes',
			'posts_per_page' => 20,
			'paged'          => smk_theme_current_pag(),
		);
		$new = $this->addToQuery( $user );
		return wp_parse_args( $new, $def );
	}

	public function count( $user ){		
		$query = $this->querySettings( $user );
		if( isset($query['paged']) ){
			unset($query['paged']);
		}
		$recipes_query = new WP_Query($query);
		return ($recipes_query->have_posts() && $this->addToQuery( $user )) ? $recipes_query->found_posts : 0;
	}
	public function content( $user ){
		$query = $this->querySettings( $user );
		$recipes_query = new WP_Query($query);
		echo '<div class="recipes-list clearfix">';
		if ($recipes_query->have_posts() && $this->addToQuery( $user )) {
			while ($recipes_query->have_posts()) : 
				$recipes_query->the_post();

				get_template_part("tpl/recipes", "view-list");
			endwhile; 
			smk_theme_pagination($recipes_query);
		}
		else{
			echo '<div class="notification red super-light center">' . $this->noResults( $user ) . '</div>';
		}
		echo '</div>';
	}
}
new Smk_User_Summary_Tab_Recipes('recipes', __('Recipes', 'smk_theme'));


/* Favorites Tab
------------------------------------------------*/
class Smk_User_Summary_Tab_Favorites extends Smk_User_Summary_Tab_Recipes{
	public function noResults( $user ){
		return sprintf( __('%1$s doesn\'t have any favorite recipes.', 'smk_theme'), $user->display_name);
	}

	public function addToQuery( $user ){
		$fav_list = smk_get_user_favorites($user->ID);
		if( !empty($fav_list) ){
			return array(
				'post__in' => $fav_list,
			);
		}
		else{
			return false;
		}
	}
}
if( smk_favorites_enabled() ){
	new Smk_User_Summary_Tab_Favorites('favorites', __('Favorites', 'smk_theme'));
}


/* Likes Tab
------------------------------------------------*/
class Smk_User_Summary_Tab_Likes extends Smk_User_Summary_Tab_Recipes{
	public function noResults( $user ){
		return sprintf( __('%1$s has not liked any recipes.', 'smk_theme'), $user->display_name);
	}

	public function addToQuery( $user ){
		$likes_list = smk_get_user_likes($user->ID);
		if( !empty($likes_list) ){
			return array(
				'post__in' => $likes_list,
			);
		}
		else{
			return false;
		}
	}
}
if( smk_likes_enabled() ){
	new Smk_User_Summary_Tab_Likes('likes', __('Likes', 'smk_theme'));
}


/* Collections Tab
------------------------------------------------*/
// class Smk_User_Summary_Tab_Collections extends Smk_User_Summary_Tab{
// 	public function count( $user ){
// 		return 0;
// 	}
// 	public function content( $user ){
// 		echo '<div class="notification red super-light center">'. __('No Collections.', 'smk_theme') .'</div>';
// 	}
// }
// new Smk_User_Summary_Tab_Collections('collections', __('Collections', 'smk_theme'));


/* Forums Tab Replies
------------------------------------------------*/
class Smk_User_Summary_Tab_Forums extends Smk_User_Summary_Tab{
	public function count( $user ){
		$r = bbp_get_user_reply_count_raw( $user->ID );
		$t = bbp_get_user_topic_count_raw( $user->ID );
		return absint( $r ) + absint( $t );
	}
	public function content( $user ){
		?>
		<div class="forums-module bbp-search-results clearfix">
			<?php 
				$replies = bbp_has_replies( array('author' => $user->ID, 'order' => 'DESC' ) );
				if ( $replies ) {
					
					while ( bbp_replies() ) : bbp_the_reply();
						bbp_get_template_part( 'loop', 'search-reply' );
					endwhile;

					bbp_get_template_part( 'pagination', 'replies'    );
				}
				else{
					echo '<div class="notification red super-light center">'. __('No activity on the forums.', 'smk_theme') .'</div>';
				}

			?>
		</div>

		<?php
	}
}
if( function_exists('bbpress') ){
	new Smk_User_Summary_Tab_Forums('forums', __('Forums', 'smk_theme'));
}


/* Comments Tab
------------------------------------------------*/
class Smk_User_Summary_Tab_Comments extends Smk_User_Summary_Tab{
	public function count( $user ){
		$args = array(
			'status' => 'approve',
			'user_id' => $user->ID,
			'count' => true,
		);
		$all_comments = get_comments( $args );
		return $all_comments;
	}
	public function content( $user ){
		$current_page      = ( !empty($_GET['comment-page']) && ( absint($_GET['comment-page']) > 0 ) ) ? absint($_GET['comment-page']) : 1;
		$total_comments    = $this->count( $user );
		$comments_per_page = 20;
		$offset            = $comments_per_page * ($current_page - 1);
		$total_pages       = round( $total_comments / $comments_per_page );

		$args = array(
			'status'  => 'approve',
			'user_id' => $user->ID,
			'number'  => $comments_per_page,
			'offset'  => $offset,
		);
		$all_comments = get_comments( $args );
		if( !empty($all_comments) ){
			echo '<div class="profile-comments-list">';
				foreach ($all_comments as $comment) {
					$date = date_create_from_format('Y-m-d H:i:s', $comment->comment_date);
					$comment_date = date_format($date, 'd F Y, H:i');
					?>
							
						<div class="comment clearfix">
							<div class="comment-photo">
								<a href="#"><?php echo get_avatar( $comment, 50 ); ?></a>
							</div>
							<div class="comment-text">
								<div class="comment-head clearfix">
									<span class="comment-title">
										<strong><?php echo $comment->comment_author; ?></strong> 
										<?php echo _x('commented on', 'A user "commented on" a post', 'smk_theme'); ?> 
										<a href="<?php echo get_permalink($comment->comment_post_ID); ?>"><?php echo get_the_title( $comment->comment_post_ID ); ?></a>
									</span>
									<span class="comment-date"><?php echo $comment_date; ?></span>
								</div>
								<div class="text"><?php echo $comment->comment_content; ?></div>
							</div>
						</div>
						<div class="clear"></div>

					<?php
				}
			echo '</div>
			<div class="clear"></div>';

			smk_theme_pagination($total_pages, array(
				'query_arg' => 'comment-page',
			));
		}
		else{
			echo '<div class="notification red super-light center">'. __('No comments.', 'smk_theme') .'</div>';
		}
	}
}
new Smk_User_Summary_Tab_Comments('comments', __('Comments', 'smk_theme'));