<?php
if( class_exists('Smk_PageBuilder_Module') && !class_exists( 'Smk_Theme_PBM_Featured_Recipe' ) ) {
	class Smk_Theme_PBM_Featured_Recipe extends Smk_PageBuilder_Module {

		function settings(){
			return array(
				'title' => __('Featured recipe', 'smk_theme'),
				'desc' =>  __('Show a recipe as to be featured on homepage.', 'smk_theme'),
				'category' => 'content theme_defined',
			);
		}

		function form(){
			return array(

				array(
					'id' 	=> 'title',
					'type' 	=> 'input',
					'label' => __('Title:', 'smk_theme'),
					'std' 	=> __('Featured', 'smk_theme'),
				),

				array(
					'id' 	=> 'post_id',
					'type' 	=> 'posts',
					'label' => __('Select a single recipe:', 'smk_theme'),
					'mode'	=> 'select',
					//'std' 	=> array('2'),
					//'desc' 	=> 'Input description.',
					'args'	=> array('post_type' => 'smk_recipes'), //get_posts() - http://codex.wordpress.org/Function_Reference/get_posts
				),

				array(
					'id' 	=> 'show_slider',
					'type' 	=> 'switch',
					'label' => __('Show slider', 'smk_theme'),
					'desc' 	=> __('If this option is enabled the previous selection will be ignored and the next options will be used instead.', 'smk_theme'),
					'std' 	=> 0,
					// 'labels' => array(
					// 	'on' => 'Enable',
					// 	'off' => 'Disable',
					// 	'text' => 'Right side description',
					// )
				),

				array(
					'id' 	=> 'sort_by',
					'type' 	=> 'select',
					'label' => __('Select what to display:', 'smk_theme'),
					'std' 	=> 'date',
					'options' => array(
						'date'              => __('Recent', 'smk_theme'),
						'favorites_count'   => __('Favorites', 'smk_theme'), 
						'likes_count'       => __('Likes', 'smk_theme'),
						'modified'          => __('Last modified', 'smk_theme'),
						'rand'              => __('Random', 'smk_theme'),
						'comment_count'     => __('Most commented', 'smk_theme'),
						'is_featured'       => __('Only featured recipes', 'smk_theme'),
						'is_featured_first' => __('Featured recipes first', 'smk_theme'),
					),
					'fold' => 'show_slider',
				),

				array(
					'id' 	=> 'per_page',
					'type' 	=> 'sliderui',
					'label' => __('If the previous option is selected select the max number of recipes to display:', 'smk_theme'),
					'min' 	=> '1',
					'max' 	=> '15',
					'std' 	=> '3',
					'fold' => 'show_slider',
				),

				array(
					'id' 	=> 'autoplay',
					'type' 	=> 'sliderui',
					'label' => __('Autoplay time in seconds', 'smk_theme'),
					'desc' 	=> __('Select 0(zerro) to disable autplay.', 'smk_theme'),
					'min' 	=> '0',
					'max' 	=> '15',
					'std' 	=> '5',
					'fold' => 'show_slider',
				),

			);
		}

		public function getSliderAtts($data){
			$atts = array();
			$atts['autoplay'] = ( !empty($data['autoplay']) && absint($data['autoplay']) > 0 ) ? absint($data['autoplay']) * 1000 : 'false';

			$output = '';
			foreach ($atts as $key => $value) {
				$output .= ' data-'. $key .'="'. $value .'"';
			}

			return $output;
		}

		function render($data){

			$title = ( !empty($data['title']) ) ? '<div class="badge">'. esc_html($data['title']) .'</div>' : '';
			$sort_by = ( !empty($data['sort_by']) ) ? $data['sort_by'] : 'date';
			$post_id = ( !empty($data['post_id']) && absint($data['post_id']) > 0 ) ? absint($data['post_id']) : '';
			$per_page = ( !empty($data['per_page']) && absint($data['per_page']) > 0 ) ? absint($data['per_page']) : 1;
			$show_slider = ( !empty($data['show_slider']) && absint($data['show_slider']) > 0 ) ? absint($data['show_slider']) : 0;

			$recipe_label = '';
			
			$the_query = array (
				'post_type'      => 'smk_recipes',
			);

			if( $show_slider ){
				$new_args = $this->sortRecipesQuery( $sort_by );
				$the_query = wp_parse_args( $new_args, $the_query );
				$the_query['posts_per_page'] = $per_page;
			}
			else{
				$the_query['posts_per_page'] = 1;
				if( $post_id ){
					$the_query['post__in'] =  (array) $post_id;
				}
				$recipe_label = $title;
			}

			$recipes_query = new WP_Query($the_query);

			$slider_atts = $this->getSliderAtts($data);
			echo ( $show_slider ) ? '<div class="big-featured-recipes-slider"'. $slider_atts .'>' : '';

			if ($recipes_query->have_posts()) {
				while ($recipes_query->have_posts()) : $recipes_query->the_post();

				$this_id = get_the_ID();
				$post_author_id = get_post_field( 'post_author', $this_id );

				$is_featured    = get_post_meta( get_the_ID(), 'smk_recipe_is_featured', true );
				if( $show_slider && !empty($is_featured) && 'yes' == $is_featured ){
					$recipe_label = '<div class="badge">'. __('Featured', 'smk_theme') .'</div>';
				}
				?>
				<div class="home-recipe-of-the-day clearfix">
					<div class="smk_tk_grid desk_6">
						<div class="entry-photo">
							<?php 
								echo $recipe_label;

								$img_id = get_post_thumbnail_id( $this_id );
								if ( !empty($img_id) ) {
									echo '<a href="'. get_the_permalink( $this_id ) .'">
									<img src="'. smk_theme_resize( wp_get_attachment_url( $img_id ), 780, 490, true, true, true) .'" alt="" />
									</a>';
								} 
							
							?>
						</div>
					</div>
					<div class="smk_tk_grid desk_6">
						<h3><a href="<?php echo get_the_permalink( $this_id ); ?>"><?php echo esc_html( get_the_title() ); ?></a></h3>
						<?php smk_theme_excerpt(35, '...', true); ?>
						
						<div class="entry-meta clearfix">
							<?php if( 'on' == smk_recipe_setting( 'ui_enable_favorites', 'on' ) ) : ?>
							<div class="meta favorites"> 
								<span class="icon"><i class="the-icon fa fa-heart-o"></i></span>
								<span class="number"><?php printf( __('%d favorites', 'smk_theme'), smk_get_favorites_count( $this_id) ) ?></span>
							</div>
							<?php endif; ?>
							
							<?php if( 'on' == smk_recipe_setting( 'ui_enable_likes', 'on' ) ) : ?>
							<div class="meta likes"> 
								<span class="icon"><i class="the-icon fa fa-thumbs-o-up"></i></span>
								<span class="number"><?php printf( __('%d likes', 'smk_theme'), smk_get_likes_count( $this_id) ) ?></span>
							</div>
							<?php endif; ?>
							
							<div class="meta comments"> 
								<span class="icon"><i class="the-icon fa fa-comments"></i></span>
								<span class="number"><?php smk_comments_number_link(false); ?></span>
							</div>
						</div>
						<div class="clear"></div>

						<div class="entry-info-author">
							<a href="<?php echo get_author_posts_url( $post_author_id ); ?>">
								<?php echo get_avatar( $post_author_id, 80 ); ?>
							</a>
							<div class="submited-by"><?php _e('Author:', 'smk_theme') ?></div>
							<div class="author-name">
								<?php 
									echo '<a href="'. get_author_posts_url( $post_author_id ) .'">' . get_the_author_meta( 'display_name', $post_author_id ) .'</a>'; 
									$cook_level = smk_user_cooking_level($post_author_id, 'level');
									if( !empty($cook_level) && $cook_level !== 'none' ){
										echo '<span class="the-value mark '. smk_user_cooking_level($post_author_id, 'color') .'">'. smk_user_cooking_level($post_author_id) .'</span>';
									}
								?>
							</div>
							<div class="total-recipes"><?php printf( __('%d recipes', 'smk_theme'), smk_get_total_user_recipes( $post_author_id ) ); ?></div>
						</div>

					</div>
				</div>
				<?php

				endwhile; 
			}
			wp_reset_postdata();

			echo ( $show_slider ) ? '</div>' : '';

		}

		public function sortRecipesQuery( $sort_by ){
			$the_query = array();
			switch ($sort_by) {
				case 'favorites_count':
					$the_query['orderby']  = 'meta_value_num';
					$the_query['meta_key'] = 'smk_marks_count_favorite';
					break;
				
				case 'likes_count':
					$the_query['orderby']  = 'meta_value_num';
					$the_query['meta_key'] = 'smk_marks_count_like';
					break;
				
				case 'is_featured':
					$the_query['orderby']    = 'meta_value';
					$the_query['meta_key']   = 'smk_recipe_featured_time';
					$the_query['meta_query'] = array(
						array(
							'key'     => 'smk_recipe_is_featured',
							'value'   => 'yes',
							// 'compare' => 'IN',
						),
						array(
							'key'     => 'smk_recipe_featured_time',
						),
					);
					break;
					
				case 'is_featured_first':
					$the_query['orderby']    = 'meta_value';
					$the_query['meta_key']   = 'smk_recipe_featured_time';
					$the_query['meta_query'] = array(
						array(
							'key'     => 'smk_recipe_is_featured',
						),
						array(
							'key'     => 'smk_recipe_featured_time',
						),
					);
					break;
				
				
				default:
					$sort_by = ( in_array($sort_by, array( 'date', 'modified', 'rand', 'comment_count' )) ) ? $sort_by : 'date';
					$the_query['orderby']  = $sort_by;
					$the_query['meta_key'] = false;
					break;
			}

			// Only with photo
			$the_query['meta_query'][] = array( 
				'key' => '_thumbnail_id',
				'compare' => 'EXISTS'
			);

			return $the_query;
		}
		

	}//class
}//check class_exists
