<?php
if( class_exists('Smk_PageBuilder_Module') && !class_exists( 'Smk_Theme_PBM_Home_Blog_List' ) ) {
	class Smk_Theme_PBM_Home_Blog_List extends Smk_PageBuilder_Module {

		function settings(){
			return array(
				'title'    => __('Home blog list', 'smk_theme'),
				'desc'     =>  __('Show a list of blog posts based on custom settings.', 'smk_theme'),
				'category' => 'content theme_defined',
			);
		}

		function form(){
			return array(

				array(
					'id' 	=> 'title',
					'type' 	=> 'input',
					'label' => __('Title:', 'smk_theme'),
					'std' 	=> __('Blog', 'smk_theme'),
				),
				array(
					'id' 	=> 'per_page',
					'type' 	=> 'sliderui',
					'label' => __('Max number of recipes to display:', 'smk_theme'),
					'min' 	=> '2',
					'max' 	=> '40',
					'std' 	=> '5',
				),
				array(
					'id' 	=> 'sort_by',
					'type' 	=> 'select',
					'label' => __('Sort by:', 'smk_theme'),
					'std' 	=> 'date',
					'options' => array(
						'date'            => __('Date', 'smk_theme'),
						'modified'        => __('Last modified date', 'smk_theme'),
						'rand'            => __('Random order', 'smk_theme'),
						'comment_count'   => __('Comments count', 'smk_theme'),
					),
				),
				array(
					'id' 	=> 'style',
					'type' 	=> 'select',
					'label' => __('Style:', 'smk_theme'),
					'std' 	=> 'carousel',
					'options' => array(
						'carousel'          => __('Carousel', 'smk_theme'),
						'list'              => __('List', 'smk_theme'),
					),
				),

				array(
					'id' 	=> 'number_of_columns',
					'type' 	=> 'sliderui',
					'label' => __('Number of columns:', 'smk_theme'),
					'std' 	=> '4',
					'min' 	=> '3',
					'max' 	=> '6',
				),

			);
		}
		
		function render($data){
			$title    = ( !empty($data['title']) ) ? esc_html($data['title']) : '';
			$per_page = ( !empty($data['per_page']) && absint($data['per_page']) > 2 ) ? absint($data['per_page']) : 8;
			$sort_by  = ( !empty($data['sort_by']) ) ? $data['sort_by'] : 'date';
			$style    = ( !empty($data['style']) ) ? $data['style'] : 'carousel';
			$number_of_columns    = ( !empty($data['number_of_columns']) && absint($data['number_of_columns']) > 3 ) ? absint( $data['number_of_columns'] ) : '4';

			$posts_list_class = '';
			$container_class  = '';
			$h4_class         = '';
			$carousel_nav     = false;

			if( $style == 'carousel' ){
				$posts_list_class = 'home-carousel-posts show-'. $number_of_columns .'-items';
				$carousel_nav       = true;
				$container_class = ' carousel-container';
				$h4_class = ' class="carousel-posts-heading"';
			}
			else{
				$posts_list_class = 'recipes-list home-recipes-list';
			}

			$the_query = array (
				'post_type'      => 'post',
				'posts_per_page' => $per_page,
			);

			$sort_by = ( in_array($sort_by, array( 'date', 'modified', 'rand', 'comment_count' )) ) ? $sort_by : 'date';
			$the_query['orderby']  = $sort_by;

			$posts_query = new WP_Query($the_query);
			?>
			<div class="grid-container<?php echo $container_class; ?>">
				
					<div class="grid <?php echo ( $carousel_nav ) ? 'desk-6 mob-6' : 'desk-12'; ?>">
						<h4<?php echo $h4_class; ?>><?php echo esc_html($title); ?></h4>
					</div>
					<?php if( $carousel_nav ) : ?>
						<div class="grid desk-6 mob-6">
							<div class="carousel-posts-nav clearfix">
								<div class="carousel-posts-nav-next"><i class="fa fa-chevron-right"></i></div>
								<div class="carousel-posts-nav-prev"><i class="fa fa-chevron-left"></i></div>
							</div>
						</div>
					<?php endif; ?>
					<div class="clear"></div>
					
					<div class="<?php echo $posts_list_class; ?> clearfix">
						
						<?php
						if ($posts_query->have_posts()) {
							while ($posts_query->have_posts()) : $posts_query->the_post();


							if( 'carousel' == $style ){
							?>
								<!-- Entry -->
								<div class="entry style-columns">
									<?php
										$img_url  = '';
										$thumb_bg = '';
										if( has_post_thumbnail() ) {
											$img_url = '<img src="'. smk_theme_resize(smk_theme_post_image_url(), 460, 460, true) .'" alt="' . esc_attr( get_the_title() ) . '" />';
										}
										elseif( ! has_post_thumbnail() ){
											$thumb_bg = ' thumb-bg';
										}

										echo '<a href="'. get_permalink() .'"><div class="entry-photo'. $thumb_bg .'">'. $img_url .'</div></a>';
									?>
									<div class="entry-title">
										<a href="<?php the_permalink(); ?>"><?php the_title();?></a>
									</div>
									<div class="entry-meta">
										<span class="date"><?php smk_post_date('j M Y'); ?></span>
									</div>
									<div class="entry-content">
										<p><?php smk_theme_excerpt( 15 ); ?></p>
									</div>

									<div class="entry-controls">
										<span class="control entry-comments" title="<?php _e('Comments', 'smk_theme') ?>"> <i class="fa fa-comments"></i> </span> 
										<span class="control-tip"><?php smk_comments_number_link(false); ?></span>
									</div>
								</div> <!-- .entry -->

							<?php
							} //if( 'carousel' == $style )
							else{
								
								echo '<div class="grid desk-12">
									<div class="home-blog-post clearfix">
										<div class="entry-date">
											<div class="date">'. smk_post_date('j', false) .'</div>
											<div class="month">'. smk_post_date('F', false) .'</div>
										</div>
										<div class="entry-details">
											<div class="entry-title"><a href="'. get_permalink() .'">'. get_the_title() .'</a></div>
											<div class="entry-content">
												'. smk_theme_excerpt(15, "...", false) .'
											</div>
										</div>
									</div>
								</div>';

							}

						endwhile; 
						}
						else{
							echo '<div class="notification orange light">' . __('Sorry, no posts matched your criteria.', 'smk_theme') . '</div>';
						}
						wp_reset_postdata();
						?>

					</div> <!-- .home-carousel-posts -->

				</div>

			<?php

		}

	}//class
}//check class_exists