<?php
if( class_exists('Smk_PageBuilder_Module') && !class_exists( 'Smk_Theme_PBM_Home_Recipes_List' ) ) {
	class Smk_Theme_PBM_Home_Recipes_List extends Smk_PageBuilder_Module {

		function settings(){
			return array(
				'title' => __('Home recipes list', 'smk_theme'),
				'desc' =>  __('Show a list of recipes based on custom settings.', 'smk_theme'),
				'category' => 'content theme_defined',
			);
		}

		function categories_list( $args = array() ){
			$categories = get_terms('recipe_categories', $args);
			$output     = array(
				'any_category' => __('Any category', 'smk_theme')
			);
			if( !empty($categories) ){ 
				foreach ( $categories as $cat ) {
					$output[$cat->slug] = $cat->name;
				}
			}
			return $output;
		}

		function form(){
			return array(

				array(
					'id' 	=> 'title',
					'type' 	=> 'input',
					'label' => __('Title:', 'smk_theme'),
					'std' 	=> __('Recipes', 'smk_theme'),
				),
				array(
					'id' 	=> 'per_page',
					'type' 	=> 'sliderui',
					'label' => __('Max number of recipes to display:', 'smk_theme'),
					'min' 	=> '2',
					'max' 	=> '40',
					'std' 	=> '8',
				),
				array(
					'id' 	=> 'sort_by',
					'type' 	=> 'select',
					'label' => __('Sort by:', 'smk_theme'),
					'std' 	=> 'date',
					'options' => array(
						'date'              => __('Date', 'smk_theme'),
						'favorites_count'   => __('Favorites count', 'smk_theme'), 
						'likes_count'       => __('Likes count', 'smk_theme'),
						'modified'          => __('Last modified date', 'smk_theme'),
						'rand'              => __('Random order', 'smk_theme'),
						'comment_count'     => __('Comments count', 'smk_theme'),
						'is_featured'       => __('Only featured recipes', 'smk_theme'),
						'is_featured_first' => __('Featured recipes first', 'smk_theme'),
					),
				),
				array(
					'id' 	=> 'style',
					'type' 	=> 'select',
					'label' => __('Style:', 'smk_theme'),
					'std' 	=> 'carousel',
					'options' => array(
						'carousel'          => __('Carousel', 'smk_theme'),
						'carousel_big_grid' => __('Carousel big grid', 'smk_theme'), 
						'grid'              => __('Grid', 'smk_theme'),
						'list'              => __('List', 'smk_theme'),
						'big_list'          => __('Big list', 'smk_theme'),
					),
				),

				array(
					'id' 	=> 'number_of_columns',
					'type' 	=> 'sliderui',
					'label' => __('Number of columns:', 'smk_theme'),
					'std' 	=> '4',
					'min' 	=> '3',
					'max' 	=> '10',
				),
				array(
					'id' 	=> 'category',
					'type' 	=> 'select',
					'label' => __('Category:', 'smk_theme'),
					'std' 	=> 'date',
					'options' => $this->categories_list(),
				),

			);
		}
		
		function render($data){
			$title    = ( !empty($data['title']) ) ? esc_html($data['title']) : '';
			$per_page = ( !empty($data['per_page']) && absint($data['per_page']) > 2 ) ? absint($data['per_page']) : 8;
			$sort_by  = ( !empty($data['sort_by']) ) ? $data['sort_by'] : 'date';
			$style    = ( !empty($data['style']) ) ? $data['style'] : 'carousel';
			$category    = ( !empty($data['category']) ) ? $data['category'] : 'any_category';
			$number_of_columns    = ( !empty($data['number_of_columns']) && absint($data['number_of_columns']) > 3 ) ? absint( $data['number_of_columns'] ) : 4;

			$recipes_list_class = '';
			$carousel_nav       = false;
			if( $style == 'carousel_big_grid' ){
				$recipes_list_class = 'home-carousel-posts recipes-list fullwidth-grid home-recipes-list show-'. $number_of_columns .'-items';
				$carousel_nav       = true;
			}
			elseif( $style == 'carousel' ){
				$recipes_list_class = 'home-carousel-posts show-'. $number_of_columns .'-items';
				$carousel_nav       = true;
			}
			else{
				$recipes_list_class = 'recipes-list home-recipes-list';
			}

			$the_query = array (
				'post_type'      => 'smk_recipes',
				'posts_per_page' => $per_page,
			);

			if( 'any_category' !== $category ){
				$the_query['tax_query'] = array(
					array(
						'taxonomy' => 'recipe_categories',
						'field'    => 'slug',
						'terms'    => $category,
					),
				);
			}

			switch ($sort_by) {
				case 'favorites_count':
					$the_query['orderby']  = 'meta_value_num';
					$the_query['meta_key'] = 'smk_marks_count_favorite';
					break;
				
				case 'likes_count':
					$the_query['orderby']  = 'meta_value_num';
					$the_query['meta_key'] = 'smk_marks_count_like';
					break;
				
				case 'is_featured':
					$the_query['orderby']    = 'meta_value';
					$the_query['meta_key']   = 'smk_recipe_featured_time';
					$the_query['meta_query'] = array(
						array(
							'key'     => 'smk_recipe_is_featured',
							'value'   => 'yes',
							// 'compare' => 'IN',
						),
						array(
							'key'     => 'smk_recipe_featured_time',
						),
					);
					break;
					
				case 'is_featured_first':
					$the_query['orderby']    = 'meta_value';
					$the_query['meta_key']   = 'smk_recipe_featured_time';
					$the_query['meta_query'] = array(
						array(
							'key'     => 'smk_recipe_is_featured',
						),
						array(
							'key'     => 'smk_recipe_featured_time',
						),
					);
					break;
				
				
				default:
					$sort_by = ( in_array($sort_by, array( 'date', 'modified', 'rand', 'comment_count' )) ) ? $sort_by : 'date';
					$the_query['orderby']  = $sort_by;
					$the_query['meta_key'] = false;
					break;
			}
			$recipes_query = new WP_Query($the_query);
			?>
			<div class="grid-container carousel-container">
				
					<div class="grid <?php echo ( $carousel_nav ) ? 'desk-6 mob-6' : 'desk-12'; ?>">
						<h4 class="carousel-posts-heading"><?php echo esc_html($title); ?></h4>
					</div>
					<?php if( $carousel_nav ) : ?>
						<div class="grid desk-6 mob-6">
							<div class="carousel-posts-nav clearfix">
								<div class="carousel-posts-nav-next"><i class="fa fa-chevron-right"></i></div>
								<div class="carousel-posts-nav-prev"><i class="fa fa-chevron-left"></i></div>
							</div>
						</div>
					<?php endif; ?>
					<div class="clear"></div>
					
					<div class="<?php echo $recipes_list_class; ?> clearfix">
						
						<?php
						if ($recipes_query->have_posts()) {
							$position = 1;
							while ($recipes_query->have_posts()) : $recipes_query->the_post();


							if( 'carousel' == $style ){
							?>
								<!-- Entry -->
								<div class="entry style-columns">
									<?php
										$img_url  = '';
										$thumb_bg = '';
										if( has_post_thumbnail() ) {
											$img_url = '<img src="'. smk_theme_resize(smk_theme_post_image_url(), 460, 460, false) .'" alt="' . esc_attr( get_the_title() ) . '" />';
										}
										elseif( ! has_post_thumbnail() ){
											$thumb_bg = ' thumb-bg';
										}

										echo '<a href="'. get_permalink() .'"><div class="entry-photo'. $thumb_bg .'">'. $img_url .'</div></a>';
									?>
									<div class="entry-title">
										<a href="<?php the_permalink(); ?>"><?php the_title();?></a>
									</div>
									<div class="entry-meta">
										<span class="date"><?php smk_post_date('j M Y'); ?></span>
									</div>
									<div class="entry-content">
										<p><?php smk_theme_excerpt( 15 ); ?></p>
									</div>
									<div class="entry-controls">

									<?php if( 'comment_count' !== $sort_by ) { ?>

										<?php smk_favorite_button( false, array(
											'tag'              => 'a',
											'class'            => 'control entry-to-favorites',
											'content'          => '<i class="fa fa-heart-o"></i>',
											'content_remove'   => '<i class="fa fa-heart"></i>',
											'total_in_title'   => false,
											'modify_content'   => 'next',
											'title'            => __('Add to favorites', 'smk_theme'),
											'title_remove'     => __('Remove from favorites', 'smk_theme'),
											'title_not_logged' => __('Please log in to add this post to favorites', 'smk_theme'),
										)); ?>
										<span class="control-tip"><?php echo smk_get_favorites_count( get_the_ID() ); ?></span>

										<?php smk_like_button( false, array(
											'tag'              => 'a',
											'class'            => 'control entry-like',
											'content'          => '<i class="fa fa-thumbs-o-up"></i>',
											'content_remove'   => '<i class="fa fa-thumbs-up"></i>',
											'total_in_title'   => false,
											'modify_content'   => 'next',
											'title'            => __('Like', 'smk_theme'),
											'title_remove'     => __('Dislike', 'smk_theme'),
											'title_not_logged' => __('Please log in to like this post', 'smk_theme'),
										)); ?>
										<span class="control-tip"><?php echo smk_get_likes_count( get_the_ID() ); ?></span>

									<?php 
									}
									else{
										?>
										<span class="control entry-comments" title="<?php _e('Comments', 'smk_theme') ?>"> <i class="fa fa-comments"></i> </span> 
										<span class="control-tip"><?php smk_comments_number_link(false); ?></span>
										<?php
										} 
									?>
									</div>


								</div> <!-- .entry -->
						<?php
							} //if( 'carousel' == $style )
							elseif( 'carousel_big_grid' == $style ){
								$show_meta = ($number_of_columns < 7) ? true : false;
								smk_get_template_part("tpl/recipes-view-grid.php", array(
									'position' => false,
									'show_meta' => $show_meta,
								));
							}
							elseif( 'grid' == $style ){
								$show_meta = ($number_of_columns < 6) ? true : false;
								smk_get_template_part("tpl/recipes-view-grid.php", array(
									'position' => $position,
									'show_meta' => $show_meta,
									'columns' => $number_of_columns,
								));
							}

							elseif( 'list' == $style ){
								echo '<div class="grid desk-12">';
								smk_get_template_part("tpl/recipes-view-list.php");
								echo '</div>';
							}

							elseif( 'big_list' == $style ){
								echo '<div class="grid desk-12">';
								smk_get_template_part("tpl/recipes-view-large.php");
								echo '</div>';
							}


						endwhile; 
						$position++;
						$position = ( $position > $number_of_columns) ? 1 : $position;
						}
						else{
							echo '<div class="notification orange light">' . __('Sorry, no recipes matched your criteria.', 'smk_theme') . '</div>';
						}
						wp_reset_postdata();
						?>

					</div> <!-- .home-carousel-posts -->

				</div>

			<?php

		}

	}//class
}//check class_exists
