<?php
if( ! function_exists('smk_theme_related_posts') ){
	function smk_theme_related_posts( $settings = array(), $custom_query_args = array() ){

		$default_settings = array(
			'posts_per_page' => 6, 
			'show_thumbs' => true
		);

		$settings       = wp_parse_args( $settings, $default_settings );
		$posts_per_page = $settings['posts_per_page'] > 0 ? $settings['posts_per_page'] : 6;
		$the_cats       = array();
		$post_type      = isset( $settings['post_type'] ) ? $settings['post_type'] : 'post';

		// Prepare query args
		if( isset( $settings['post_type'] ) && isset($settings['tax']) ){
			$categories = get_the_terms(get_the_ID(), $settings['tax']);
			if( $categories ){
				foreach ($categories as $key => $cat) {
					$the_cats[] = $cat->term_id;
				}

				$custom_query_args['tax_query'] = array(
					array(
						'taxonomy' => $settings['tax'],
						'terms'    => (array) $the_cats,
					),
				);
			}
		}
		else{
			$categories = get_the_category();
			foreach ($categories as $key => $cat) {
				$the_cats[] = $cat->term_id;
			}
			$custom_query_args['cat'] = join(',', $the_cats);
		}
		
		$implicit_query_args = array( 
			'post_type' => $post_type,
			'posts_per_page' => $posts_per_page,
			'post__not_in' => (array) get_the_ID()
		);
		$query_args = wp_parse_args( $implicit_query_args, $custom_query_args );

		$the_query = new WP_Query( $query_args );

		// If no valid results, display random posts, and cache the results.
		if ( ! $the_query->have_posts() ) {
			wp_reset_postdata();
			$transient_key = 'smk_related_posts_'. $post_type;
			if ( false === ( $the_query = get_transient( $transient_key ) ) ) {
				$query_args = array(
					'orderby' => 'rand',
				);
				unset($query_args['tax_query']);
				unset($query_args['cat']);
				$query_args = wp_parse_args( $implicit_query_args, $query_args );
				$the_query = new WP_Query( $query_args );
				set_transient( $transient_key, $the_query, 15 * MINUTE_IN_SECONDS  );
			}
		}

		if ( $the_query->have_posts() ) {
			$count = $the_query->post_count;
			?>
				<div class="grid-container">
				
					<div class="grid desk-6">
						<h2 class="carousel-posts-heading"><?php _e('You may also like:', 'smk_theme'); ?></h2>
					</div>
					<?php if( $count > 3 ) { ?>
					<div class="grid desk-6">
						<div class="carousel-posts-nav clearfix">
							<div class="carousel-posts-nav-next"><i class="fa fa-chevron-right"></i></div>
							<div class="carousel-posts-nav-prev"><i class="fa fa-chevron-left"></i></div>
						</div>
					</div>
					<?php } ?>
					<div class="clear"></div>
					
					<div class="carousel-posts clearfix">
					<?php
						while ( $the_query->have_posts() ) {
							$the_query->the_post();
							?>
								<!-- Entry -->
								<div class="entry style-columns">
									<?php
										$img_url  = '';
										$thumb_bg = '';
										if( $settings['show_thumbs'] && has_post_thumbnail() ) {
											$img_url = '<img src="'. smk_theme_resize(smk_theme_post_image_url(), 460, 460, true) .'" alt="' . esc_attr( get_the_title() ) . '" />';
										}
										elseif( $settings['show_thumbs'] && ( ! has_post_thumbnail() ) ){
											$thumb_bg = ' thumb-bg';
										}

										echo '<a href="'. get_permalink() .'"><div class="entry-photo'. $thumb_bg .'">'. $img_url .'</div></a>';
									?>
									
									<div class="entry-title">
										<?php echo '<a href="'. get_permalink() .'">' . get_the_title() . '</a>'; ?>
									</div>
									<div class="entry-meta">
										<span class="date"><?php printf( __('%1$s', 'smk_theme') , get_the_time('F j, Y') ); ?></span>
									</div>
									<div class="entry-content">
										<?php smk_theme_excerpt( 10 ); ?>
									</div>
								</div> <!-- .entry -->
							<?php
						}
					?>
					</div> <!-- .carousel-posts -->

				</div> <!-- www.scriptha.ir -->
			<?php
		} else {
			// no posts found
		}

		wp_reset_postdata();
	}
}
