<?php
function smk_theme_customize_register_custom_controls( $wp_customize ) {
	/*
	-------------------------------------------------------------------------------
	Font Family control
	-------------------------------------------------------------------------------
	*/
	class Smk_Customize_Font_Family_Control extends WP_Customize_Control {
		public $type = 'font_family';
	
		public function render_content() {

			$all_fonts = smk_toolkit_fonts();
			?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php if ( ! empty( $this->description ) ) : ?>
						<span class="description customize-control-description"><?php echo $this->description ; ?></span>
					<?php endif; ?>

					<select <?php $this->link(); ?>>
						<?php 
						$saved_value = $this->value();
						if( !empty($all_fonts) ){
							foreach ( (array) $all_fonts as $font_group_key => $font_group) {
								echo '<optgroup label="'. $font_group['label'] .'">';
									foreach ($font_group['options'] as $family => $title) {
										$selected = selected( $saved_value, $family, false );
										$selected = !empty($selected) ? ' selected="selected"' : '';
										echo '<option value="'. esc_attr($family) .'"'. $selected .'>'. $title .'</option>';
									}
								echo '</optgroup>';
							}
						}
						?>
					</select>
				</label>
			<?php
		}
	}
	/*
	-------------------------------------------------------------------------------
	Button control
	-------------------------------------------------------------------------------
	*/
	class Smk_Customize_Button_Control extends WP_Customize_Control {
		public $type = 'button';
		public $args = array();

		public function __construct( $manager, $id, $args = array() ) {
			$this->args = $args;
			parent::__construct( $manager, $id, $args);
		}

		public function render_content() {
			?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php if ( ! empty( $this->description ) ) : ?>
						<span class="description customize-control-description"><?php echo $this->description ; ?></span>
					<?php endif; ?>
				</label>
					
				<?php 
					$button_id    = ( !empty($this->args['button_id']) ) ? ' id="'. $this->args['button_id'] .'"' : '';
					$button_value = ( !empty($this->args['button_value']) ) ? $this->args['button_value'] : '';
					echo '<button'. $button_id . '>'. esc_html($button_value) .'</button>';
				?>
			<?php
		}
	}
}
add_action( 'customize_register', 'smk_theme_customize_register_custom_controls' );

class Smk_Theme_Customize{

	public $customize;
	public $section;

	public function __construct( $wp_customize ){
		$this->customize = $wp_customize;
		$this->section = 'title_tagline';
	}

	public function addSection( $id, $title = false, $settings = array() ){	
		// Add new section
		if( !empty($title) && trim($title) !== false ){
			$defaults = array( 'title' => $title );
			$settings = wp_parse_args( $settings, $defaults );
			$this->customize->add_section( $id, $settings );
		}
		
		// Switch to this section
		$this->section = $id;
	}

	public function addPanel( $id, $title = '', $settings = array() ){	
		// Add new panel
		$title = !empty($title) && trim($title) !== false ? $title : $id;
		$defaults = array( 'title' => $title );
		$settings = wp_parse_args( $settings, $defaults );
		$this->customize->add_panel( $id, $settings );
	}

	public function addField( $id, $type = 'text', $settings = array() ){
		$defaults = array( 'default' => '' );
		$settings = wp_parse_args( $settings, $defaults );

		// Create the settings
		$this->customize->add_setting( $id, $settings );

		// Add control to this setting
		$settings['section'] = $this->section;
		$settings['type']    = $type;

		switch ($type) {
			case 'text':
			case 'checkbox':
			case 'radio':
			case 'select':
			case 'dropdown-pages':
			case 'textarea':
				$this->customize->add_control( $id, $settings );
				break;
			
			case 'color':
				$this->customize->add_control( new WP_Customize_Color_Control( $this->customize, $id, $settings ) );
				break;
			
			case 'upload':
				$this->customize->add_control( new WP_Customize_Upload_Control( $this->customize, $id, $settings ) );
				break;
			
			case 'image':
				$this->customize->add_control( new WP_Customize_Image_Control( $this->customize, $id, $settings ) );
				break;

			case 'background':
				$this->customize->add_control( new WP_Customize_Background_Image_Control( $this->customize, $id, $settings ) );
				break;
			
			case 'font_family':
				$this->customize->add_control( new Smk_Customize_Font_Family_Control( $this->customize, $id, $settings ) );
				break;
			
			case 'button':
				$this->customize->add_control( new Smk_Customize_Button_Control( $this->customize, $id, $settings ) );
				break;
			
			default:
				# code...
				break;
		}

	}

}



function smk_theme_customize_register( $wp_customize ) {
	if( ! class_exists('Smk_Theme_Customize') ) 
		return;

	$ctz = new Smk_Theme_Customize( $wp_customize );

	/*
	-------------------------------------------------------------------------------
	Theme fonts section
	-------------------------------------------------------------------------------
	*/
	$ctz->addSection( 'smk_theme_fonts', __('Theme fonts', 'smk_theme') );
	
	$ctz->addField( 'heading-font-family', 'font_family', array(
		'label' => __('Headings font family', 'smk_theme'),
		'default' => 'Arial, "Helvetica Neue", Helvetica, sans-serif',
	));

	$ctz->addField( 'body-font-family', 'font_family', array(
		'label' => __('Body text font family', 'smk_theme'),
		'default' => 'Arial, "Helvetica Neue", Helvetica, sans-serif',
	));

	/*
	-------------------------------------------------------------------------------
	Theme styles section
	-------------------------------------------------------------------------------
	*/
	$ctz->addSection( 'smk_theme_styles', __('Theme styles', 'smk_theme') );

	$ctz->addField( 'color-scheme-primary', 'color', array(
		'label' => __('Color scheme primary', 'smk_theme'),
		'default' => '#288DFF',
	));

	$ctz->addField( 'rw-header-background-color', 'color', array(
		'label' => __('Header background', 'smk_theme'),
		'default' => '#2A3744',
	));

	$ctz->addField( 'link-color', 'color', array(
		'label' => __('Link color', 'smk_theme'),
		'default' => '',
	));

	$ctz->addField( 'link-hover-color', 'color', array(
		'label' => __('Link color - hover state', 'smk_theme'),
		'default' => '',
	));

	$ctz->addField( 'body-background-color', 'color', array(
		'label' => __('Body background color', 'smk_theme'),
		'default' => '',
	));

	$ctz->addField( 'body-background-image', 'image', array(
		'label' => __('Body background image', 'smk_theme'),
		'default' => '',
	));

	$ctz->addField( 'body-background-repeat', 'select', array(
		'label' => __('Body background repeat', 'smk_theme'),
		'default' => 'repeat',
		'choices' => array(
			'repeat' => __('Repeat', 'smk_theme'),
			'no-repeat' => __('No repeat', 'smk_theme')
		),
	));

	$ctz->addField( 'body-background-attachment', 'select', array(
		'label' => __('Body background attachment', 'smk_theme'),
		'default' => 'scroll',
		'choices' => array(
			'scroll' => __('Scroll', 'smk_theme'),
			'fixed' => __('Fixed', 'smk_theme')
		),
	));

	$ctz->addField( 'body-background-size', 'select', array(
		'label' => __('Body background size', 'smk_theme'),
		'default' => 'auto',
		'choices' => array(
			'auto' => __('Auto', 'smk_theme'),
			'cover' => __('Cover', 'smk_theme'),
			'contain' => __('Contain', 'smk_theme')
		),
	));

	/*
	-------------------------------------------------------------------------------
	Header UX
	-------------------------------------------------------------------------------
	*/
	$ctz->addSection( 'smk_theme_header_ux', __('Header UX', 'smk_theme') );

	$ctz->addField( 'sticky_header', 'checkbox', array(
		'label' => __('Sticky header', 'smk_theme'),
	));

	$ctz->addField( 'show_header_search_icon', 'checkbox', array(
		'label' => __('Show search icon in header', 'smk_theme'),
	));

	$ctz->addField( 'show_header_pm_icon', 'checkbox', array(
		'label' => __('Show PM icon in header', 'smk_theme'),
	));

	$ctz->addField( 'show_header_submission_icon', 'checkbox', array(
		'label' => __('Show submission icon in header', 'smk_theme'),
	));

	$ctz->addField( 'show_header_user_menu', 'checkbox', array(
		'label' => __('Show user menu in header', 'smk_theme'),
	));

	$ctz->addField( 'user_menu_show_element', 'select', array(
		'label' => __('User menu pointer.', 'smk_theme'),
		'default' => 'avatar',
		'choices' => array(
			'avatar' => __('User avatar', 'smk_theme'),
			'username' => __('Username', 'smk_theme'),
			'icon' => __('Icon', 'smk_theme'),
		),
	));

	$ctz->addField( 'auth_links', 'select', array(
		'label' => __('Authentification links', 'smk_theme'),
		'default' => 'signin',
		'choices' => array(
			'signin' => __('Only "Sign In" link', 'smk_theme'),
			'signin_n_reg' => __('"Sign In" and "Register" links', 'smk_theme'),
		),
	));

	$ctz->addField( 'custom_login_link', 'text', array(
		'label' => __('Custom "Sign In" link.', 'smk_theme'),
		'default' => '',
	));
	
	$ctz->addField( 'custom_registration_link', 'text', array(
		'label' => __('Custom "Registration" link.', 'smk_theme'),
		'default' => '',
	));

	/*
	-------------------------------------------------------------------------------
	Single recipe UI
	-------------------------------------------------------------------------------
	*/
	$ctz->addSection( 'smk_theme_single_recipe_ui', __('Single recipe UI', 'smk_theme') );

	$ctz->addField( 'single_recipe_meta_position', 'select', array(
		'label' => __('Single recipe meta position.', 'smk_theme'),
		'default' => 'right',
		'choices' => array(
			'right' => _x('Right', 'Recipe meta position', 'smk_theme'),
			'left' => _x('Left', 'Recipe meta position', 'smk_theme'),
			'top' => _x('Top', 'Recipe meta position', 'smk_theme'),
			'bottom' => _x('Bottom', 'Recipe meta position', 'smk_theme'),
		),
	));


	/*
	-------------------------------------------------------------------------------
	Theme settings
	-------------------------------------------------------------------------------
	*/
	$ctz->addSection( 'smk_theme_settings', __('Theme settings', 'smk_theme') );

	$ctz->addField( 'site_logo', 'image', array(
		'label' => __('Site logo', 'smk_theme'),
	));

	$ctz->addField( 'logo-align', 'select', array(
		'label' => __('Logo align', 'smk_theme'),
		'default' => 'left',
		'choices' => array(
			'left' => __('Left', 'smk_theme'),
			'center' => __('Center', 'smk_theme'),
		),
	));

	$ctz->addField( 'layout_style', 'select', array(
		'label' => __('Layout style', 'smk_theme'),
		'default' => 'boxed',
		'description' => __('Select the layout style.', 'smk_theme'),
		'choices' => array(
			'boxed' => __('Boxed', 'smk_theme'),
			'full' => __('Full width', 'smk_theme'),
		),
	));

	$ctz->addField( 'layout_width', 'select', array(
		'label' => __('Layout width', 'smk_theme'),
		'default' => 1140,
		'description' => __('Select the layout width.', 'smk_theme'),
		'choices' => array(
			'940' => 940,
			'1040' => 1040,
			'1140' => 1140,
			'1240' => 1240,
			'1340' => 1340,
			'1440' => 1440,
		),
	));

	$ctz->addField( 'sidebar_width', 'select', array(
		'label' => __('Sidebar width', 'smk_theme'),
		'default' => 300,
		'description' => __('Select the sidebar width.', 'smk_theme'),
		'choices' => array(
			'240' => 240,
			'300' => 300,
			'340' => 340,
			'400' => 400,
			'440' => 440,
		),
	));

	$ctz->addField( 'recipes_index_sidebar', 'select', array(
		'label' => __('Recipes sidebar', 'smk_theme'),
		'default' => 'none',
		'description' => __('Show or not a sidebar on recipes index page.', 'smk_theme'),
		'choices' => array(
			'none' => __('No sidebar', 'smk_theme'),
			'right' => __('Right sidebar', 'smk_theme'),
			'left' => __('Left sidebar', 'smk_theme'),
		),
	));

	$ctz->addField( 'site_copyright', 'textarea', array(
		'label' => __('Copyright text', 'smk_theme'),
		'default' => __('Copyright &amp;copy; {YEAR}. All rights reserved', 'smk_theme'),
		'description' => sprintf( __('The website copyright in the footer. Use %s to display the current year and %s to get the site url.', 'smk_theme'), '<code>{YEAR}</code>', '<code>{SITE_URL}</code>'),
	));

	$ctz->addField( 'show_recipes_view_filter', 'radio', array(
		'label' => __('Show recipes view filter', 'smk_theme'),
		'default' => 'y',
		'choices' => array(
			'y' => __('Yes, show it.', 'smk_theme'),
			'n' => __('No, hide it.', 'smk_theme'),
		),
	));

	$ctz->addField( 'show_recipes_per_page_filter', 'radio', array(
		'label' => __('Show recipes per page filter', 'smk_theme'),
		'default' => 'y',
		'choices' => array(
			'y' => __('Yes, show it.', 'smk_theme'),
			'n' => __('No, hide it.', 'smk_theme'),
		),
	));

	/*
	-------------------------------------------------------------------------------
	404 page
	-------------------------------------------------------------------------------
	*/
	$ctz->addSection( 'smk_theme_404_page_settings', __('404 page settings', 'smk_theme') );

	$ctz->addField( 'text_404', 'text', array(
		'label' => __('404 text', 'smk_theme'),
		'default' => '404',
	));

	$ctz->addField( 'not_found_title', 'text', array(
		'label' => __('"Not found" title', 'smk_theme'),
		'default' => __('Page not found', 'smk_theme'),
	));

	$ctz->addField( 'not_found_text', 'textarea', array(
		'label' => __('"Not found" text', 'smk_theme'),
		'default' => __("We're truly sorry, but there is no such page.<br /> It might have been removed, had its name changed, or is temporarily unavailable.", "smk_theme"),
	));

}
add_action( 'customize_register', 'smk_theme_customize_register' );



function smk_theme_setting( $option, $default = '' ){
	return get_theme_mod($option, $default);
}

/*
-------------------------------------------------------------------------------
Apply settings
-------------------------------------------------------------------------------
*/

function smk_theme_logo_filter( $the_logo ){
	$logo = smk_theme_setting('site_logo');
	if( !empty($logo) ){
		return '<a href="'. site_url() .'">
			<img src="'. esc_url($logo) .'" class="logo" alt="'. get_bloginfo('name') .'" />
		</a>';
	}
	else{
		return $the_logo;
	}
}
add_filter( 'smk_theme_logo', 'smk_theme_logo_filter' );

function smk_theme_logo_holder_filter( $class ){
	$option = smk_theme_setting('logo-align');
	if( !empty($option) ){
		if( $option == 'center' ){
			return $class . ' center-logo';
		}
	}
	return $class;
}
add_filter( 'smk_logo_holder_class', 'smk_theme_logo_holder_filter' );



function smk_color_is_hex( $subject ){
	$check = preg_match("/^#(?:[0-9a-fA-F]{3}){1,2}$/", $subject);
	return ( $check === 1 );
}

function smk_color_is_light( $color = FALSE ){
	// Get our color
	$color = str_replace('#', '', $color);
	// Calculate straight from rbg
	$r = hexdec($color[0].$color[1]);
	$g = hexdec($color[2].$color[3]);
	$b = hexdec($color[4].$color[5]);
	return (( $r*299 + $g*587 + $b*114 )/1000 > 130);
}

function smk_color_is_dark( $color = FALSE ){
	// Get our color
	$color = str_replace('#', '', $color);
	// Calculate straight from rbg
	$r = hexdec($color[0].$color[1]);
	$g = hexdec($color[2].$color[3]);
	$b = hexdec($color[4].$color[5]);
	return (( $r*299 + $g*587 + $b*114 )/1000 <= 130);
}

function smk_set_less_color( $opt_name, $default ){
	$opt = smk_theme_setting( $opt_name );
	return ( !empty ($opt) && smk_color_is_hex($opt) ) ? $opt : $default;
}


/*
-------------------------------------------------------------------------------
Inject custom CSS
-------------------------------------------------------------------------------
*/
function smk_gustos_theme_css( $mode = false ){

	// This website upload dir
	$upload_dir = wp_upload_dir();
	$up_path    = trailingslashit($upload_dir['basedir']);
	$logo       = ('site_logo');
	$less       = new lessc;

	$color_scheme        = smk_set_less_color( 'color-scheme-primary', '#288DFF' );
	$header_bg           = smk_set_less_color( 'rw-header-background-color', '#2A3744' );
	$menu_link_bright    = ( smk_color_is_dark($header_bg) ) ? '#eee' : '#555';
	$link_hover          = smk_set_less_color( 'link-hover-color', '' );
	$body_bg_color       = smk_set_less_color( 'body-background-color', '#eee' );
	$body_bg_image       = smk_theme_setting( 'body-background-image', '' );
	$body_bg_repeat      = smk_theme_setting( 'body-background-repeat', 'repeat' );
	$body_bg_attachment  = smk_theme_setting( 'body-background-attachment', 'scroll' );
	$body_bg_size        = smk_theme_setting( 'body-background-size', 'auto' );
	$body_font_family    = smk_theme_setting( 'body-font-family', 'Arial, "Helvetica Neue", Helvetica, sans-serif' );
	$heading_font_family = smk_theme_setting( 'heading-font-family', 'Arial, "Helvetica Neue", Helvetica, sans-serif' );
	$layout_style        = smk_theme_setting( 'layout_style', 'boxed' );
	$layout_width        = smk_theme_setting( 'layout_width', 1140 );
	$sidebar_width       = smk_theme_setting( 'sidebar_width', 300 );
	$body_bg_image       = ( 'boxed' == $layout_style ) ? 'url('. $body_bg_image .')' : 'none';

	$less_var = array(
		"color-scheme-primary"       => $color_scheme,
		"rw-header-background-color" => $header_bg,
		"menu-main-color"            => $header_bg,
		"menu-main-link-color"       => $menu_link_bright,
		"menu-main-link-before"      => $menu_link_bright,
		"rw-header-link-color"       => $menu_link_bright,
		"rw-header-text-color"       => $menu_link_bright,
		"link-color"                 => smk_set_less_color( 'link-color', $color_scheme ),
		"link-hover-color"           => !empty($link_hover) ? $link_hover : 'darken('. $color_scheme  .', 10%)',
		"body-background-color"      => $body_bg_color,
		"body-background-image"      => $body_bg_image,
		"body-background-repeat"     => $body_bg_repeat,
		"body-background-attachment" => $body_bg_attachment,
		"body-background-size"       => $body_bg_size,
		"body-font-family"           => $body_font_family,
		"heading-font-family"        => $heading_font_family,
		"rw-layout-width"            => $layout_width . 'px',
		"sidebar-width"              => $sidebar_width . 'px',
	);

	$less->setVariables( $less_var );

	$mode = ( is_customize_preview() ) ? '-preview' : '';

	$need_css_compile = get_option('smk_gustos_theme_compile_css');

	if( is_customize_preview() || ( !is_customize_preview() && $need_css_compile ) ){
		try {
			$less->compileFile(SMK_THEME_ASSETS .'less/theme.less', $up_path . 'gustos-theme'. $mode .'.css');
			if( !is_customize_preview() && $need_css_compile ){
				delete_option('smk_gustos_theme_compile_css');
			}
		} catch (exception $e) {
			echo "fatal error: " . $e->getMessage();
		}
	}

}
add_action('wp_head', 'smk_gustos_theme_css');

function smk_gustos_custom_theme_style( $mode = false ){
	$mode = ( is_customize_preview() ) ? '-preview' : '';
	$upload_dir = wp_upload_dir();
	$up_url = trailingslashit($upload_dir['baseurl']);

	$standard_fonts = array(
		'Arial',
		'Arial Black',
		'Arial Narrow',
		'Arial Rounded MT Bold',
		'Avant Garde',
		'Calibri',
		'Candara',
		'Helvetica Neue',
		'Impact',
		'Lucida Grande',
		'Optima',
		'Segoe UI',
		'Tahoma',
		'Trebuchet MS',
		'Verdana',
		'Georgia',
		'Palatino',
		'TimesNewRoman',
		'Consolas',
		'Courier New',
		'Lucida Console',
	);

	$body_font_family    = smk_theme_setting( 'body-font-family', 'Arial, "Helvetica Neue", Helvetica, sans-serif' );
	$body_font_family = explode(',', str_replace(array("'", "\""), '', $body_font_family));
	$body_font_family = trim($body_font_family[0]);

	if( !in_array( $body_font_family, (array) $standard_fonts) ){
		wp_enqueue_style( 'body-google-font', '//fonts.googleapis.com/css?family='. str_replace(' ', '+', $body_font_family) );
	}

	$heading_font_family = smk_theme_setting( 'heading-font-family', 'Arial, "Helvetica Neue", Helvetica, sans-serif' );
	$heading_font_family = explode(',', str_replace(array("'", "\""), '', $heading_font_family));
	$heading_font_family = trim($heading_font_family[0]);
	
	if( !in_array( $heading_font_family, (array) $standard_fonts) ){
		wp_enqueue_style( 'heading-google-font', '//fonts.googleapis.com/css?family='. str_replace(' ', '+', $heading_font_family) );
	}

	wp_enqueue_style( 'custom-gustos-theme'. $mode, $up_url . 'gustos-theme'. $mode .'.css' );
}
add_action('wp_enqueue_scripts', 'smk_gustos_custom_theme_style', 99);


function smk_theme_gustos_request_compile_css(){
	update_option('smk_gustos_theme_compile_css', time());
}
add_action('customize_save', 'smk_theme_gustos_request_compile_css');