<?php
class Smk_Recipes_List extends Smk_Widget {

	function __construct() {
		$widget_settings = array();

		$widget_ops = array(
			'classname' 	=> 'widget_recipes_list', 
			'description' 	=> __('Display a list of recipes.','smk_theme')
		);

		Wp_Widget::__construct('widget_recipes_list', __('Recipes List', 'smk_theme'), $widget_ops, $widget_settings );

	}


	function options() {	
		$wgt_opt = array();
		$wgt_opt[] = array(
			'id' 	=> 'title',
			'type' 	=> 'input',
			'label' => __('Title', 'smk_theme'),
			'std' 	=> __('Recipes', 'smk_theme'),

		);
		$wgt_opt[] = array(
			'id' 	=> 'number_of_recipes',
			'type' 	=> 'input',
			'label' => __('Number of recipes to show', 'smk_theme'),
			'std' 	=> '4',
		);
		$wgt_opt[] = array(
			'id' 	=> 'sort_by',
			'type' 	=> 'select',
			'label' => __('Sort by:', 'smk_theme'),
			'std' 	=> 'date',
			'options' => array(
				'date'              => __('Date', 'smk_theme'),
				'favorites_count'   => __('Favorites count', 'smk_theme'), 
				'likes_count'       => __('Likes count', 'smk_theme'),
				'modified'          => __('Last modified date', 'smk_theme'),
				'rand'              => __('Random order', 'smk_theme'),
				'comment_count'     => __('Comments count', 'smk_theme'),
				'is_featured'       => __('Only featured recipes', 'smk_theme'),
				'is_featured_first' => __('Featured recipes first', 'smk_theme'),
			),
		);

		return $wgt_opt;
	}

	
	public function widget( $args, $instance ) {	

		echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
		}

		$posts_per_page = ( !empty( $instance['number_of_recipes'] ) && absint( $instance['number_of_recipes'] ) > 0 ) ? absint( $instance['number_of_recipes'] ) : 4;
		$sort_by  = ( !empty($instance['sort_by']) ) ? $instance['sort_by'] : 'date';
		$the_query = array (
			'post_type'      => 'smk_recipes',
			'posts_per_page' => $posts_per_page,
		);

		// Sort by
		switch ($sort_by) {
			case 'favorites_count':
				$the_query['orderby']  = 'meta_value_num';
				$the_query['meta_key'] = 'smk_marks_count_favorite';
				break;
			
			case 'likes_count':
				$the_query['orderby']  = 'meta_value_num';
				$the_query['meta_key'] = 'smk_marks_count_like';
				break;
			
			case 'is_featured':
				$the_query['orderby']    = 'meta_value';
				$the_query['meta_key']   = 'smk_recipe_featured_time';
				$the_query['meta_query'] = array(
					array(
						'key'     => 'smk_recipe_is_featured',
						'value'   => 'yes',
						// 'compare' => 'IN',
					),
					array(
						'key'     => 'smk_recipe_featured_time',
					),
				);
				break;
			
			case 'is_featured_first':
				$the_query['orderby']    = 'meta_value';
				$the_query['meta_key']   = 'smk_recipe_featured_time';
				$the_query['meta_query'] = array(
					array(
						'key'     => 'smk_recipe_is_featured',
					),
					array(
						'key'     => 'smk_recipe_featured_time',
					),
				);
				break;
			
			default:
				$sort_by = ( in_array($sort_by, array( 'date', 'modified', 'rand', 'comment_count' )) ) ? $sort_by : 'date';
				$the_query['orderby']  = $sort_by;
				$the_query['meta_key'] = false;
				break;
		}

		echo '<div class="widget-posts-list">';
		$recipes_query = new WP_Query($the_query);
		if ($recipes_query->have_posts()) {
			while ($recipes_query->have_posts()) : 

				$recipes_query->the_post();
				?>
				<!-- Entry -->
				<div class="post">
					<div class="entry-photo">
						<?php if ( has_post_thumbnail() ) {
							echo '<img src="'. smk_theme_resize(smk_theme_post_image_url(), 50, 50, true) .'" alt="" />'; 
						} ?>
					</div>
					<div class="entry-title">
						<a href="<?php the_permalink(); ?>"><?php the_title();?></a>
					</div>
					<div class="entry-controls minimal">
						
						<?php if( 'comment_count' !== $sort_by ) { ?>
						
							<?php smk_favorite_button( false, array(
								'tag'              => 'a',
								'class'            => 'control entry-to-favorites',
								'content'          => '<i class="fa fa-heart-o"></i>',
								'content_remove'   => '<i class="fa fa-heart"></i>',
								'total_in_title'   => false,
								'modify_content'   => 'next',
								'title'            => __('Add to favorites', 'smk_theme'),
								'title_remove'     => __('Remove from favorites', 'smk_theme'),
								'title_not_logged' => __('Please log in to add this post to favorites', 'smk_theme'),
							)); ?>
							<span class="control-tip"><?php echo smk_get_favorites_count( get_the_ID() ); ?></span>

							<?php smk_like_button( false, array(
								'tag'              => 'a',
								'class'            => 'control entry-like',
								'content'          => '<i class="fa fa-thumbs-o-up"></i>',
								'content_remove'   => '<i class="fa fa-thumbs-up"></i>',
								'total_in_title'   => false,
								'modify_content'   => 'next',
								'title'            => __('Like', 'smk_theme'),
								'title_remove'     => __('Dislike', 'smk_theme'),
								'title_not_logged' => __('Please log in to like this post', 'smk_theme'),
							)); ?>
							<span class="control-tip"><?php echo smk_get_likes_count( get_the_ID() ); ?></span>
							<span class="control entry-comments" title="<?php _e('Comments', 'smk_theme') ?>"> <i class="fa fa-comments"></i> </span> 
							<span class="control-tip"><?php echo get_comments_number(); ?></span>

						<?php 
						}
						else{
							?>
							<span class="control entry-comments" title="<?php _e('Comments', 'smk_theme') ?>"> <i class="fa fa-comments"></i> </span> 
							<span class="control-tip"><?php smk_comments_number_link(false); ?></span>
							<?php
							} 
						?>

					</div>
				</div> <!-- .entry -->
				<?php
			endwhile;
		}
		echo '</div>';

		wp_reset_query();
		echo $args['after_widget'];
	}

} // class Foo_Widge