<?php
/* 
 * Widget Image
 *
 * Upload an image and optionally attach a title and description.
 *
 * -------------------------------------------------------------------------------------
 * @Author: Smartik
 * @Author URI: http://smartik.ws/
 * @Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 * @Date:   2014-05-25 14:09:43
 * @Last Modified by:   Smartik
 * @Last Modified time: 2014-05-26 10:03:34
 *
 */
if( ! class_exists('Smk_Theme_WidgetImage') && class_exists('Smk_Widget') ) {
class Smk_Theme_WidgetImage extends Smk_Widget {

	public $pbm_img;

	function __construct() {
		
		$widget_settings = array();

		$widget_ops = array(
			'classname' 	=> 'widget_image', 
			'description' 	=> __('Upload an image and optionally attach a title and description.','smk_theme')
		);

		Wp_Widget::__construct('widget_image', __('SMK Widget Image','smk_theme'), $widget_ops, $widget_settings );

	}

	################################################################################
	
	/**
	 * The options to be passed in form() method
	 *
	 * The options to be passed in form() method. If you modify form() method then
	 * these options will have no effect unless you include the form() from parent.
	 *
	 * @return array
	 */
	function options() {
	
		$wgt_opt = array();

		$wgt_opt[] = array(
			'id' 	=> 'title',
			'type' 	=> 'input',
			'label' => __('Title', 'smk_theme'),
			'desc' 	=> __('Widget title', 'smk_theme'),
		);
		$wgt_opt[] = array(
			'id' 	=> 'image',
			'type' 	=> 'upload',
			'label' => __('Image:', 'smk_theme'),
		);
		$wgt_opt[] = array(
			'id' 	=> 'max_width',
			'type' 	=> 'sliderui',
			'label' => __('Image:', 'smk_theme'),
			'min' 	=> '0',
			'max' 	=> '600',
			'std' 	=> '220',
		);
		$wgt_opt[] = array(
			'id' 	=> 'align',
			'type' 	=> 'visual_select',
			'label' => __('Align', 'smk_theme'),
			'std'   => 'default',
			'options' => array(
				array(
					'val'   => 'default',
					'label' => __('Default', 'smk_theme'),
				),
				array(
					'val'   => 'center',
					'label' => __('Center', 'smk_theme'),
				),
			),
			'mode' => 'text'
		);
		$wgt_opt[] = array(
			'id' 	=> 'description',
			'type' 	=> 'textarea',
			'label' => __('Image description:', 'smk_theme'),
			'desc' 	=> __('A short description about this image. Leave empty to disable.', 'smk_theme'),
		);
		
		return $wgt_opt;

	}

	################################################################################
	
	/**
	 * Widget front-end output
	 *
	 * The content to display on front-end
	 *
	 * @param string $args the arguments before_widget, after_widget, etc 
	 * @param array $instance is the saved data. 
	 */
	function widget( $args, $instance ) {
		
		extract($args);

		// smk_print($args);
		// smk_print($instance);

		$title       = smk_get_value($instance, 'title', '');
		$description = smk_get_value( $instance, 'description', '');
		$max_width   = absint( smk_get_value( $instance, 'max_width', 220) );
		$image       = esc_url( smk_get_value( $instance, 'image', '') );
		if( $max_width > 0 ){
			$image = smk_resize($image, $max_width);
		}
		$align = smk_get_value($instance, 'align', 'default');
		$align = ('center' == $align ) ? ' class="aligncenter"' : '';

		echo $before_widget;

		if( !empty($title) ){
			echo $before_title;
				echo $title;
			echo $after_title;
		}

		if( !empty($image) ){
			echo '<div class="image"><img src="'. $image .'" alt="'. $title .'"'. $align .' /></div>';
		}
		if( !empty($description) ){
			echo '<div class="description">'. wpautop( $description ) .'</div>';
		}

		echo $after_widget;

	}

}//End Class
}//End class_exists check
?>