<?php
class Smk_Mark_Post{

	protected $userId;
	protected $type;

	public function __construct( $type ){
		// User ID
		$current_user = Smk_Theme_User::currentUser();
		$this->userId = $current_user->ID;

		// Mark type(favorite, like, etc.)
		$this->type = $type;
	}

	public function button( $post_id = false, $settings = array() ){
		$post_id    = $post_id ? $post_id : get_the_ID();
		$settings   = $this->prepareSettings( $post_id, $settings );
		$class      = !empty($settings['class']) ? ' '.$settings['class'] : '';
		$is_active  = is_user_logged_in() && $this->userHasMarked($post_id) ? ' '. $settings['class_active'] : '';
		$content    = !empty($settings['content']) ? $settings['content'] : '';
		$content    = $this->userHasMarked($post_id) ? $settings['content_remove'] : $content;

		$output = '<'. $settings['tag'] . $this->getButtonAttr( $settings['attributes'] ) .' class="smk-mark-button'. $class  . $is_active .'">'. $content .'</'. $settings['tag'] .'>';

		if( $settings['echo'] ){
			echo $output;
		}
		else{
			return $output;
		}
	}

	public function getButtonAttr( $atts ){
		$attributes = '';
		if( !empty($atts) ){
			if( is_array($atts) ){
				$attr = array();
				foreach ($atts as $key => $value) {
					if( ! is_numeric($key) && isset( $value ) ){
						$attr[] = $key .'="'. $value .'"';
					}
				}
				if( !empty($attr) ){
					$attributes = ' '. join($attr, ' ');
				}
			}
		}
		return $attributes;
	}

	public function prepareSettings( $post_id, $settings = array()){
		$default_settings = array(
			'tag'              => 'div',
			'class'            => '',
			'class_active'     => 'active',
			'title'            => __('Mark post', 'smk_theme'),
			'content'          => __('Mark post', 'smk_theme'),
			'title_remove'     => __('Unmark post', 'smk_theme'),
			'content_remove'   => '',
			'title_format'     => '%text%', //%text% (%count%)
			'title_not_logged' => __('Please log in to mark this post', 'smk_theme'),
			'attributes'       => array(),
			'modify_content'   => false, // Modify the content in next or prev element. Used for JS to change the value in an element that is after or before the button
			'echo'             => true,
		);
		$settings        = wp_parse_args( $settings, $default_settings );
		$settings['tag'] = !empty($settings['tag']) && in_array($settings['tag'], array('div', 'span', 'li', 'a', 'button')) ? $settings['tag'] : 'div';
		$total           = $this->getMarksCount($post_id);
		$total           = absint($total) > 0 ? absint($total) : 0;
		$attributes      = !empty( $settings['attributes'] ) ? $settings['attributes'] : array();

		// Sanitize
		$settings['class_active']  = sanitize_html_class($settings['class_active']);

		// Attributes
		$attributes['data-post']     = absint($post_id);
		$attributes['data-settings'] = htmlentities( json_encode($settings) );
		$attributes['data-act']      = sanitize_title($this->type);
		$attributes['data-l']        = absint(is_user_logged_in());

		//The title
		$title_format = !empty($settings['title_format']) ? $settings['title_format'] : '';
		if( is_user_logged_in() ){
			$add_title = !empty($settings['title']) ? wp_kses_data( $settings['title'] ) : '';
			$remove_title = !empty($settings['title_remove']) ? wp_kses_data( $settings['title_remove'] ) : '';
			$temp_title = ( $this->userHasMarked($post_id) ) ? $remove_title : $add_title;
			$attributes['title'] = str_replace(array('%text%','%count%'), array($temp_title, $total), $title_format);
			
			$settings['content'] = !empty($settings['content']) ? $settings['content'] : '';
			$settings['content_remove'] = !empty($settings['content_remove']) ? $settings['content_remove'] : $settings['content'];
		}
		else{
			$attributes['title'] = !empty($settings['title_not_logged']) ? $settings['title_not_logged'] : '';
		}

		if( $settings['tag'] == 'a' ){
			$attributes['href'] = '#';
		}
		$settings['attributes'] = $attributes;

		return $settings;
	}

	// Add post ID to user favorites
	public function updateUserMark( $post_id ){
		$previous = get_user_meta( $this->userId, 'smk_marked_posts_'. $this->type, true);
		$previous = (!empty($previous) && is_array($previous)) ? $previous : array();
		
		if( ! in_array($post_id, $previous) ){
			$new = array_merge($previous, (array) $post_id);
			update_user_meta( $this->userId, 'smk_marked_posts_'. $this->type, $new);
		}
	}

	// Remove post ID from user favorites
	public function removeUserMark( $post_id ){
		$previous = get_user_meta( $this->userId, 'smk_marked_posts_'. $this->type, true);
		$previous = (!empty($previous) && is_array($previous)) ? $previous : array();
		if( ($key = array_search($post_id, $previous)) !== false  ){
			unset($previous[$key]);
			update_user_meta( $this->userId, 'smk_marked_posts_'. $this->type, $previous);
		}
	}

	// Add user ID to post favorited by
	public function updateMark( $post_id = false ){
		$previous = get_post_meta( $post_id, 'smk_marked_by_'. $this->type, true);
		$previous = (!empty($previous) && is_array($previous)) ? $previous : array();
		
		if( ! in_array($this->userId, $previous) ){
			$new = array_merge($previous, (array) $this->userId);
			update_post_meta( $post_id, 'smk_marked_by_'. $this->type, $new);
		}
	}

	// Remove user ID from post favorited by
	public function removeMark( $post_id = false ){
		$previous = get_post_meta( $post_id, 'smk_marked_by_'. $this->type, true);
		$previous = (!empty($previous) && is_array($previous)) ? $previous : array();
		if( ($key = array_search($this->userId, $previous)) !== false  ){
			unset($previous[$key]);
			update_post_meta( $post_id, 'smk_marked_by_'. $this->type, $previous);
		}
	}

	// Update favorites count for this post this post
	public function updateMarksCount( $post_id ){
		$all   = get_post_meta( $post_id, 'smk_marked_by_'. $this->type, true);
		$all   = (!empty($all) && is_array($all)) ? $all : array();
		$total = !empty($all) ? count( $all ) : 0;
		update_post_meta( $post_id, 'smk_marks_count_'. $this->type, $total);
	}

	// How many favorited this post
	public function getMarksCount( $post_id ){
		$total = get_post_meta( $post_id, 'smk_marks_count_'. $this->type, true);
		$total = (!empty($total) && absint($total) > 0 ) ? absint($total) : 0;
		return $total;
	}

	// Has the user favorited this post already?
	public function userHasMarked( $post_id ){
		$all = get_post_meta( $post_id, 'smk_marked_by_'. $this->type, true);
		$all = (!empty($all) && is_array($all)) ? $all : array();
		return in_array($this->userId, $all);
	}

	// Get all favorited posts by user
	public function getUserMarks( $user_id = false ){
		if( ! $user_id ){
			$user_id = $this->userId;
		}
		return get_user_meta( $user_id, 'smk_marked_posts_'. $this->type, true);
	}

}