<?php
/**
 * Recipe is featured
 *
 * Check if the recipe is featured or not by ID
 *
 * @param int $post_id The recipe ID 
 * @return bool True if is featured 
 */
function smk_recipe_is_featured( $post_id ){
	$is_featured = get_post_meta( $post_id, 'smk_recipe_is_featured', true );
	return !empty($is_featured) && 'yes' == $is_featured;
}

/**
 * Feature a recipe
 *
 * Make a recipe featured
 *
 * @param int $post_id The recipe ID 
 * @return bool True if is made featured. 
 */
function smk_recipe_do_feature( $post_id ){
	$is_featured = update_post_meta( $post_id, 'smk_recipe_is_featured', 'yes' );
	$feature_time = update_post_meta( $post_id, 'smk_recipe_featured_time', time() );
	if( $feature_time ) return true;
}

/**
 * "Unfeature" a recipe
 *
 * Remove featured label of a recipe
 *
 * @param int $post_id The recipe ID 
 * @return bool True if is not featured anymore 
 */
function smk_recipe_do_not_feature( $post_id ){
	update_post_meta( $post_id, 'smk_recipe_is_featured', 'no' );
	$deleted = update_post_meta( $post_id, 'smk_recipe_featured_time', '0' );
	return $deleted;
}

function smk_make_recipe_featured_ajax_handler(){
	$messages = array();
	
	if( !empty($_POST) ){
		$post_id = !empty($_POST['post_id']) ? $_POST['post_id'] : false;
		if( current_user_can( 'edit_others_posts' ) ){
			if( smk_recipe_is_featured($post_id) ){
				smk_recipe_do_not_feature( $post_id );
				$messages['featured'] = __('Make featured', 'smk_theme');
				$messages['status'] = 'not_featured';
			}
			else{
				smk_recipe_do_feature( $post_id );
				$messages['featured'] = __('Make not featured', 'smk_theme');
				$messages['status'] = 'featured';
			}
		}
	}

	echo json_encode($messages);
	die();
}
add_action('wp_ajax_smk_make_recipe_featured_ajax_handler', 'smk_make_recipe_featured_ajax_handler');


function smk_recipe_feature_recipe_link( $recipe_id = false ){
	if( current_user_can( 'edit_others_posts' ) ){
		$recipe_id = ( $recipe_id ) ? $recipe_id : get_the_ID();
		if( smk_recipe_is_featured($recipe_id) ){
			$text = __('Make not featured', 'smk_theme');
			$class = ' featured';
		}else{
			$text = __('Make featured', 'smk_theme');
			$class = ' not_featured';
		}
		$text  = ( smk_recipe_is_featured($recipe_id) ) ? __('Make not featured', 'smk_theme') : __('Make featured', 'smk_theme');
		return '<a href="#" data-id="' . $recipe_id . '" class="smk-make-recipe-featured'. $class .'">'. $text .'</a>';
	}
}