<?php 
if( !class_exists('Smk_Recipes_Cpt') ){
	class Smk_Recipes_Cpt{

		public $id;
		public $regtax = 'register_taxonomy';
		public $regcpt = 'register_post_type';

		public function __construct( $id ){
			$this->id = $id;
			add_action( 'init', array( $this, 'postType' ) );
			add_action( 'init', array( $this, 'addTagsTax' ) );
			add_action( 'init', array( $this, 'addCategoriesTax' ) );
			add_action( 'init', array( $this, 'addIngredientsTax' ) );
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Register Post type
		 *
		 * Register Custom Post Type
		 * 
		 * @action-hook init
		 * 
		 * @return void 
		 */
		public function postType(){

			// Create The Labels (Output) For The Post Type
			$labels = array(
				'name'               => __('Recipes', 'smk_theme'), 
				'singular_name'      => __('Recipe', 'smk_theme'),
				'add_new'            => _x('Add Recipe', 'portfolio', 'smk_theme'), 
				'edit_item'          => __('Edit Recipe', 'smk_theme'),
				'new_item'           => __('New Recipe', 'smk_theme'), 
				'view_item'          => __('View Recipe', 'smk_theme'),
				'search_items'       => __('Search Recipes', 'smk_theme'), 
				'not_found'          => __('No Recipes Found', 'smk_theme'),
				'not_found_in_trash' => __('No Recipes Found In Trash', 'smk_theme'),
				'parent_item_colon'  => '' 
			);
			
			// Set Up The Arguements
			$args = array(
				'labels'             => $labels, 
				'public'             => true, 
				'has_archive'        => true,
				'publicly_queryable' => true, 
				'show_ui'            => true, 
				'query_var'          => true, 
				'rewrite'            => array(
					'slug' => $this->getSlug('recipes', 'smk_recipes_permalink_slug'),
				),
				'capability_type'    => 'post',
				'menu_icon'          => 'dashicons-book-alt',
				'hierarchical'       => false, 
				'show_in_nav_menus'  => true,
				'menu_position'      => 20, 
				'taxonomies'         => array( 'recipe_tags', 'recipe_categories', 'recipe_ingredients' ),
				'supports'           => array(
					'title',
					'editor',
					'thumbnail',
					'comments',
				),
			);
			
			// Register post type
			$this->regCpt( $args );

		}

		public function addTagsTax(){
			$labels = array(
				'name'                       => _x( 'Recipe Tags', 'Tags general name', 'smk_theme' ),
				'singular_name'              => _x( 'Tag', 'Tags singular name', 'smk_theme' ),
				'search_items'               => __( 'Search Tags', 'smk_theme' ),
				'popular_items'              => __( 'Popular Tags', 'smk_theme' ),
				'all_items'                  => __( 'All Tags', 'smk_theme' ),
				'parent_item'                => null,
				'parent_item_colon'          => null,
				'edit_item'                  => __( 'Edit Tag', 'smk_theme' ),
				'update_item'                => __( 'Update Tag', 'smk_theme' ),
				'add_new_item'               => __( 'Add New Tag', 'smk_theme' ),
				'new_item_name'              => __( 'New Tag Name', 'smk_theme' ),
				'separate_items_with_commas' => __( 'Separate tags with commas', 'smk_theme' ),
				'add_or_remove_items'        => __( 'Add or remove tags', 'smk_theme' ),
				'choose_from_most_used'      => __( 'Choose from the most used tags', 'smk_theme' ),
				'not_found'                  => __( 'No tags found.', 'smk_theme' ),
				'menu_name'                  => __( 'Recipe Tags', 'smk_theme' ),
			);

			$args = array(
				'hierarchical'          => false,
				'labels'                => $labels,
				'show_ui'               => true,
				'show_admin_column'     => true,
				'update_count_callback' => '_update_post_term_count',
				'query_var'             => true,
				'rewrite'               => array( 'slug' => $this->getSlug('recipe-tag', 'smk_recipes_tag_permalink_slug') ),
			);

			$this->regTax( 'recipe_tags', $args );
		}

		public function addCategoriesTax(){
			$labels = array(
				'name'              => _x( 'Recipe Categories', 'Categories general name', 'smk_theme' ),
				'singular_name'     => _x( 'Category', 'Categories singular name', 'smk_theme' ),
				'search_items'      => __( 'Search Categories', 'smk_theme' ),
				'all_items'         => __( 'All Categories', 'smk_theme' ),
				'parent_item'       => __( 'Parent Category', 'smk_theme' ),
				'parent_item_colon' => __( 'Parent Category:', 'smk_theme' ),
				'edit_item'         => __( 'Edit Category', 'smk_theme' ),
				'update_item'       => __( 'Update Category', 'smk_theme' ),
				'add_new_item'      => __( 'Add New Category', 'smk_theme' ),
				'new_item_name'     => __( 'New Category Name', 'smk_theme' ),
				'menu_name'         => __( 'Recipe Categories', 'smk_theme' ),
			);

			$args = array(
				'hierarchical'      => true,
				'labels'            => $labels,
				'show_ui'           => true,
				'show_admin_column' => true,
				'query_var'         => true,
				'rewrite'           => array( 'slug' => $this->getSlug('recipe-category', 'smk_recipes_category_permalink_slug') ),
			);

			$this->regTax( 'recipe_categories', $args );
		}

		public function addIngredientsTax(){
			$labels = array(
				'name'              => _x( 'Ingredients', 'Ingredients general name', 'smk_theme' ),
				'singular_name'     => _x( 'Ingredient', 'Ingredients singular name', 'smk_theme' ),
				'search_items'      => __( 'Search Ingredients', 'smk_theme' ),
				'all_items'         => __( 'All Ingredients', 'smk_theme' ),
				'parent_item'       => __( 'Parent Ingredient', 'smk_theme' ),
				'parent_item_colon' => __( 'Parent Ingredient:', 'smk_theme' ),
				'edit_item'         => __( 'Edit Ingredient', 'smk_theme' ),
				'update_item'       => __( 'Update Ingredient', 'smk_theme' ),
				'add_new_item'      => __( 'Add New Ingredient', 'smk_theme' ),
				'new_item_name'     => __( 'New Ingredient Name', 'smk_theme' ),
				'menu_name'         => __( 'Recipe Ingredients', 'smk_theme' ),
			);

			$args = array(
				'hierarchical'      => true,
				'labels'            => $labels,
				'show_ui'           => false,
				'show_admin_column' => true,
				'query_var'         => true,
				'rewrite'           => array( 'slug' => $this->getSlug('recipe-ingredient', 'smk_recipes_ingredient_permalink_slug') ),
			);

			$this->regTax( 'recipe_ingredients', $args );
		}

		public function getSlug( $slug, $option ){
			$recipes_slug = get_option( $option );
			if( !empty($recipes_slug ) ){
				$recipes_slug = sanitize_title($recipes_slug);
				if( !empty($recipes_slug) ){
					$slug = $recipes_slug;
				}
			}
			return $slug;
		}

		public function regTax( $taxonomy, $args ){
			$fn = $this->regtax;
			$fn( $taxonomy, $this->id, $args );
		}

		public function regCpt( $args ){
			$fn = $this->regcpt;
			$fn( $this->id, $args );
		}

	}
}