<?php
if( ! class_exists('Smk_Recipe_Data') ){
	class Smk_Recipe_Data{

		protected $post_id;

		public function __construct( $post_id = false ){
			$this->post_id = $post_id ? $post_id : get_the_ID();
		}

		//------------------------------------//--------------------------------------//

		/**
		 * Update recipe views number
		 *
		 * Update the views number
		 *
		 * @return bool 
		 */
		public function updateViews(){
			$meta    = get_post_meta( $this->post_id, 'smk_theme_recipe_views', true );
			$prev    = ! empty($meta) ? absint( $meta ) : 0;
			$new     = absint( $prev ) + 1;

			return update_post_meta($this->post_id, 'smk_theme_recipe_views', $new);
		}

		//------------------------------------//--------------------------------------//

		/**
		 * Get recipe views number
		 *
		 * How many times a recipe has been read
		 *
		 * @return int 
		 */
		public function getViews(){
			$meta    = get_post_meta( $this->post_id, 'smk_theme_recipe_views', true );
			return ! empty($meta) ? absint( $meta ) : 0;
		}

		//------------------------------------//--------------------------------------//

		/**
		 * This recipe has categories
		 *
		 * Return `true` if this recipe post has categories
		 *
		 * @return bool 
		 */
		public function hasCategory(){
			$categories = get_the_terms(get_the_ID(), 'recipe_categories');
			return is_array( $categories );
		}

		//------------------------------------//--------------------------------------//

		/**
		 * Get recipe prints number
		 *
		 * How many times a recipe has been printed
		 *
		 * @return int 
		 */
		function getPrintsNumber(){
			$meta    = get_post_meta( $this->post_id, 'smk_theme_recipe_prints_number', true );
			return ! empty($meta) ? absint( $meta ) : 0;
		}

		//------------------------------------//--------------------------------------//

		/**
		 * Update recipe prints number
		 *
		 * Update the prints number
		 *
		 * @return bool 
		 */
		function updatePrintsNumber(){
			$meta    = get_post_meta( $this->post_id, 'smk_theme_recipe_prints_number', true );
			$prev    = ! empty($meta) ? absint( $meta ) : 0;
			$new     = absint( $prev ) + 1;

			return update_post_meta($this->post_id, 'smk_theme_recipe_prints_number', $new);
		}

		function preparationTime(){
			$meta = get_post_meta( $this->post_id, 'smk_recipe_preparation_time', true );
			return ( !empty($meta) && absint( $meta ) > 0 ) ? absint( $meta ) : false;
		}

		function difficulty(){
			$meta = get_post_meta( $this->post_id, 'smk_recipe_difficulty', true );
			return ( !empty($meta) && in_array( $meta, array('easy', 'moderate', 'hard') ) ) ? $meta : false;
		}

		function difficultyName(){
			$difficulty = array(
				'easy' => __('Easy', 'smk_theme'), 
				'moderate' => __('Moderate', 'smk_theme'), 
				'hard' => __('Hard', 'smk_theme'),
			);
			if( $this->difficulty() && array_key_exists( $this->difficulty(), $difficulty ) ){
				return $difficulty[ $this->difficulty() ];
			}
			else{
				return false;
			}
		}

		function ingredients(){
			$meta = get_post_meta( $this->post_id, 'smk_recipe_ingredients', true );
			if( !empty($meta[0]) && is_array($meta[0]) ){
				return $meta[0];
			}
			else{
				return false;
			}
		}

		function ingredientsCount(){
			$ingr = $this->ingredients();
			if( !empty( $ingr ) && is_array( $ingr ) ){
				return count( $ingr );
			}
			else{
				return false;
			}
		}

		function footnotes(){
			$meta = get_post_meta( $this->post_id, 'smk_recipe_footnotes', true );
			return $meta;
		}

		function links(){
			$meta = get_post_meta( $this->post_id, 'smk_recipe_links', true );
			if( !empty($meta[0]) && is_array($meta[0]) ){
				return $meta[0];
			}
			else{
				return false;
			}
		}

	}
}



function smk_recipe_setting( $option, $default = '' ){
	return srps_get_option('smk_recipes_main_settings', $option, $default);
}

function is_smk_recipes(){
	return ( is_post_type_archive( 'smk_recipes' ) || is_singular( 'smk_recipes' ) || is_tax( array('recipe_ingredients', 'recipe_categories', 'recipe_tags') ) );
}

function smk_recipes_page_title(){
	if( is_post_type_archive( 'smk_recipes' ) ){
		$the_title = get_queried_object()->labels->name;
	}
	elseif(is_tax()){
		$term = get_term_by('slug', get_query_var('term'), get_query_var('taxonomy'));
		$label = '';
		if( is_tax('recipe_ingredients') ){
			$label = _x('Ingredient:', 'Search filter label', 'smk_theme');
		}
		elseif( is_tax('recipe_categories') ){
			$label = _x('Category:', 'Search filter label', 'smk_theme');
		}
		elseif( is_tax('recipe_tags') ){
			$label = _x('Tag:', 'Search filter label', 'smk_theme');
		}

		if ($term) {
			$the_title = $label .' '. $term->name;
		} 
	}
	else{
		$the_title = get_the_title();
	}
	return $the_title;
}


//------------------------------------//--------------------------------------//
		
/**
 * Get total number of published recipes
 *
 * Get total number of published recipes.
 * Uses cache and it will expire in 3 hours.
 *
 * @return int 
 */
function smk_get_total_recipes(){
	if ( false === ( $smk_get_total_recipes = get_transient( 'smk_get_total_recipes' ) ) ) {
		$smk_get_total_recipes = wp_count_posts( 'smk_recipes' )->publish;
		set_transient( 'smk_get_total_recipes', $smk_get_total_recipes, 3 * HOUR_IN_SECONDS);
	}
	return $smk_get_total_recipes;
}

function smk_recipes_link(){
	return get_post_type_archive_link( 'smk_recipes' );
}

function smk_get_recipe_category_url( $category_slug = false ){
	$link = get_post_type_archive_link( 'smk_recipes' );
	if( !empty($category_slug) ){
		$term_link = get_term_link( $category_slug, 'recipe_categories' );
		if ( ! is_wp_error( $term_link ) ) {
			$link = $term_link;
		}
	}
	return esc_url( $link );
}

function smk_get_recipe_category_link( $category_slug = false ){
	$link = smk_get_recipe_category_url( $category_slug );
	$obj  = get_term_by('slug', $category_slug, 'recipe_categories');

	return '<a href="'. $link .'" itemprop="recipeCategory">'. $obj->name .'</a>';
}

function smk_get_recipe_tag_url( $tag_slug = false ){
	$link = get_post_type_archive_link( 'smk_recipes' );
	if( !empty($tag_slug) ){
		$term_link = get_term_link( $tag_slug, 'recipe_tags' );
		if ( ! is_wp_error( $term_link ) ) {
			$link = $term_link;
		}
	}
	return esc_url( $link );
}

function smk_get_recipe_tag_link( $tag_slug = false ){
	$link = smk_get_recipe_tag_url( $tag_slug );
	$obj  = get_term_by('slug', $tag_slug, 'recipe_tags');

	return '<a href="'. $link .'">'. $obj->name .'</a>';
}

function smk_user_can_edit_recipe( $post_id ){
	$post_author_id = get_post_field( 'post_author', $post_id );
	$current_user   = Smk_Theme_User::currentUser();
	return ( ( $post_author_id && ($current_user->ID == $post_author_id) ) || current_user_can( 'edit_post', $post_id ) );
}

function smk_recipe_exists( $post_id ) {
	return is_string( get_post_status( $post_id ) ) && ( get_post_type( $post_id ) == 'smk_recipes' );
}

function smk_recipe_is_pending( $post_id = false ){
	$post_id = ( $post_id ) ? $post_id : get_the_ID();
	$post_status = ( get_post_status ( $post_id ) == 'pending' );
	return ($post_status) ? '<div class="text-red"><strong>'. __('This recipe is awaiting moderation!', 'smk_theme') .'</strong></div>' : '';
}

function smk_recipe_submit_url(){
	$page_id = absint( smk_recipe_setting( 'submit_recipe_page' ) );
	if( $page_id > 0 ){
		return get_permalink( $page_id );
	}
	else{
		return false;
	}
}

function smk_recipe_edit_url( $recipe_id = false ){
	$recipe_id = ( $recipe_id ) ? $recipe_id : get_the_ID();
	if( $recipe_id > 0 ){
		$the_link = get_permalink( $recipe_id );
		return esc_url( add_query_arg( 'edit', $recipe_id, $the_link ) ); // $recipe_id is not required. It can be anything else instead
	}
	else{
		return false;
	}
}

function smk_recipe_edit_link( $recipe_id = false, $text = false ){
	$recipe_id = ( $recipe_id ) ? $recipe_id : get_the_ID();
	$text      = ( $text ) ? $text : __('Edit', 'smk_theme');
	return '<a href="'. smk_recipe_edit_url( $recipe_id ) .'" data-id="' . $recipe_id . '" class="smk-edit-recipe edit">'. $text .'</a>';
}

function smk_recipe_remove_link( $recipe_id = false, $text = false ){
	$recipe_id = ( $recipe_id ) ? $recipe_id : get_the_ID();
	$text      = ( $text ) ? $text : __('Remove', 'smk_theme');
	return '<a href="#" data-id="' . $recipe_id . '" class="smk-remove-recipe remove">'. $text .'</a>';
}

function smk_recipe_approve_unapprove_link( $recipe_id = false ){
	$recipe_id = ( $recipe_id ) ? $recipe_id : get_the_ID();
	$post_status = get_post_status( $recipe_id );
	
	if( $post_status == 'publish' ){
		$class = ' unapprove';
		$text  =  __('Unapprove', 'smk_theme');
	}
	else{
		$class = ' approve';
		$text  =  __('Publish', 'smk_theme');
	}
	if( current_user_can( 'edit_others_posts' ) ){
		return '<a href="#" data-id="' . $recipe_id . '" class="smk-approve-unapprove-recipe'. $class .'">'. $text .'</a>';
	}
	else{
		return false;
	}
}

function smk_manage_recipe( $recipe_id = false, $text = false, $position = '' ){
	$recipe_id = ( $recipe_id ) ? $recipe_id : get_the_ID();

	$position = ( in_array( $position, array('left', 'right') ) ) ? ' to-'. $position : '';
	$text     = ( !empty($text) ) ? $text : __('Manage recipe', 'smk_theme');

	$output = '';
	$output .= '<div class="smk-manage-recipe'. $position .'"><span class="manage-recipe-handler">'. $text .'</span>';
		$output .= '<div class="manage-links">';
			if( get_post_status() !== 'pending' || current_user_can( 'edit_post', $recipe_id ) ){
				$output .= smk_recipe_edit_link( $recipe_id );
			}
			$output .= smk_recipe_feature_recipe_link( $recipe_id );
			$output .= smk_recipe_approve_unapprove_link( $recipe_id );
			$output .= smk_recipe_remove_link( $recipe_id );
		$output .= '</div>';
	$output .= '</div>';
	
	if( is_user_logged_in() && smk_user_can_edit_recipe( $recipe_id ) && !is_edit_recipe() )
		return $output;
}

function smk_recipe_submission_enabled(){
	$submission = smk_recipe_setting( 'recipe_submission_enabled' );
	if( $submission == 'on' ){
		return true;
	}
	else{
		return false;
	}
}

function smk_ingredient_measurements(){
	$defaults = array(
		'Cups',
		'Teaspoons',
		'Tablespoons',
		'Liters',
		'Milliliters',
		'Grams',
		'Kilograms',
		'Ounces',
		'Pints',
		'Quarts',
		'Gallons',
	);

	$new = '';

	$from_panel = smk_recipe_setting( 'recipe_measurements' );
	$from_panel = !empty($from_panel) ? array_map('trim', explode(',', $from_panel) ) : array();
	$new        = ( count( $from_panel ) > 0 ) ? $from_panel : $defaults;
	$final      = array();

	$final[] = '';
	foreach ($new as $value) {
		$final[$value] = $value;
	}
	return $final;
}

function smk_get_required_fields(){
	return smk_recipe_setting( 'recipe_submission_required_fields' );
}

/**
 * Check if is currently editing a recipe
 *
 * @return bool `True` if the recipe is being edited.
 **/
function is_edit_recipe(){
	return ( is_singular( 'smk_recipes' ) && isset($_GET['edit']) );
}

function is_recipe_image_required(){
	$rf = smk_get_required_fields();
	// if(  )
}

function smk_recipe_ratings_enabled(){
	$on = smk_recipe_setting( 'ui_enable_ratings', 'on' );
	return ( 'on' == $on );
}

function smk_recipe_has_ratings(){
	$r = get_post_meta( get_the_ID(), 'smk_recipe_full_rating', true );
	return !empty($r);
}

function can_show_recipe_rating(){
	return ( smk_recipe_ratings_enabled() && smk_recipe_has_ratings() );
}