<?php
if( ! class_exists('Smk_Recipes_Rating') ){
	class Smk_Recipes_Rating{
		public $fieldId = 'recipe_rating';

		public function init(){
			add_action( 'comment_post', array($this, 'addMeta'), 10, 2 );
			add_action( 'comment_unapproved_to_approved', array($this, 'addPostMeta') );
		}
		
		public function addMeta( $comment_id, $comment_approved ) {
			$rating = !empty($_POST[ $this->fieldId ]) ? absint( $_POST[ $this->fieldId ] ) : 0;
			$rating = ( $rating > 0 && $rating < 6 ) ? $rating : false;
			if( !empty($rating) ){

				$comment_obj    = get_comment( $comment_id );
				$post_id        = $comment_obj->comment_post_ID;
				$user_id        = $comment_obj->user_id;
				$comment_parent = $comment_obj->comment_parent;
				
				$who_rated      = get_post_meta($post_id, 'smk_who_rated_the_recipe', true);
				$who_rated      = ! is_array($who_rated) ? array() :  $who_rated;

				if( !in_array($user_id, $who_rated) && absint($comment_parent) <= 0 ){
					add_comment_meta( $comment_id, $this->fieldId, $rating, true );
					$this->updateWhoRated($post_id, $who_rated, $user_id);
					if( 1 === $comment_approved ){
						$this->updateStars($post_id, $rating);
						$this->updatePostRating($post_id);
					}
				}

			}
		}

		public function addPostMeta( $comment_obj ) {
			$rating  = get_comment_meta( $comment_obj->comment_ID, $this->fieldId, true );
			$rating  = ( $rating > 0 && $rating < 6 ) ? $rating : false;
			$post_id = $comment_obj->comment_post_ID;
			
			if( !empty($rating) ){
				$this->updateStars($post_id, $rating);
				$this->updatePostRating($post_id);
			}
		}

		public function updateWhoRated($post_id, $who_rated, $user_id){
			$who_rated[ $user_id ] = $user_id;
			update_post_meta($post_id, 'smk_who_rated_the_recipe', $who_rated);
		}
		
		public function updateStars($post_id, $rating){
			$key = 'smk_recipe_rating_'. $rating. '_stars';
			$total_ratings = get_post_meta($post_id, $key, true);
			update_post_meta($post_id, $key, absint($total_ratings) + 1);
		}

		public function totalRatings(){
			$r1 = absint( get_post_meta(get_the_ID(), 'smk_recipe_rating_1_stars', true) );
			$r2 = absint( get_post_meta(get_the_ID(), 'smk_recipe_rating_2_stars', true) );
			$r3 = absint( get_post_meta(get_the_ID(), 'smk_recipe_rating_3_stars', true) );
			$r4 = absint( get_post_meta(get_the_ID(), 'smk_recipe_rating_4_stars', true) );
			$r5 = absint( get_post_meta(get_the_ID(), 'smk_recipe_rating_5_stars', true) );

			return $r1+$r2+$r3+$r4+$r5;
		}
		
		public function updatePostRating($post_id){
			$r1 = absint( get_post_meta($post_id, 'smk_recipe_rating_1_stars', true) );
			$r2 = absint( get_post_meta($post_id, 'smk_recipe_rating_2_stars', true) );
			$r3 = absint( get_post_meta($post_id, 'smk_recipe_rating_3_stars', true) );
			$r4 = absint( get_post_meta($post_id, 'smk_recipe_rating_4_stars', true) );
			$r5 = absint( get_post_meta($post_id, 'smk_recipe_rating_5_stars', true) );

			$total_ratings = $r1+$r2+$r3+$r4+$r5;
			$total_ratings_points = $r1*1+$r2*2+$r3*3+$r4*4+$r5*5;
			$result = round( $total_ratings_points/$total_ratings, 2);

			update_post_meta($post_id, 'smk_recipe_full_rating', $result);
		}
				
		public function field(){
			if( ! is_smk_recipes() ) 
				return;

			if( ! is_user_logged_in() ) 
				return;

			if( ! smk_recipe_ratings_enabled() )
				return;

			return '<div class="grid-container comment-rating-block">
				<div class="grid desk-12 both">
					<div class="form-label">'. __('Rating', 'smk_theme') .'</div>
					'. $this->getStarsForRating() .'
				</div>
			</div>
			<div class="clear"></div>';
		}

		public function getCommentRating(){
			$rating = get_comment_meta(get_comment_ID(), $this->fieldId, true);
			$rating = ( !empty($rating) && absint($rating) > 0 && absint($rating) <= 5 ) ? absint( $rating ) : 0;
			return $rating;
		}

		public function getPostRating(){
			$rating = get_post_meta(get_the_ID(), 'smk_recipe_full_rating', true);
			$rating = ( !empty($rating) && $rating > 0 && $rating <= 5 ) ? $rating : 0;
			return $rating;
		}

		public function getStarsHtml($rating){
			if( $rating > 0 ){
				$stars = '';
				for ($i = 1; $i < 6; $i++) { 
					$css_class = ( $i <= $rating ) ? ' fa-star' : ' fa-star-o';
					if( $rating > ($i-0.75) && $rating < ($i-0.25) ){
						$css_class = ' fa-star-half-o';
					}

					$stars .= '<i class="fa'. $css_class .'"></i>';
				}
				return $stars;
			}
		}

		public function getStars(){
			$rating = $this->getCommentRating();
			if( $rating > 0 ){
				$stars = $this->getStarsHtml($rating);
				return '<div class="comment-rating-result" title="'. $rating .'">'. $stars .'</div>';
			}
		}

		public function getPostStars(){
			$rating = $this->getPostRating();
			if( $rating > 0 ){
				$stars = $this->getStarsHtml($rating);
				return '<div class="post-rating-result" title="'. $rating .'" itemprop="aggregateRating" itemscope itemtype="http://schema.org/AggregateRating">'. $stars .'
					<meta itemprop="ratingValue" content="'. $rating .'" />
					<meta itemprop="reviewCount" content="'. $this->totalRatings() .'" />
				</div>';
			}
		}

		public function getStarsForRating(){
			$stars = '';
			for ($i = 1; $i < 6; $i++) { 
				$stars .= '<i class="fa fa-star-o" data-order="'. $i .'"></i>';
			}
			return '<div class="comment-form-rating-field">'. $stars .'<span class="clear-rating" style="display: none;">'. __('Cancel rating', 'smk_theme') .'</span><input name="'. $this->fieldId .'" type="hidden" value="0" /></div>';
		}

	}
}
$rating = new Smk_Recipes_Rating;
$rating->init();