<?php
function smk_recipes_search( $compact = false ){

	/* Enabled fields, set from admin panel
	------------------------------------------------*/
	$enabled = smk_recipe_setting( 'recipe_submission_enabled_fields', array() );
	if( !is_array($enabled) ){
		$enabled = array();
	}
	$e_featured_image = in_array('featured_image', $enabled);
	$e_ingredients    = in_array('ingredients', $enabled);
	$e_prep_mode      = in_array('prep_mode', $enabled);
	$e_tags           = in_array('tags', $enabled);
	$e_difficulty     = in_array('difficulty', $enabled);
	$e_prep_time      = in_array('prep_time', $enabled);
	$e_footnotes      = in_array('footnotes', $enabled);
	$e_links          = in_array('links', $enabled);

	$output = '';
	$output .= '<div class="smk-recipes-search clearfix">';
		$output .= '<form name="smk-recipes-search" method="get" action="'. smk_recipes_link() .'">';

			/* Search keyword
			------------------------------------------------*/
			$output .= smk_recipes_search_field( 'text', 'search_', array(
				'label' => __('Search keyword', 'smk_theme'),
			) );

			/* Category
			------------------------------------------------*/
			$categories = smk_recipes_search_all_categories();
			$output .= smk_recipes_search_field( 'select', 'category_', array(
				'label' => __('Category', 'smk_theme'),
				'empty_option_label' => __(' - Any category - ', 'smk_theme'),
				'options' => $categories,
			) );

			/* Ingredient
			------------------------------------------------*/
			if( $e_ingredients ) {
				$ingredients = get_terms('recipe_ingredients');
				$select_ingredients     = array();
				if( !empty($ingredients) ){ 
					foreach ( $ingredients as $cat ) {
						$select_ingredients[$cat->slug] = $cat->name;
					}
				}
				$output .= smk_recipes_search_field( 'select', 'ingredient_', array(
					'label' => __('Ingredient', 'smk_theme'),
					'empty_option_label' => __(' - Any ingredient - ', 'smk_theme'),
					'options' => $select_ingredients,
				) );
			}

			/* Difficulty
			------------------------------------------------*/
			if($e_difficulty){
				$output .= smk_recipes_search_field( 'select', 'difficulty_', array(
					'label' => __('Difficulty', 'smk_theme'),
					'empty_option_label' => __(' - Any difficulty - ', 'smk_theme'),
					'options' => array(
						'easy' => __('Easy', 'smk_theme'), 
						'moderate' => __('Moderate', 'smk_theme'), 
						'hard' => __('Hard', 'smk_theme')
					),
				) );
			}

			/* Tags
			------------------------------------------------*/
			if( $e_tags ){
				$output .= smk_recipes_search_field( 'text', 'tags_', array(
					'label' => __('Prefered tags', 'smk_theme'),
					'description' => __('Enter one or more tags, separated by a comma(,)', 'smk_theme')
				) );
			}

			/* Submitted
			------------------------------------------------*/
			$output .= smk_recipes_search_field( 'select', 'submitted_', array(
				'label' => __('Submitted', 'smk_theme'),
				'empty_option_label' => __(' - Any date - ', 'smk_theme'),
				'options' => array(
					'last_year' => __('In the last year', 'smk_theme'),
					'last_6_months' => __('In the last 6 months', 'smk_theme'),
					'last_3_months' => __('In the last 3 months', 'smk_theme'),
					'last_month' => __('In the last month', 'smk_theme'),
					'last_week' => __('In the last week', 'smk_theme'),
					'last_day' => __('In the last day', 'smk_theme'),
				),
			) );

			/* Other
			------------------------------------------------*/
			$output .= smk_recipes_search_field( 'checkboxes', 'other_settings', array(
				'label' => __('Other', 'smk_theme'),
				'options' => array(
					'only_with_photo_' => __('Show recipes only with photo', 'smk_theme'),
					'only_featured_' => __('Show only featured recipes', 'smk_theme'),
					'only_most_favorited_' => __('Show only most favorited recipes', 'smk_theme'),
					'only_most_liked_' => __('Show only most liked recipes', 'smk_theme'),
					'only_most_viewed_' => __('Show only most viewed recipes', 'smk_theme'),
				),
			) );

			/* Prep time
			------------------------------------------------*/
			if( $e_prep_time ){
				$output .= smk_recipes_search_field( 'range_val', 'prep_time_', array(
					'label' => __('Preparation time', 'smk_theme'),
					'rv_text_after' => __('minutes', 'smk_theme'),
				) );
			}

			/* Sort by
			------------------------------------------------*/
			// $output .= smk_recipes_search_field( 'select', 'sort_by_', array(
			// 	'label' => __('Sort by', 'smk_theme'),
			// 	'options' => array(
			// 		'date' => _x('Date', 'Sort by Date', 'smk_theme'), 
			// 		'favorites_count' => __('Favorites count', 'smk_theme'), 
			// 		'likes_count' => __('Likes count', 'smk_theme'),
			// 		'comment_count' => __('Comments count', 'smk_theme'),
			// 		'modified' => __('Last modified date', 'smk_theme'),
			// 	),
			// 	'hide_empty' => true,
			// 	'grid' => 3
			// ) );

			/* Per page
			------------------------------------------------*/
			$output .= smk_recipes_search_field( 'hidden', 'per_page_' );

			/* View
			------------------------------------------------*/
			$output .= smk_recipes_search_field( 'hidden', 'view' );


			$output .= smk_recipes_search_field( 'button', '&nbsp;', array(
				'button_title' => __('Search', 'smk_theme'),
			) );
		$output .= '</form>';
	$output .= '</div>';

	return $output;
}

function smk_recipes_search_field( $type, $name, $settings = array() ){
	$default_settings = array(
		'label' => $name,
		'button_title' => '',
		'checkbox_label' => '',
		'description' => '',
		'rv_text_before' => __('Between', 'smk_theme'),
		'rv_text_mid' => _x('and', 'Range: Bewtween x `and` y', 'smk_theme'),
		'rv_text_after' => '',
		'input_size' => false,
	);
	$settings = wp_parse_args( $settings, $default_settings );
	$value    = ( !empty($name) && isset( $_GET[ $name ] ) ) ? $_GET[ $name ] : '';

	// If there are no options for the select tag, do not show it.
	if( in_array( $type, array('select', 'checkboxes') ) && ( empty($settings['options']) || ! is_array($settings['options']) ) )
		return;

	// If all is ok, build the field
	$output = '<div class="smk-recipes-search-row">';
		
		$output .= '<div class="r-search-label">';
			if( !empty($settings['label']) ){
				$output .= $settings['label'];
			}
		$output .= '</div>'; //.r-search-label
		
		$output .= '<div class="r-search-field">';
			switch ( $type ) {
				case 'button':
					$output .= '<button class="button primary form-size">'. $settings['button_title'] .'</button>';
					break;
				
				case 'select':
					$output .= '<select name="'. $name .'" class="smk-field smk-field-'. $name .'">';
						// if this setting is set hide the first empty option
						if( empty($settings['hide_empty']) ){
							$select_empty_option_label = ! empty($settings['empty_option_label']) ? $settings['empty_option_label'] : ' --- ';
							$output .= '<option value=""'. selected( '', $value, false).'>'. $select_empty_option_label .'</option>';
						}
						// Echo all options
						foreach ($settings['options'] as $sval => $stitle) {
							$output .= '<option value="'. $sval .'"'. selected( $sval, $value, false).'>'. $stitle .'</option>';
						}
					$output .= '</select>';

					break;
				
				case 'checkbox':
						$output .= '<label><input type="checkbox" name="'. $name .'" value="1" class="smk-field smk-field-'. $name .'" '. checked( 1, $value, false ) .'>'. $settings['checkbox_label'] .'</label>';
					break;

				case 'checkboxes':
					foreach ($settings['options'] as $cval => $clabel) {
						$c_saved_value    = ( !empty($cval) && isset( $_GET[ $cval ] ) ) ? $_GET[ $cval ] : '';
						$output .= '<label><input type="checkbox" name="'. $cval .'" value="1" class="smk-field smk-field-'. $cval .'" '. checked( 1, $c_saved_value, false ) .'>'. $clabel .'</label>';
					}
					break;

				case 'radio':
					foreach ($settings['options'] as $cval => $clabel) {
						$c_saved_value    = ( !empty($cval) && isset( $_GET[ $cval ] ) ) ? $_GET[ $cval ] : '';
						$output .= '<label><input type="radio" name="'. $cval .'" value="1" class="smk-field smk-field-'. $cval .'" '. checked( 1, $c_saved_value, false ) .'>'. $clabel .'</label>';
					}
					break;

				case 'range_val':
						$value_min    = ( !empty($_GET[ $name .'_min' ]) ) ? $_GET[ $name .'_min' ] : '';
						$value_max    = ( !empty($_GET[ $name .'_max' ]) ) ? $_GET[ $name .'_max' ] : '';
						$output .= $settings['rv_text_before'] . ' ';
						$output .= '<input type="number" name="'. $name .'_min" value="'. $value_min .'" class="smk-field smk-field-'. $name .' minimal-size">';
						$output .= ' '. $settings['rv_text_mid'] . ' ';
						$output .= '<input type="number" name="'. $name .'_max" value="'. $value_max .'" class="smk-field smk-field-'. $name .' minimal-size">';
						$output .= ' '. $settings['rv_text_after'];
					break;

				default:
						$fullwidth = $settings['input_size'] ? $settings['input_size'] : 'fullwidth';
						$output .= '<input type="'. $type .'" name="'. $name .'" value="'. $value .'" class="smk-field smk-field-'. $name .' '. $fullwidth .'">';
					break;
			}
			if( !empty($settings['description']) ){
				$output .= '<div class="description">'. $settings['description'] .'</div>';
			}
		$output .= '</div>'; //.r-search-field

	$output .= '</div>';

	// Hidden text field
	if( 'hidden' == $type ){
		$output = '<input type="hidden" name="'. $name .'" value="'. $value .'" style="display: none;">';
	}

	return $output;
}


//------------------------------------//--------------------------------------//

/**
 * Get all possible categories
 *
 * Get all possible categories
 * 
 * @return array 
 */
function smk_recipes_search_all_categories( $args = array() ){
	$categories = get_terms('recipe_categories', $args);
	$output     = array();
	if( !empty($categories) ){ 
		foreach ( $categories as $cat ) {
			$output[$cat->slug] = $cat->name;
		}
	}
	return $output;
}


function smk_recipes_query(){
	$recipes_page = smk_theme_current_pag();
	$query = array (
		'post_type'      => 'smk_recipes',
		'posts_per_page' => smk_recipes_filter_per_page(),
		'paged'          => $recipes_page,
	);

	/* Search keyword
	------------------------------------------------*/
	$the_keyword = !empty($_GET['search_']) ? esc_html($_GET['search_']) : '';
	if( !empty($the_keyword) ){
		$query['s'] = $the_keyword;
	}

	/* Category
	------------------------------------------------*/
	$all_categories = smk_recipes_search_all_categories();
	$the_category = !empty($_GET['category_']) && array_key_exists($_GET['category_'], $all_categories) ? (array) esc_html( $_GET['category_'] ) : '';
	if( !empty($the_category) || is_tax( 'recipe_categories' ) ){
		if( is_tax( 'recipe_categories' ) ){
			$the_category = get_queried_object()->slug;
		}

		$query['tax_query'][] = array(
			'taxonomy' => 'recipe_categories',
			'field'    => 'slug',
			'terms'    => $the_category,
		);
	}

	/* Ingredient
	------------------------------------------------*/
	$the_ingredient = !empty($_GET['ingredient_']) ? (array) esc_html( $_GET['ingredient_'] ) : '';
	if( !empty($the_ingredient) || is_tax( 'recipe_ingredients' ) ){
		if( is_tax( 'recipe_ingredients' ) ){
			$the_ingredient = get_queried_object()->slug;
		}
		
		$query['tax_query'][] = array(
			'taxonomy' => 'recipe_ingredients',
			'field'    => 'slug',
			'terms'    => $the_ingredient,
		);
	}

	/* Tags
	------------------------------------------------*/
	$tags = !empty($_GET['tags_']) ? esc_html( $_GET['tags_'] ) : '';
	if( !empty($tags) || is_tax( 'recipe_tags' ) ){
		if( is_tax( 'recipe_tags' ) ){
			$tags = (array) get_queried_object()->slug;
		}
		else{
			$tags = str_replace('+', ' ', $tags );
			$tags = explode(',', $tags);
		}
		if( is_array($tags) ){
			$tags = array_map('sanitize_title', $tags);
			$query['tax_query'][] = array(
				'taxonomy' => 'recipe_tags',
				'field'    => 'slug',
				'terms'    => $tags,
			);
		}
	}

	/* Difficulty
	------------------------------------------------*/
	$difficulty = !empty($_GET['difficulty_']) ? esc_html( $_GET['difficulty_'] ) : '';
	if( !empty($difficulty) ){
		$query['meta_query'][] = array( 
			'key' => 'smk_recipe_difficulty',
			'value' => $difficulty
		);
	}

	/* Only with photo
	------------------------------------------------*/
	$only_with_photo = !empty($_GET['only_with_photo_']) ? (int) $_GET['only_with_photo_'] : '';
	if( !empty($only_with_photo) && 1 == $only_with_photo ){
		$query['meta_query'][] = array( 
			'key' => '_thumbnail_id',
			'compare' => 'EXISTS'
		);
	}

	/* Only featured
	------------------------------------------------*/
	$only_featured = !empty($_GET['only_featured_']) ? (int) $_GET['only_featured_'] : '';
	if( !empty($only_featured) && 1 == $only_featured ){
		$query['meta_query'][] = array( 
			'key' => 'smk_recipe_is_featured',
			'value' => 'yes'
		);
	}

	/* Only most favorited
	------------------------------------------------*/
	$only_most_favorited = !empty($_GET['only_most_favorited_']) ? (int) $_GET['only_most_favorited_'] : '';
	if( !empty($only_most_favorited) && 1 == $only_most_favorited ){
		$query['meta_query'][] = array( 
			'key' => 'smk_marks_count_favorite',
			'value' => '0',
			'compare' => '>',
			'type' => 'NUMERIC',
		);
		$query['orderby']  = 'meta_value_num';
		$query['meta_key'] = 'smk_marks_count_favorite';
	}

	/* Only most liked
	------------------------------------------------*/
	$only_most_liked = !empty($_GET['only_most_liked_']) ? (int) $_GET['only_most_liked_'] : '';
	if( !empty($only_most_liked) && 1 == $only_most_liked ){
		$query['meta_query'][] = array( 
			'key' => 'smk_marks_count_like',
			'value' => '0',
			'compare' => '>',
			'type' => 'NUMERIC',
		);
		if( empty($query['meta_key']) ){
			$query['orderby']  = 'meta_value_num';
			$query['meta_key'] = 'smk_marks_count_like';
		}
	}

	/* Only most viewed
	------------------------------------------------*/
	$only_most_viewed = !empty($_GET['only_most_viewed_']) ? (int) $_GET['only_most_viewed_'] : '';
	if( !empty($only_most_viewed) && 1 == $only_most_viewed ){
		$query['meta_query'][] = array( 
			'key' => 'smk_theme_recipe_views',
			'value' => '0',
			'compare' => '>',
			'type' => 'NUMERIC',
		);
		if( empty($query['meta_key']) ){
			$query['orderby']  = 'meta_value_num';
			$query['meta_key'] = 'smk_theme_recipe_views';
		}
	}

	/* Date
	------------------------------------------------*/
	$submitted = !empty($_GET['submitted_']) && in_array($_GET['submitted_'], array('last_year','last_6_months','last_3_months','last_month','last_week','last_day')) ? esc_html( $_GET['submitted_'] ) : '';
	$dates_query = array(
		'last_year' => '1 year ago',
		'last_6_months' => '6 months ago',
		'last_3_months' => '3 months ago',
		'last_month' => '1 month ago',
		'last_week' => '1 week ago',
		'last_day' => '1 day ago',
	);
	if( !empty($submitted) ){
		$query['date_query'][] = array(
			'after'     => $dates_query[ $submitted ],
			'before'    => 'now',
			'inclusive' => true,
		);
	}

	/* Preparation time
	------------------------------------------------*/
	$prep_time__min = !empty($_GET['prep_time__min']) && (int) $_GET['prep_time__min'] >= 0 ? (int) $_GET['prep_time__min'] : '';
	$prep_time__max = !empty($_GET['prep_time__max']) && (int) $_GET['prep_time__max'] > 0 ? (int) $_GET['prep_time__max'] : '';
	if( !empty($prep_time__min) || !empty($prep_time__max) ){
		$prep_time__min = $prep_time__min >= 0 ? $prep_time__min : 0;
		$prep_time__max = $prep_time__max > 0 ? $prep_time__max : 999;
		if( $prep_time__min > $prep_time__max ){
			$prep_time__max = 999;
		}
		$query['meta_query'][] = array( 
			'key' => 'smk_recipe_preparation_time',
			'value' => array($prep_time__min, $prep_time__max),
			'compare' => 'BETWEEN',
			'type' => 'NUMERIC',
		);
	}



	/* Sort by NOT WORKING PROPERLY. Posts with the non existent key are not included
	------------------------------------------------*/
	// $sort_by = !empty($_GET['sort_by_']) ? $_GET['sort_by_'] : '';
	// switch ($sort_by) {
	// 	case 'favorites_count':
	// 		$query['meta_query']['relation'] = 'OR';
	// 		$query['meta_query'][] = array( 
	// 			'key' => 'smk_marks_count_favorite',
	// 			'value' => '0',
	// 			'compare' => '>='
	// 		);
	// 		$query['meta_query'][] = array( 
	// 			'key' => 'smk_marks_count_favorite',
	// 			'compare' => 'NOT EXISTS',
	// 			// 'value' => 'something here',
	// 		);
	// 		$query['orderby']  = 'meta_value_num';
	// 		$query['meta_key'] = 'smk_marks_count_favorite';
	// 		break;
		
	// 	case 'likes_count':
	// 		$query['orderby']  = 'meta_value_num title';
	// 		$query['meta_key'] = 'smk_marks_count_like';
	// 		break;
		
	// 	default:
	// 		$sort_by = ( in_array($sort_by, array( 'date', 'modified', 'rand', 'comment_count' )) ) ? $sort_by : 'date';
	// 		$query['orderby']  = $sort_by;
	// 		$query['meta_key'] = false;
	// 		break;
	// }

	/* Include tags AND categories
	------------------------------------------------*/
	if( !empty($query['tax_query']) && count($query['tax_query']) > 1 ){
		$query['tax_query']['relation'] = 'AND';
	}

	// If is admin show pending and private and publish
	$show_unapproved = smk_recipe_setting( 'admin_list_unapproved_recipes', 'on' );
	if( current_user_can('edit_others_posts') && 'on' == $show_unapproved ){
		$query['post_status'] = array( 'pending', 'publish', 'private' );
	}

	// Following feed
	if( !empty( $_GET['following_feed_']) && is_user_logged_in() ) {
		$current_user = Smk_Theme_User::currentUser();
		if( is_object($current_user) ){
			$current_user_id = $current_user->ID;
			$following_users_ids = (array) get_user_meta($current_user_id, 'st_following', true);
			$query['author__in'] = !empty($following_users_ids) ? $following_users_ids : 999999999999; // Fake auhor ID if the user has no followers.
		}
		
	}

	return new WP_Query($query);
}

function smk_get_recipes_search_url(){
	$recipe_search_page_id = smk_recipe_setting( 'recipe_search_page' );
	$search_url            = get_permalink($recipe_search_page_id);
	return $search_url;
}

/*
-------------------------------------------------------------------------------
The search filter
-------------------------------------------------------------------------------
*/
function smk_get_search_filter(){
	$recipe_search_page_id = smk_recipe_setting( 'recipe_search_page' );
	$active_filter         = ( isset( $_GET['search_'] ) ) ? ' active' : '';
	$current_query_args    = $_SERVER['QUERY_STRING'];
	$search_url            = get_permalink($recipe_search_page_id);
	$query_sep             = ( strrpos('?', $search_url) === false ) ? '?' : '&amp;';
	$query_sep             = ( !empty($current_query_args) ) ? $query_sep : '';

	if( is_tax( array('recipe_categories', 'recipe_tags', 'recipe_ingredients') ) ){
		$slug_ = get_queried_object()->slug;
		$param = false;
		if( is_tax( 'recipe_categories' ) ){
			$param = 'category_';
		}
		elseif( is_tax( 'recipe_tags' ) ){
			$param = 'tags_';
		}
		elseif( is_tax( 'recipe_ingredients' ) ){
			$param = 'ingredient_';
		}
		$refine_url = esc_url( add_query_arg( array( $param => $slug_ ), $search_url ) );
	}
	else{
		$refine_url = $search_url . $query_sep . $current_query_args;
	}

	$output = '';

	if( !empty( $recipe_search_page_id ) && 'on' == smk_recipe_setting( 'ui_enable_filter', 'on' ) ) {
		$output .= '<a href="'. esc_url($refine_url) .'" class="filter-recipes-pointer'. $active_filter .'">'. __('Refine search', 'smk_theme') .'</a>';
	}

	// Following feed
	if( !empty( $_GET['following_feed_']) && is_user_logged_in() ) {
		$output .= '<a href="'. smk_remove_query_arg( array( 'following_feed_' ) ) .'" class="filter-recipes-key following_filter_key">'. __('Following', 'smk_theme') .' <i class="filter-close-icon fa fa-close"></i></a>';		
	}

	// Search keyword
	if( !empty( $_GET['search_']) ) {
		$search_ = esc_html( $_GET['search_'] );
		$output .= '<a href="'. smk_remove_query_arg( array( 'search_', 'pag' ) ) .'" class="filter-recipes-key search_filter_key">'. $search_ .' <i class="filter-close-icon fa fa-close"></i></a>';
	}

	// Category
	if( !empty( $_GET['category_']) || is_tax( 'recipe_categories' ) ) {
		if( is_tax( 'recipe_categories' ) ){
			$category_ = get_queried_object()->slug;
			$remove_url = smk_recipes_link();
		}
		else{
			$category_ = esc_html( $_GET['category_'] );
			$remove_url = smk_remove_query_arg( array( 'category_', 'pag' ) );
		}

		if( !empty($category_) ){
			$term = get_term_by( 'slug', $category_, 'recipe_categories' );
			if( is_object($term) ){
				$output .= '<a href="'. $remove_url .'" class="filter-recipes-key category_filter_key">'. __('Category', 'smk_theme') .': '. $term->name .' <i class="filter-close-icon fa fa-close"></i></a>';
			}
		}
	}

	// Category
	if( !empty( $_GET['ingredient_']) || is_tax( 'recipe_ingredients' ) ) {
		if( is_tax( 'recipe_ingredients' ) ){
			$ingredient_ = get_queried_object()->slug;
			$remove_url = smk_recipes_link();
		}
		else{
			$ingredient_ = esc_html( $_GET['ingredient_'] );
			$remove_url = smk_remove_query_arg( array( 'ingredient_', 'pag' ) );
		}

		if( !empty($ingredient_) ){
			$term = get_term_by( 'slug', $ingredient_, 'recipe_ingredients' );
			if( is_object($term) ){
				$output .= '<a href="'. $remove_url .'" class="filter-recipes-key ingredient_filter_key">'. __('Ingredient', 'smk_theme') .': '. $term->name .' <i class="filter-close-icon fa fa-close"></i></a>';
			}
		}
	}

	// Difficulty
	if( !empty( $_GET['difficulty_']) ) {
		$difficulty_ = esc_html( $_GET['difficulty_'] );
		$difficulties = array(
			'easy' => __('Easy', 'smk_theme'), 
			'moderate' => __('Moderate', 'smk_theme'), 
			'hard' => __('Hard', 'smk_theme')
		);
		if( in_array($difficulty_, array('easy', 'moderate', 'hard')) ){
			$output .= '<a href="'. smk_remove_query_arg( array( 'difficulty_', 'pag' ) ) .'" class="filter-recipes-key difficulty_filter_key">'. __('Difficulty', 'smk_theme') .': '. $difficulties[ $difficulty_ ] .' <i class="filter-close-icon fa fa-close"></i></a>';
		}
	}

	// Tags
	if( !empty( $_GET['tags_']) || is_tax( 'recipe_tags' ) ) {
		if( is_tax( 'recipe_tags' ) ){
			$tags_ = get_queried_object()->name;
			$remove_url = smk_recipes_link();
		}
		else{
			$tags_ = esc_html( $_GET['tags_'] );
			$remove_url = smk_remove_query_arg( array( 'tags_', 'pag' ) );
		}

		$output .= '<a href="'. $remove_url .'" class="filter-recipes-key tags_filter_key">'. __('Tags', 'smk_theme') .': '.  $tags_ .' <i class="filter-close-icon fa fa-close"></i></a>';
	}

	// Submitted
	if( !empty( $_GET['submitted_']) ) {
		$subm_date = array(
			'last_year' => __('In the last year', 'smk_theme'),
			'last_6_months' => __('In the last 6 months', 'smk_theme'),
			'last_3_months' => __('In the last 3 months', 'smk_theme'),
			'last_month' => __('In the last month', 'smk_theme'),
			'last_week' => __('In the last week', 'smk_theme'),
			'last_day' => __('In the last day', 'smk_theme'),
		);
		$submitted_ = esc_html( $_GET['submitted_'] );
		if( !empty($submitted_) && array_key_exists($submitted_, $subm_date) ){
			$output .= '<a href="'. smk_remove_query_arg( array( 'submitted_', 'pag' ) ) .'" class="filter-recipes-key submitted_filter_key">'. $subm_date[ $submitted_ ] .' <i class="filter-close-icon fa fa-close"></i></a>';
		}
	}

	// Only
	// only_with_photo_=1&only_featured_=1&only_most_favorited_=1&only_most_liked_
	if( !empty( $_GET ) ) {
		$only_with_photo_     = !empty($_GET['only_with_photo_']) ? absint( $_GET['only_with_photo_'] ) : 0;
		$only_featured_       = !empty($_GET['only_featured_']) ? absint( $_GET['only_featured_'] ) : 0;
		$only_most_favorited_ = !empty($_GET['only_most_favorited_']) ? absint( $_GET['only_most_favorited_'] ) : 0;
		$only_most_liked_     = !empty($_GET['only_most_liked_']) ? absint( $_GET['only_most_liked_'] ) : 0;
		$only_most_viewed_    = !empty($_GET['only_most_viewed_']) ? absint( $_GET['only_most_viewed_'] ) : 0;
		$show = false;
		$only = array();

		if( 1 == $only_with_photo_ ){
			$show = true;
			$only[] = __('with photo', 'smk_theme');
		}
		if( 1 == $only_featured_ ){
			$show = true;
			$only[] = __('featured', 'smk_theme');
		}
		if( 1 == $only_most_favorited_ ){
			$show = true;
			$only[] = __('most favorited', 'smk_theme');
		}
		if( 1 == $only_most_liked_ ){
			$show = true;
			$only[] = __('most liked', 'smk_theme');
		}
		if( 1 == $only_most_viewed_ ){
			$show = true;
			$only[] = __('most viewed', 'smk_theme');
		}

		if( $show ){
			$output .= '<a href="'. smk_remove_query_arg( array( 'only_with_photo_', 'only_featured_', 'only_most_favorited_', 'only_most_liked_', 'only_most_viewed_', 'pag' ) ) .'" class="filter-recipes-key only_filter_key">'. _x('Only', 'noun', 'smk_theme') .': '. join(', ', $only) .' <i class="filter-close-icon fa fa-close"></i></a>';
		}
	}

	// Preparation time: 
	//prep_time__min=7&prep_time__max=12

	if( !empty( $_GET['prep_time__min']) || !empty( $_GET['prep_time__max']) ) {
		$prep_time__min = !empty($_GET['prep_time__min']) ? absint( $_GET['prep_time__min'] ) : '';
		$prep_time__max = !empty($_GET['prep_time__max']) ? absint( $_GET['prep_time__max'] ) : '';
		if( !empty($prep_time__max) && $prep_time__min > $prep_time__max ){
			$prep_time__max = '';
		}
		if( empty($prep_time__min) ){
			$title = sprintf( __('Preparation: max %s minutes', 'smk_theme'), $prep_time__max );
		}
		elseif( empty($prep_time__max) ){
			$title = sprintf( __('Preparation: min %s minutes', 'smk_theme'), $prep_time__min );
		}
		else{
			$title = sprintf( __('Preparation: %s - %s minutes', 'smk_theme'), $prep_time__min, $prep_time__max );
		}
		$output .= '<a href="'. smk_remove_query_arg( array( 'prep_time__min','prep_time__max', 'pag' ) ) .'" class="filter-recipes-key prep_time_filter_key">'. $title .' <i class="filter-close-icon fa fa-close"></i></a>';
	}

	return $output;
}