<?php
class Srps_Permalink_Settings {

	public function __construct() {
		add_action('admin_init', array( $this, 'settingsInit' ));
		add_action('admin_init', array( $this, 'settingsSave' ));
	}

	/*
	-------------------------------------------------------------------------------
	Fields
	-------------------------------------------------------------------------------
	*/
	public function settingsInit() {
		$this->addField( 'smk_recipes_permalink_slug', array( $this, 'recipesSlugInput' ), __( 'Recipes slug', 'smk_theme' ) );
		$this->addField( 'smk_recipes_tag_permalink_slug', array( $this, 'recipesTagSlugInput' ), __( 'Recipes tag slug', 'smk_theme' ) );
		$this->addField( 'smk_recipes_category_permalink_slug', array( $this, 'recipesCategorySlugInput' ), __( 'Recipes category slug', 'smk_theme' ) );
		$this->addField( 'smk_recipes_ingredient_permalink_slug', array( $this, 'recipesIngredientSlugInput' ), __( 'Recipes ingredient slug', 'smk_theme' ) );
	}

	/*
	-------------------------------------------------------------------------------
	Callbacks
	-------------------------------------------------------------------------------
	*/
	public function recipesSlugInput() {
		echo $this->input( 'smk_recipes_permalink_slug', 'recipes');
	}
	
	public function recipesTagSlugInput() {
		echo $this->input( 'smk_recipes_tag_permalink_slug', 'recipe-tag');
	}

	public function recipesCategorySlugInput() {
		echo $this->input( 'smk_recipes_category_permalink_slug', 'recipe-category');
	}

	public function recipesIngredientSlugInput() {
		echo $this->input( 'smk_recipes_ingredient_permalink_slug', 'recipe-ingredient');
	}
	
	/*
	-------------------------------------------------------------------------------
	Save settings
	-------------------------------------------------------------------------------
	*/
	public function settingsSave() {
		if ( ! is_admin() ) return;

		$this->saveField( 'smk_recipes_permalink_slug' );
		$this->saveField( 'smk_recipes_tag_permalink_slug' );
		$this->saveField( 'smk_recipes_category_permalink_slug' );
		$this->saveField( 'smk_recipes_ingredient_permalink_slug' );
	}

	/*
	-------------------------------------------------------------------------------
	Helpers
	-------------------------------------------------------------------------------
	*/
	public function input( $option_name, $placeholder = '' ) {
		$slug = get_option( $option_name );
		$value = ( isset( $slug ) ) ? esc_attr( $slug ) : ''; 
		return '<input name="'. $option_name .'" type="text" class="regular-text code" value="'. $slug .'" placeholder="'. $placeholder .'" />';
	}

	public function addField( $option_name, $callback, $title ){
		add_settings_field(
			$option_name, // id
			$title,       // setting title
			$callback,    // display callback
			'permalink',  // settings page
			'optional'    // settings section
		);
	}

	public function saveField( $option_name ){
		if ( isset( $_POST[$option_name] ) ) {
			$permalink_structure = sanitize_title( $_POST[$option_name] );
			$permalink_structure = untrailingslashit( $permalink_structure );
		
			update_option( $option_name, $permalink_structure );
		}
	}
}
new Srps_Permalink_Settings;