<?php 
if( !class_exists('Smk_Auth_Form') ){
	class Smk_Auth_Form{

		//------------------------------------//--------------------------------------//
				
		/**
		 * Register ajax handlers
		 *
		 * Register ajax actions.
		 *
		 * @return void 
		 */
		public function register(){
			add_action('wp_ajax_nopriv_smk_login_form_ajax_handler', array( $this, 'ajaxFormHandler' )); //Only for non-logged in users
			add_action('wp_footer', array( $this, 'getForm' )); //Append login form to the end of document 
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Process the ajax request
		 *
		 * Process the ajax request that is coming from $_POST
		 *
		 * 100 - No data
		 * 101 - No login
		 * 102 - No password
		 * 103 - Invalid credits
		 * 104 - Success
		 * 105 - Unknown error
		 * 
		 * @return string 
		 */
		public function ajaxFormHandler(){
			if( isset($_POST) && !empty($_POST) ){
			
				$form_data = !empty($_POST['data']) ? $_POST['data'] : false;
				if( empty( $form_data ) ) die( '100' );

				parse_str($form_data, $data); // Convert jQuery serialized data to a PHP array

				if( $data['formtype'] == 'log' ){
					$this->logMode( $data );
				}
				elseif( $data['formtype'] == 'reg' ){
					$this->regMode( $data );
				}
				elseif( $data['formtype'] == 'rec' ){
					$this->recMode( $data );
				}
							
			}
			die('105');
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Log in mode
		 *
		 * Process the required data to log in the user
		 *
		 * @param array $data  
		 * @return string The message code 
		 */
		public function logMode( $data ){
			// Verify username
			$username = !empty($data['username']) ? $data['username'] : false;
			if( empty( $username ) ) die( '101' );

			// Verify password
			$password = !empty($data['password']) ? $data['password'] : false;
			if( empty( $password ) ) die( '102' );

			// Verify remember
			$remember = !empty($data['remember']) ? true : false;

			$creds = array(
				'user_login' => $username,
				'user_password' => $password,
				'remember' => $remember,
			);
			$user = wp_signon( $creds, false );
			if ( is_wp_error($user) ){
				die('103');
			}
			else{
				die('104');
			}
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Register mode
		 *
		 * Process the required data to register the user
		 *
		 * @param array $data  
		 * @return string The message code 
		 */
		public function regMode( $data ){
			// Verify username
			$username = !empty($data['username']) ? $data['username'] : false;
			if( empty( $username ) ) die( '101' );

			// Verify password
			$password = !empty($data['password']) ? $data['password'] : false;
			if( empty( $password ) ) die( '102' );

			// Confirm password
			$confirm_password = !empty($data['confirm_password']) ? $data['confirm_password'] : false;
			if( empty( $confirm_password ) ) die( '106' );

			// Accept terms
			$registration_terms_enable = smk_recipe_setting( 'registration_terms_enable' );
			if( !empty($registration_terms_enable) ){
				$terms = !empty($data['terms']) ? $data['terms'] : false;
				if( empty( $terms ) ) die( '118' );
			}

			//reCaptcha
			$registration_captcha_enable = smk_recipe_setting( 'registration_captcha_enable' );
			$registration_captcha_site_key = smk_recipe_setting( 'registration_captcha_site_key' );
			$registration_captcha_secret_key = smk_recipe_setting( 'registration_captcha_secret_key' );
			if( !empty($registration_captcha_site_key) && !empty($registration_captcha_secret_key) && !empty($registration_captcha_enable) && $registration_captcha_enable == 'on' ){
				if(isset($data['g-recaptcha-response'])){
					$captcha = $data['g-recaptcha-response'];
				}
				if(!$captcha){
					die( '119' );
				}
				$response = file_get_contents('https://www.google.com/recaptcha/api/siteverify?secret='. $registration_captcha_secret_key .'&response='. $captcha. '&remoteip='. $_SERVER['REMOTE_ADDR'] );
				$response = json_decode($response);
				if( !empty($response) && is_object($response) && ! empty($response->success) && $response->success == false ){
					die( '120' );
				}
			}

			// VErify Password and Confirm
			if( $password !== $confirm_password ) die( '107' );

			// Email
			$email = !empty($data['email']) ? $data['email'] : false;
			if( empty( $email ) ) die( '108' );

			// Verify username and email
			if( username_exists( $username ) ) die( '111' );
			if( email_exists( $email ) ) die( '112' );
			if( ! is_email( $email ) ) die( '109' );

			// Register user
			$userdata = array(
				'user_login'  => $username,
				'user_pass'   => $password,
				'user_email'  => $email
			);

			$user_id = wp_insert_user( $userdata ) ;

			// Log in
			$creds = array(
				'user_login' => $username,
				'user_password' => $password,
				'remember' => true,
			);
			$user = wp_signon( $creds, false );

			//On success
			if( !is_wp_error( $user_id ) ) {
				die('113');
			}
			else{
				die('105');
			}

		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Recover mode
		 *
		 * Process the required data to recover the user password
		 *
		 * @param array $data  
		 * @return string The message code 
		 */
		public function recMode( $data ){
			// Verify username or email if exists in DB
			$username_or_email = !empty($data['username_or_email']) ? $data['username_or_email'] : false;
			if( empty( $username_or_email ) ) die( '110' );

			$mail_send = $this->retrievePassword( $username_or_email );
			if( $mail_send === true ){
				die('116');
			}
			else{
				die('117');
			}
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Handles sending password retrieval email to user.
		 *
		 * @uses $wpdb WordPress Database object
		 *
		 * @return bool|WP_Error True: when finish. WP_Error on error
		 */
		public function retrievePassword( $user_login ) {
			global $wpdb, $wp_hasher;

			if ( empty( $user_login ) ) {
				return false;
			} else if ( strpos( $user_login, '@' ) ) {
				$user_data = get_user_by( 'email', trim( $user_login ) );
				if ( empty( $user_data ) )
					return false;
			} else {
				$login = trim($user_login);
				$user_data = get_user_by('login', $login);
			}

			/**
			 * Fires before errors are returned from a password reset request.
			 *
			 * @since 2.1.0
			 */
			do_action( 'lostpassword_post' );

			if ( !$user_data ) {
				return false;
			}

			// redefining user_login ensures we return the right case in the email
			$user_login = $user_data->user_login;
			$user_email = $user_data->user_email;

			/**
			 * Fires before a new password is retrieved.
			 *
			 * @since 1.5.0
			 * @deprecated 1.5.1 Misspelled. Use 'retrieve_password' hook instead.
			 *
			 * @param string $user_login The user login name.
			 */
			do_action( 'retreive_password', $user_login );
			/**
			 * Fires before a new password is retrieved.
			 *
			 * @since 1.5.1
			 *
			 * @param string $user_login The user login name.
			 */
			do_action( 'retrieve_password', $user_login );

			/**
			 * Filter whether to allow a password to be reset.
			 *
			 * @since 2.7.0
			 *
			 * @param bool true           Whether to allow the password to be reset. Default true.
			 * @param int  $user_data->ID The ID of the user attempting to reset a password.
			 */
			$allow = apply_filters( 'allow_password_reset', true, $user_data->ID );

			if ( ! $allow )
				return __('Password reset is not allowed for this user', 'smk_theme');
			else if ( is_wp_error($allow) )
				return $allow;

			// Generate something random for a password reset key.
			$key = wp_generate_password( 20, false );

			/**
			 * Fires when a password reset key is generated.
			 *
			 * @since 2.5.0
			 *
			 * @param string $user_login The username for the user.
			 * @param string $key        The generated password reset key.
			 */
			do_action( 'retrieve_password_key', $user_login, $key );

			// Now insert the key, hashed, into the DB.
			if ( empty( $wp_hasher ) ) {
				require_once ABSPATH . 'wp-includes/class-phpass.php';
				$wp_hasher = new PasswordHash( 8, true );
			}
			$hashed = $wp_hasher->HashPassword( $key );
			$wpdb->update( $wpdb->users, array( 'user_activation_key' => $hashed ), array( 'user_login' => $user_login ) );

			$message = __('Someone requested that the password be reset for the following account:', 'smk_theme') . "\r\n\r\n";
			$message .= network_home_url( '/' ) . "\r\n\r\n";
			$message .= sprintf(__('Username: %s', 'smk_theme'), $user_login) . "\r\n\r\n";
			$message .= __('If this was a mistake, just ignore this email and nothing will happen.', 'smk_theme') . "\r\n\r\n";
			$message .= __('To reset your password, visit the following address:', 'smk_theme') . "\r\n\r\n";
			$message .= '<' . network_site_url("wp-login.php?action=rp&key=$key&login=" . rawurlencode($user_login), 'login') . ">\r\n";

			if ( is_multisite() )
				$blogname = $GLOBALS['current_site']->site_name;
			else
				// The blogname option is escaped with esc_html on the way into the database in sanitize_option
				// we want to reverse this for the plain text arena of emails.
				$blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);

			$title = sprintf( __('[%s] Password Reset', 'smk_theme'), $blogname );

			/**
			 * Filter the subject of the password reset email.
			 *
			 * @since 2.8.0
			 *
			 * @param string $title Default email title.
			 */
			$title = apply_filters( 'retrieve_password_title', $title );
			/**
			 * Filter the message body of the password reset mail.
			 *
			 * @since 2.8.0
			 *
			 * @param string $message Default mail message.
			 * @param string $key     The activation key.
			 */
			$message = apply_filters( 'retrieve_password_message', $message, $key );

			if ( $message && !wp_mail( $user_email, wp_specialchars_decode( $title ), $message ) )
				return __('The e-mail could not be sent.', 'smk_theme') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function.', 'smk_theme');

			return true;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Send email
		 *
		 * Send the email to the user with the necesary data
		 *
		 * @param string The email address
		 * @return bool 
		 */
		public function mailSend( $email ){
			wp_mail( $username_or_email, 'The subject', 'The message' );
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get form
		 *
		 * Get login and registration forms block
		 * 
		 * @return string
		 */
		public function getForm(){
			if( ! is_user_logged_in() ){
				$output = '<div class="smk-theme-login-block-back-shadow"></div>';
				$output .= '<div class="smk-theme-login-block">';
				$output .= '<div class="smk-theme-login-block-type">
					<span class="type-login active">'. __('Log In', 'smk_theme') .'</span>
					<span class="type-register">'. __('Register', 'smk_theme') .'</span>
					<span class="type-recover">'. __('Lost Password', 'smk_theme') .'</span>
				</div>';
				$output .= '<div class="smk-theme-login-block-close"><i class="fa fa-close"></i></div>';
					$output .= '<form class="smk-theme-login-form" method="post" action="'. site_url( $_SERVER['REQUEST_URI'] ) .'">';
						$output .= '<div class="form-message-response"></div>';
						$output .= $this->loginForm();
						$output .= '<input type="hidden" name="formtype" class="smk-login-form-type" value="log" />';
					$output .= '</form>';	
				$output .= '</div>';
				echo $output;
			}
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Login form
		 *
		 * The login form
		 *  
		 * @return string The HTML 
		 */
		public function loginForm(){

			$output = '';
			$output =  $this->loginFields();
			$output .= $this->registrationFields();
			$output .= $this->recoverFields();

			// Submit
			$output .= '<div><input type="submit" name="submit" class="button primary smk-theme-login-form-button" value="'. __('Submit', 'smk_theme') .'" /></div>';
			if( function_exists('wsl_shortcode_wordpress_social_login') ){
				$output .= '<div class="smk-login-social">'. wsl_shortcode_wordpress_social_login() .'</div>';
			}

			return $output;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Login form fields
		 *
		 * The login form fields
		 *  
		 * @return string The HTML 
		 */
		public function loginFields(){
			$output = '<div class="form-row fr-log-y fr-reg-y">
				<div class="form-label">'. __('Username', 'smk_theme') .'</div>
				<input type="text" name="username" class="fullwidth" />
			</div>';

			$output .= '<div class="form-row fr-log-y fr-reg-y">
				<div class="form-label">'. __('Password', 'smk_theme') .'</div>
				<input type="password" name="password" class="fullwidth" />
			</div>';

			$output .= '<div class="form-row fr-log-y">
				<label><input type="checkbox" name="remember" value="forever" checked="checked" /> '. __('Remember me', 'smk_theme') .'</label>
			</div>';

			return $output;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Registration form fields
		 *
		 * The registration form fields
		 *  
		 * @return string The HTML 
		 */
		public function registrationFields(){
			$output = '<div class="form-row fr-reg-y">
				<div class="form-label">'. __('Confirm Password', 'smk_theme') .'</div>
				<input type="password" name="confirm_password" class="fullwidth" />
			</div>';

			$output .= '<div class="form-row fr-reg-y">
				<div class="form-label">'. __('Email', 'smk_theme') .'</div>
				<input type="text" name="email" class="fullwidth" />
			</div>';
			
			$registration_terms_enable = smk_recipe_setting( 'registration_terms_enable' );
			
			if( !empty($registration_terms_enable) ){
				$registration_terms_text = smk_recipe_setting( 'registration_terms_text' );
				$registration_terms_text = !empty($registration_terms_text) ? $registration_terms_text : __('I accept terms and conditions.', 'smk_theme');

				$output .= '<div class="form-row fr-reg-y">
					<label><input type="checkbox" name="terms" value="1" checked="checked" />'. $registration_terms_text .'</label>
				</div>';
			}

			$registration_captcha_enable = smk_recipe_setting( 'registration_captcha_enable' );
			$registration_captcha_site_key = smk_recipe_setting( 'registration_captcha_site_key' );
			$registration_captcha_secret_key = smk_recipe_setting( 'registration_captcha_secret_key' );

			if( !empty($registration_captcha_site_key) && !empty($registration_captcha_secret_key) && !empty($registration_captcha_enable) && $registration_captcha_enable == 'on' ){
				$output .= '<div class="form-row fr-reg-y">
					<div class="g-recaptcha" data-sitekey="'. $registration_captcha_site_key .'"></div>
				</div>';
			}

			return $output;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Recover form fields
		 *
		 * The recover form fields
		 *  
		 * @return string The HTML 
		 */
		public function recoverFields(){
			$output = '<div class="form-row fr-rec-y">
				<div class="form-label">'. __('Username or email', 'smk_theme') .'</div>
				<input type="text" name="username_or_email" class="fullwidth" />
			</div>';

			return $output;
		}

	}
}