<?php
class Smk_User_Form_Register_Type{
	public $name;
	public $class;

	public function __construct( $name, $class ){
		$this->name = $name;
		$this->class = $class;

		if( !array_key_exists( $this->name, Smk_User_Form_Base::types() ) ){
			add_filter( 'smk_user_form_field_types', array( $this, 'addType' ) );
		}
	}

	public function addType( $prev ){
		$new[ $this->name ] = $this->class;
		return wp_parse_args( $new, $prev );
	}
}

//------------------------------------//--------------------------------------//

function smk_register_user_field_type( $name, $class ){
	new Smk_User_Form_Register_Type( $name, $class );
}

//------------------------------------//--------------------------------------//

class Smk_User_Form_Type{

	public $input_id;
	public $input_settings;

	public function __construct( $input_id, $input_settings = array() ){
		$this->input_id = $input_id;
		$this->input_settings = $input_settings;
	}

	public function show( $id, $settings, $saved_value ){
		return false;
	}

	public function sanitize( $data, $settings ){
		return $data;
	}

	public function display( $user ){
		$id = $this->input_id;
		$settings = $this->input_settings;
		$saved_value = get_user_meta($user->ID, $id, true);

		$output = '<tr>';
			$output .= '<th><label>'. $settings['title'] .'</label></th>';
			$output .= '<td>';
				$output .= $this->show( $id, $settings, $saved_value );
			$output .= '</td>';
		$output .= '</tr>';

		echo $output;
	}
}

//------------------------------------//--------------------------------------//

class Smk_User_Form_Type_Input extends Smk_User_Form_Type{

	public function show( $id, $settings, $saved_value ){
		return '<input type="text" name="'. $id .'" value="'. esc_attr($saved_value) .'" class="regular-text" />';
	}

	public function sanitize( $data, $settings ){
		return sanitize_text_field($data);
	}

}

//------------------------------------//--------------------------------------//

smk_register_user_field_type( 'input', 'Smk_User_Form_Type_Input' );

//------------------------------------//--------------------------------------//

class Smk_User_Form_Type_Textarea extends Smk_User_Form_Type{

	public function show( $id, $settings, $saved_value ){
		return '<textarea name="'. $id .'" rows="5" cols="30">'. esc_textarea($saved_value) .'</textarea>';
	}

}

//------------------------------------//--------------------------------------//

smk_register_user_field_type( 'textarea', 'Smk_User_Form_Type_Textarea' );

//------------------------------------//--------------------------------------//

class Smk_User_Form_Type_Select extends Smk_User_Form_Type{

	public function show( $id, $settings, $saved_value ){
		$output = '';
		if( !empty($settings['options']) && is_array($settings['options']) ){
			$output .= '<select name="'. $id .'">';
			foreach ($settings['options'] as $key => $value) {
				$selected = ( !empty($saved_value) && ($key == $saved_value) ) ? ' selected="selected"' : '';
				$output .= '<option value="'. esc_html( $key ) .'"'. $selected .' >'. esc_attr($value) .'</option>';	
			}
			$output .= '</select>';
		}
		return $output;
	}

}

//------------------------------------//--------------------------------------//

smk_register_user_field_type( 'select', 'Smk_User_Form_Type_Select' );