<?php
if( ! class_exists('Smk_Theme_User_Follow') ){
	class Smk_Theme_User_Follow{
		
		public function register(){
			add_action( 'wp_ajax_follow_user', array( $this, 'followUser' ) );
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Button
		 *
		 * The button used to follow a user
		 *
		 * @param string $user The user ID, to be followed  
		 * @param array $args Button settings  
		 * @return string The HTML 
		 */
		public function button( $user, $args = array() ){
			$default_args = array(
				'title' => array(
					'default' => '',
					'active' => '',
					'not_yourself' => __("You can't follow yourself.", "smk_theme"),
					'not_logged' => __("Please log in to follow this user.", "smk_theme"),
				),
				'btn_class' => array(
					'default' => 'button blue',
					'active' => 'button green active current',
				),
				'btn_text' => array(
					'default' => __('Follow', 'smk_theme'),
					'active' => __('Following', 'smk_theme'),
				),
				'icon_class' => array(
					'default' => 'fa-plus',
					'active' => 'fa-check',
				),
			);

			$args = wp_parse_args($args, $default_args);
			$btn_class = '';
			$btn_text = '';
			$icon_class = '';
			$title = '';
			$not_allowed_class = '';

			$current_user = $this->currentUser();
			$follower = $current_user->ID;
			$followers = $this->followers( $user );

			if( ! is_user_logged_in() ){
				$not_allowed_class = ' not-allowed';
				$title = $args['title']['not_logged'];
			}
			if( $follower == $user ){
				$title = $args['title']['not_yourself'];
				$not_allowed_class = ' not-allowed';
			}

			if( in_array( $follower, $followers ) ){
				$btn_class = $args['btn_class']['active'];
				$btn_text = $args['btn_text']['active'];
				$icon_class = $args['icon_class']['active'];
			}
			else{
				$btn_class = $args['btn_class']['default'];
				$btn_text = $args['btn_text']['default'];
				$icon_class = $args['icon_class']['default'];
			}

			return '<a href="#" class="follow-user '. $btn_class . $not_allowed_class .'" data-id="'. $user .'" title="'. $title .'">
				<i class="fa '. $icon_class .'"></i> <span class="text">'. $btn_text .'</span>
			</a>';

		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Follow the user
		 *
		 * Ajax handler to follow a user
		 * 
		 * @return string The message 
		 */
		public function followUser(){
			$follower_obj = $this->currentUser();
			$follower = $follower_obj->ID;
			$response = 'fail';
			
			if( isset($_POST) ){
				$user = !empty($_POST['usertofollow']) ? $_POST['usertofollow'] : false;
				if( $user && $follower != $user ){
					$all_followers = $this->followers( $user );
					
					// delete_user_meta($user, 'st_followers');

					if( ! in_array($follower, $all_followers) ){
						$response = $this->follow( $follower, $user, $all_followers );
						do_action( 'smk_followed_user', $user );
					}
					elseif( array_search($follower, $all_followers) !== false ) {
						$response = $this->unfollow( $follower, $user, $all_followers );
						do_action( 'smk_unfollowed_user', $user );
					}
				}
			}

			echo $response;
			die();
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Current user
		 *
		 * Get the current user that is currently logged and is browsing the site.
		 *
		 * @return object 
		 */
		public function currentUser(){
			global $current_user;
			get_currentuserinfo();
			return $current_user;
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Followers
		 *
		 * Get all followers
		 *
		 * @return array 
		 */
		public function followers( $user ){
			$all_followers = get_user_meta($user, 'st_followers', true);
			return !empty( $all_followers ) && is_array($all_followers) ? $all_followers : array();
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Follow user
		 *
		 * Follow a user
		 *
		 * @return string The message
		 */
		public function follow( $follower, $user, $all_followers ){
			$all_followers = array_merge($all_followers, (array) $follower);
			update_user_meta($user, 'st_followers', $all_followers);
			$this->addToFollowing( $follower, $user );
			return 'followed';
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Unfollow user
		 *
		 * Unfollow a user
		 *
		 * @return string The message
		 */
		public function unfollow( $follower, $user, $all_followers ){
			$key = array_search($follower, $all_followers);
			unset( $all_followers[$key] );
			update_user_meta($user, 'st_followers', $all_followers);
			$this->removeFromFollowing( $follower, $user );
			return 'unfollowed';
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Add to following
		 *
		 * Add a user ID to following
		 *
		 * @return void 
		 */
		public function addToFollowing( $follower, $user ){
			$all_following = get_user_meta($follower, 'st_following', true);
			$all_following = !empty( $all_following ) && is_array($all_following) ? $all_following : array();

			$all_following = array_merge($all_following, (array) $user);
			update_user_meta($follower, 'st_following', $all_following);
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Remove from following
		 *
		 * Remove a user ID from following
		 *
		 * @return void 
		 */
		public function removeFromFollowing( $follower, $user ){
			$all_following = get_user_meta($follower, 'st_following', true);
			$all_following = !empty( $all_following ) && is_array($all_following) ? $all_following : array();

			$key = array_search($user, $all_following);
			unset( $all_following[$key] );
			update_user_meta($follower, 'st_following', $all_following);
		}

	}
}