<?php 
if( !class_exists('Smk_Private_Messages_Cpt') ){
	class Smk_Private_Messages_Cpt{

		public $id;
		public $regcpt = 'register_post_type';

		public function __construct( $id ){
			$this->id = $id;
			add_action( 'init', array( $this, 'postType' ) );
			add_action( 'manage_'. $this->id .'_posts_custom_column', array( $this, 'columnsContent' ), 10, 2 );
			add_filter( 'manage_edit-'. $this->id .'_columns', array( $this, 'columns' ) );
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Register Post type
		 *
		 * Register Custom Post Type
		 * 
		 * @action-hook init
		 * 
		 * @return void 
		 */
		public function postType(){

			// Create The Labels (Output) For The Post Type
			$labels = array(
				'name'               => __('Private Messages', 'smk_theme'), 
				'singular_name'      => __('Private Message', 'smk_theme'),
				'add_new'            => _x('Add Private Message', 'portfolio', 'smk_theme'), 
				'edit_item'          => __('Edit Private Message', 'smk_theme'),
				'new_item'           => __('New Private Message', 'smk_theme'), 
				'view_item'          => __('View Private Message', 'smk_theme'),
				'search_items'       => __('Search Private Messages', 'smk_theme'), 
				'not_found'          => __('No Private Messages Found', 'smk_theme'),
				'not_found_in_trash' => __('No Private Messages Found In Trash', 'smk_theme'),
				'parent_item_colon'  => '' 
			);
			
			// Set Up The Arguements
			$args = array(
				'labels'             => $labels, 
				'public'             => false, 
				'has_archive'        => false,
				'publicly_queryable' => false, 
				'show_ui'            => true, 
				'query_var'          => true, 
				'rewrite'            => array(
					'slug' => 'smk-private-messages',
				),
				'capability_type'    => 'post',
				'menu_icon'          => 'dashicons-format-chat',
				'hierarchical'       => false, 
				'show_in_nav_menus'  => false,
				'show_in_menu'       => 'users.php',
				'menu_position'      => 20, 
				'supports'           => array(
					'title',
				),
			);
			
			// Register post type
			$this->regCpt( $args );

		}

		public function regCpt( $args ){
			$fn = $this->regcpt;
			$fn( $this->id, $args );
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Columns
		 *
		 * Register custom columns
		 *
		 * @param array $columns
		 * @return array
		 */
		public function columns($columns){
			$columns = array(
				'cb'            => '<input type="checkbox" />',
				'title'         => __( 'Title', 'smk_theme' ),
				'details'       => __( 'Details', 'smk_theme' ),
				'date'          => __( 'Date', 'smk_theme' ),
			);

			return $columns;
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Columns Content
		 *
		 * Add content to custom columns
		 *
		 * @param string $column
		 * @param string $post_id
		 * @return string Html content
		 */
		public function columnsContent($column, $post_id){
			global $post;

			switch ($column) {

				case 'details':

					$meta_value = get_post_meta( $post_id, 'smk_pm_receiver', true );
					$messages   = get_post_meta( $post_id, 'smk_private_messages_list', true );
					$total      = (is_array($messages)) ? count($messages) : 0;

					// Users
					echo '<p><strong>'. sprintf( 
						__('From %1$s to %2$s', 'smk_theme'),  
						$this->userUrl( get_the_author_meta( 'ID' ) ),
						!empty($meta_value) ? $this->userUrl( $meta_value ) : '---'
					) .'</strong></p>';

					if( $total > 0 ){
						echo $this->firstMessage($messages);
						echo $this->lastMessage($messages);
					}
					break;

				default:
					break;
			}

		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Message
		 *
		 * Get the message info
		 *
		 * @param array $msg_data Message data  
		 * @param string $title Block title  
		 * @return string
		 */
		public function message( $msg_data, $title = '' ){
			$return = '';
			if( !empty($msg_data['message']) ){
				if( !empty($title) ){
					$return .= '<div><strong>'. $title .'</strong></div>';
				}
				$return .= '<p>'. $this->excerpt($msg_data['message'], 35) .'</p>';
			}
			return $return;
		}

		public function firstMessage( $messages ){
			reset($messages);
			$first = key($messages);
			return $this->message( $messages[$first], __('First message:', 'smk_theme') );
		}

		public function lastMessage( $messages ){
			if( count($messages) > 1 ){
				end($messages);
				$last = key($messages);
				return $this->message( $messages[$last], __('Last reply:', 'smk_theme') );
			}
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * User url
		 *
		 * Create user url
		 *
		 * @param int $user_id  
		 * @return string
		 */
		public function userUrl( $user_id ){
			return '<a href="'. get_author_posts_url( $user_id ) .'" target="_blank">' . get_the_author_meta( 'display_name', $user_id ) .'</a>';
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Excerpt
		 *
		 * Get the excerpt
		 *
		 * @param string $text  
		 * @param int $len Number of words 
		 * @param string $trim 
		 * @return string
		 */
		public function excerpt($text = '', $len = 20, $trim = "..."){
			$limit = $len+1;
			$text = wp_strip_all_tags( $text );
			$excerpt = explode(' ', $text, $limit);
			$num_words = count($excerpt);

			if($num_words >= $len){
				$last_item = array_pop($excerpt);
			}
			else{
				$trim = '';
			}
			$excerpt = implode(" ", $excerpt) . $trim;
			
			return $excerpt;
		}


	}
}