<?php 
if( !class_exists('Smk_Private_Messages_Form') ){
	class Smk_Private_Messages_Form{

		//------------------------------------//--------------------------------------//
				
		/**
		 * Register ajax handlers
		 *
		 * Register ajax actions.
		 *
		 * @return void 
		 */
		public function register(){
			add_action('wp_ajax_smk_private_messages_form_ajax_handler', array( $this, 'ajaxForm' ));
			add_action('wp_ajax_smk_private_messages_delete_msg_ajax_handler', array( $this, 'ajaxDeleteMsg' ));
			add_action('wp_ajax_smk_private_messages_mark_as_important_ajax_handler', array( $this, 'ajaxMarkAsImportant' ));
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Submission form
		 *
		 * Render the submission form HTML
		 *
		 * @param object $author The receiver that must get this message, not the user that sends it.  
		 * @param string $mode Submission mode: 'create' a new discussion or 'reply' to an existing discussion.
		 * @param int $post_id If the $mode = 'reply', then is required to add the discussion ID here.
		 * @return string The form HTML
		 */
		public function form( $author, $mode, $post_id = false ){
			$user = Smk_Theme_User::currentUser();
			?>
			<form method="post" class="private-messaging-form">
				<div class="form-label">
				<?php 
					if( 'create' == $mode ){
						echo sprintf( __('Send private message to %1$s', 'smk_theme'), $author->display_name); 
					}
					elseif( 'reply' == $mode ){
						_e('Reply', 'smk_theme'); 
					}
				?>
				</div>
				<div class="form-description">Press Ctrl + Enter to send the message.</div>
				<div class="response-message"></div>
				<textarea name="message" class="private-messaging-textarea"></textarea>
				<input type="hidden" name="sender" value="<?php echo $user->ID; ?>" />
				<?php if(  'create' == $mode  ) { ?>
					<input type="hidden" name="receiver" value="<?php echo $author->ID; ?>" />
					<input type="hidden" name="private_message" value="create" />
				<?php }
				elseif( 'reply' == $mode ){ ?>
					<input type="hidden" name="conversation_id" value="<?php echo $post_id; ?>" />
					<input type="hidden" name="private_message" value="reply" />
				<?php } ?>
				<?php wp_nonce_field( 'private_message_form' ); ?>
				<div class="private-messaging-footer clearfix">
					<input type="submit" class="button primary private-messaging-button" value="<?php _e('Send message', 'smk_theme'); ?>" />
				</div>
			</form>
			<?php
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Ajax Form
		 *
		 * Ajax form handler. This function is used to process the $_POST request generated by submission form.
		 * 
		 * @return string An error/success code or the messages if it comes from a reply request. 
		 */
		public function ajaxForm(){
			$return = '';
			if( isset($_POST) ){
			
				$form_data = !empty($_POST['data']['form_data']) ? $_POST['data']['form_data'] : false;
				if( empty( $form_data ) ) die( '100' );

				parse_str($form_data, $data);
				
				// Security check.
				$nonce = !empty($data['_wpnonce']) ? $data['_wpnonce'] : false;
				if ( ! wp_verify_nonce( $nonce, 'private_message_form' ) ) die( '103' );
				
				// Data
				$message = !empty($data['message']) ? trim( wp_kses_data( $data['message']) ) : false;
				if( empty( $message ) )  die( '101' );

				$private_message_type = !empty($data['private_message']) ? $data['private_message'] : false;
				if( empty( $private_message_type ) ) die( '100' );

				$post_args = array(
					'post_type'      => 'smk_private_messages',
				); 
				$message_data = array(
					'from'    => absint($data['sender']),
					'message' => $message,
					'date'    => time(),
				);

				if( $private_message_type == 'create' ){
					
					$title = sprintf( 
						__('From %1$s to %2$s', 'smk_theme'),  
						get_the_author_meta( 'display_name', absint($data['sender']) ),
						get_the_author_meta( 'display_name', absint($data['receiver']) )
					);

					$post_args['post_content'] = '';
					$post_args['post_status'] = 'publish';
					$post_args['post_title'] = $title;
					$post_args['post_author'] = absint($data['sender']);
					// $post_args['post_date'] = date( 'Y-m-d H:i:s', mt_rand(YEAR_IN_SECONDS, time()) ); // Random date. DO NOT uncomment
					
					$post_id = wp_insert_post( $post_args );

					if( !empty($post_id) ){

						// Add the message
						$messages[] = $message_data;
						update_post_meta($post_id, 'smk_private_messages_list', $messages);
						
						// Update other meta
						update_post_meta($post_id, 'smk_pm_sender', absint($data['sender']));
						update_post_meta($post_id, 'smk_pm_receiver', absint($data['receiver']));
						update_post_meta($post_id, 'smk_pm_in_inbox_to_receiver', absint($data['receiver']));
						update_post_meta($post_id, 'smk_pm_unread_for_receiver', absint($data['receiver']));

						//Add new PM to user list
						$this->addNewPm( absint($data['receiver']), $post_id );

						$return = '102';
					}
					else{
						$return = '100';
					}
				}
				elseif( $private_message_type == 'reply' ){
					$post_id = !empty($data['conversation_id']) ? trim( absint($data['conversation_id']) ) : false;
					if( !empty($post_id) ){
						$post_args['ID'] = $post_id;
						$post_args['post_date'] = date("Y-m-d H:i:s");
						wp_update_post( $post_args );

						// Add the message
						$saved_messages = get_post_meta($post_id, 'smk_private_messages_list', true);
						$messages[] = $message_data;
						$new_messages = array_merge( (array) $saved_messages, $messages);
						update_post_meta($post_id, 'smk_private_messages_list', $new_messages);

						// Update other meta
						$receiver_id = get_post_meta( $post_id, 'smk_pm_receiver', true );
						$sender_id = get_post_meta( $post_id, 'smk_pm_sender', true );
						if( absint($data['sender']) == $receiver_id){ // If it's a reply back from receiver
							update_post_meta($post_id, 'smk_pm_in_inbox_to_sender', absint($sender_id));
							update_post_meta($post_id, 'smk_pm_unread_for_sender', absint($sender_id));

							//Add new PM to user list
							$this->addNewPm( absint($sender_id), $post_id );
						}
						else{
							update_post_meta($post_id, 'smk_pm_unread_for_receiver', absint($receiver_id));

							//Add new PM to user list
							$this->addNewPm( absint($receiver_id), $post_id );
						}
						
						$current_user   = Smk_Theme_User::currentUser();
						$msg_to_list    = new Smk_Private_Messages_List($current_user);

						$saved_messages = get_post_meta($post_id, 'smk_private_messages_list', true);
						$msg_to_list->theMessages($saved_messages, $post_id);

						die();

						$return = '102';
					}
					else{
						$return = '100';
					}
				}

			}
			echo $return;
			die();
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Ajax delete message
		 *
		 * The ajax handler to delete a message.
		 * 
		 * @return void 
		 */
		public function ajaxDeleteMsg(){
			$current_user   = Smk_Theme_User::currentUser();
			if( isset($_POST) ){
			
				$message_id = !empty($_POST['message_id']) ? $_POST['message_id'] : false;
				if( empty( $message_id ) )  die();

				$post_id = !empty($_POST['post_id']) ? $_POST['post_id'] : false;
				if( empty( $post_id ) )  die();

				$saved_messages = get_post_meta($post_id, 'smk_private_messages_list', true);
				// If the request comes from comment author allow to delete
				if( $current_user->ID == $saved_messages[$message_id]['from'] || current_user_can('create_users') ){
					unset($saved_messages[$message_id]);
					update_post_meta($post_id, 'smk_private_messages_list', $saved_messages);
				}

				$msg_to_list    = new Smk_Private_Messages_List($current_user);

				$saved_messages = get_post_meta($post_id, 'smk_private_messages_list', true);
				$msg_to_list->theMessages($saved_messages, $post_id);
			}
			die();
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Ajax mark discussion as important
		 *
		 * The ajax handler to mark a discussion as being important.
		 * 
		 * @return void 
		 */
		public function ajaxMarkAsImportant(){
			$current_user   = Smk_Theme_User::currentUser();
			$d = 'error';
			if( isset($_POST) ){
			
				$post_id = !empty($_POST['post_id']) ? $_POST['post_id'] : false;
				if( empty( $post_id ) )  die();

				$receiver_id = get_post_meta( $post_id, 'smk_pm_receiver', true );
				$sender_id = get_post_meta( $post_id, 'smk_pm_sender', true );
				$imp_receiver = get_post_meta( $post_id, 'smk_pm_important_for_receiver', true );
				$imp_sender = get_post_meta( $post_id, 'smk_pm_important_for_sender', true );

				if( $current_user->ID == $receiver_id ){
					$k = 'smk_pm_important_for_receiver';
					if( $imp_receiver ) { 
						delete_post_meta($post_id, $k); 
						$d = 'unmarked';
					}
					else{
						update_post_meta($post_id, $k, $receiver_id);
						$d = 'marked';
					}
				}
				elseif( $current_user->ID == $sender_id ){
					$k = 'smk_pm_important_for_sender';
					if( $imp_sender ) { 
						delete_post_meta($post_id, $k);
						$d = 'unmarked';
					}
					else{
						update_post_meta($post_id, $k, $sender_id);
						$d = 'marked';
					}
				}
				else{
					die();
				}

			}
			die($d);
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Add a new PM for a user
		 *
		 * Description
		 *
		 * @param type var  
		 * @return var 
		 */
		public function addNewPm( $user_id, $post_id ){
			$previous = get_user_meta( $user_id, 'st_new_pm', true);
			$previous = (!empty($previous) && is_array($previous)) ? $previous : array();
			if( ! in_array($post_id, $previous) ){
				$new = array_merge($previous, (array) $post_id);
				update_user_meta( $user_id, 'st_new_pm', $new);
			}
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Remove a new PM
		 *
		 * Remove a PM from the list of new messages
		 *
		 * @param int $user_id The user ID that has this PM in its list  
		 * @param int $post_id The discussion ID  
		 * @return void
		 */
		public function removeNewPm( $user_id, $post_id ){
			$previous = get_user_meta( $user_id, 'st_new_pm', true);
			$previous = (!empty($previous) && is_array($previous)) ? $previous : array();
			if( in_array($post_id, $previous) ){
				if( ($key = array_search($post_id, $previous)) !== false  ){
					unset($previous[$key]);
					update_user_meta( $user_id, 'st_new_pm', $previous);
				}
				
			}
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Remove all new PMs
		 *
		 * Remove all PMs from the list of new PMs
		 *
		 * @param int $user_id Is the user ID that needs to remove the PMs  
		 * @return void 
		 */
		public function removeNewPms( $user_id ){
			delete_user_meta( $user_id, 'st_new_pm' );
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Debug
		 *
		 * This is an internal function for debugging
		 *
		 * @param array|mixed $a Variable to debug.
		 * @return string A pre code block with all data printed. 
		 */
		public function d($a){
			echo '<pre>';
				print_r($a);
			echo '</pre>';
		}

	}
}