<?php 
if( !class_exists('Smk_Private_Messages_List') ){
	class Smk_Private_Messages_List{

		// The author object
		public  $author;

		//------------------------------------//--------------------------------------//
				
		/**
		 * Construct
		 *
		 * @param object $author The author data  
		 * @return void 
		 */
		public function __construct( $author ){
			$this->author = $author;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get the header
		 *
		 * Get the header with all links
		 * 
		 * @return string The HTML 
		 */
		public function getHeader(){
			?>

			<div class="profile-private-messages-header">
				<a href="<?php echo esc_url( add_query_arg( array( 'pm-type' => 'received' ), smk_remove_query_arg( array('pm-page', 'pm-id') ) ) ); ?>" <?php echo $this->headerActiveLink( 'received' ) ?>><?php _e('Received', 'smk_theme') ?></a>
				<a href="<?php echo esc_url( add_query_arg( array( 'pm-type' => 'sent' ), smk_remove_query_arg( array('pm-page', 'pm-id') ) ) ); ?>" <?php echo $this->headerActiveLink( 'sent' ) ?>><?php _e('Sent', 'smk_theme') ?></a> 
				<a href="<?php echo esc_url( add_query_arg( array( 'pm-type' => 'important' ), smk_remove_query_arg( array('pm-page', 'pm-id') ) ) ); ?>" <?php echo $this->headerActiveLink( 'important' ) ?>><?php _e('Important', 'smk_theme') ?></a>
			</div>
			
			<div class="profile-private-messages">
			<div class="profile-private-messages-table">
			<?php
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get the footer
		 *
		 * Get the footer
		 * 
		 * @return string The HTML 
		 */
		public function getFooter(){
			?>
			</div>
			</div>
			<div class="profile-private-messages-footer"></div>
			<?php
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Header active link
		 *
		 * Return the class active if the current link == current page.
		 *
		 * @param string $get The parameter to compare with $_GET['pm-type']
		 * @return string 
		 */
		public function headerActiveLink( $get ){
			$type = ( isset( $_GET ) && isset($_GET['pm-type']) ) ? $_GET['pm-type'] : 'received';
			return ($type == $get) ? ' class="active"' : '';	
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Pagination
		 *
		 * The pagination function for messages list
		 *
		 * @param int $total_pages The number of total pages available 
		 * @param int $pm_page The current page
		 * @return string 
		 */
		public function pagination($total_pages, $pm_page){
			if( $total_pages > 1 ){
				echo '<div class="private-messages-pagination button-block center">';
				echo '<div class="button-group">';
					for ($i=1; $i <= $total_pages; $i++) { 
						if( $pm_page == $i ){
							echo '<span class="button small primary current">'. $i .'</span>';
						}
						elseif( $i == 1 ){
							echo '<a class="button small" href="'. smk_remove_query_arg( 'pm-page' ) .'">'. $i .'</a>';
						}
						else{
							echo '<a class="button small" href="'. esc_url( add_query_arg( array( 'pm-page' => $i ) ) ) .'">'. $i .'</a>';
						}
					}
				echo '</div>';
				echo '</div>';
			}
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get sent messages list
		 *
		 * Get sent messages list for current user
		 *  
		 * @return string 
		 */
		public function getSent(){
			$posts_per_page = 30;
			$pm_page = ( !empty( $_GET['pm-page'] ) && absint($_GET['pm-page']) > 0 ) ? absint($_GET['pm-page']) : 1;
			$args = array(
				'post_type' => 'smk_private_messages',
				'author' => $this->author->ID,
				'posts_per_page' => $posts_per_page,
				'paged' => $pm_page,
			);

			$this->theQuery( $args );
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get received messages list
		 *
		 * Get received messages list for current user
		 *  
		 * @return string 
		 */
		public function getReceived(){
			$posts_per_page = 30;
			$pm_page = ( !empty( $_GET['pm-page'] ) && absint($_GET['pm-page']) > 0 ) ? absint($_GET['pm-page']) : 1;
			$args = array(
				'post_type' => 'smk_private_messages',
				'posts_per_page' => $posts_per_page,
				'paged' => $pm_page,
				'meta_query' => array(
					'relation' => 'OR',
					array(
						'key'     => 'smk_pm_in_inbox_to_receiver',
						'value'   => $this->author->ID,
						'compare' => 'IN',
					),
					array(
						'key'     => 'smk_pm_in_inbox_to_sender',
						'value'   => $this->author->ID,
						'compare' => 'IN',
					),
				),
			);

			$this->theQuery( $args );
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get important messages list
		 *
		 * Get important messages list for current user
		 *  
		 * @return string 
		 */
		public function getImportant(){
			$posts_per_page = 30;
			$pm_page = ( !empty( $_GET['pm-page'] ) && absint($_GET['pm-page']) > 0 ) ? absint($_GET['pm-page']) : 1;
			$args = array(
				'post_type' => 'smk_private_messages',
				'posts_per_page' => $posts_per_page,
				'paged' => $pm_page,
				'meta_query' => array(
					'relation' => 'OR',
					array(
						'key'     => 'smk_pm_important_for_receiver',
						'value'   => $this->author->ID,
						'compare' => 'IN',
					),
					array(
						'key'     => 'smk_pm_important_for_sender',
						'value'   => $this->author->ID,
						'compare' => 'IN',
					),
				),
			);

			$this->theQuery( $args );
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * The Query
		 *
		 * The query loop to retrieve the messages list.
		 *
		 * @param array $args WP_Query args  
		 * @return string The HTML 
		 */
		public function theQuery( $args ){
			$the_query = new WP_Query( $args );
			$pm_page   = ( !empty( $_GET['pm-page'] ) && absint($_GET['pm-page']) > 0 ) ? absint($_GET['pm-page']) : 1;
			
			// The Loop
			if ( $the_query->have_posts() ) {
				while ( $the_query->have_posts() ) {
					$the_query->the_post();
					$this->message();
				}

				$total_pages = $the_query->max_num_pages;
				$this->pagination($total_pages, $pm_page);

			} else {
				echo '<div class="profile-section-message clearfix">' . __('No messages found.', 'smk_theme') .'</div>';
			}

			wp_reset_postdata();
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get new messages
		 *
		 * Get the new messages HTML for the surrent user.
		 * 
		 * @return string The HTML 
		 */
		public function getNew(){

			$nothing = '<div class="no-new-private-messages clearfix">' . __('No new messages.', 'smk_theme') .'</div>';

			$args = array(
				'post_type' => 'smk_private_messages',
				'posts_per_page' => 5,
				'meta_query' => array(
					'relation' => 'OR',
					array(
						'key'     => 'smk_pm_in_inbox_to_receiver',
						'value'   => $this->author->ID,
						'compare' => 'IN',
					),
					array(
						'key'     => 'smk_pm_in_inbox_to_sender',
						'value'   => $this->author->ID,
						'compare' => 'IN',
					),
				),
			);

			$new = get_user_meta( $this->author->ID, 'st_new_pm', true);
			if( !empty($new) && is_array($new) ){
				$args['post__in'] = $new;
				
				// The Query
				$the_query = new WP_Query( $args );

				// The Loop
				if ( $the_query->have_posts() ) {
					while ( $the_query->have_posts() ) {
						$the_query->the_post();

						$url = smk_add_query_arg( array( 'profile-section' => 'pm', 'pm-id' => get_the_ID() ), get_author_posts_url( $this->author->ID ) );
						$messages = get_post_meta( get_the_ID(), 'smk_private_messages_list', true );
									end($messages);
									$last = key($messages);
						$last_message = $messages[$last];

					?>
						<div class="note clearfix">
							<a href="<?php echo $url; ?>">
								<div class="user-message">
									<?php echo get_avatar( absint($last_message['from']), 50 ); ?>
									<div class="username"><?php echo get_the_author_meta( 'display_name', absint($last_message['from']) ); ?></div>
									<div class="message"><?php echo convert_smilies( $this->excerpt( $last_message['message'], 6 ) ); ?></div>
									<div class="date"><?php echo $this->discussionTime(); ?></div>
									<i class="fa fa-envelope-o type"></i>
								</div>
							</a>
						</div>
					<?php

					}
				}
				else {
					echo $nothing;
				}
			}
			else {
				echo $nothing;
			}
		
			wp_reset_postdata();
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Total new messages
		 *
		 * Total new message that the current user has
		 *
		 * @return int The number 
		 */
		public function getNewTotal(){
			$new = get_user_meta( $this->author->ID, 'st_new_pm', true);
			return ( is_array($new) ) ? count($new) : 0;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * A single message from list
		 *
		 * A single message from the messages list
		 * 
		 * @return string The HTML 
		 */
		public function message(){
			$post_id = get_the_ID();
			$url = smk_add_query_arg( array( 'pm-id' => $post_id ) );
			$messages = get_post_meta( $post_id, 'smk_private_messages_list', true );
						end($messages);
						$last = key($messages);
			$last_message = $messages[$last];
			$unread_for_sender = get_post_meta($post_id, 'smk_pm_unread_for_sender', true);
			$unread_for_receiver = get_post_meta($post_id, 'smk_pm_unread_for_receiver', true);
			$unread = ( $unread_for_sender == $this->author->ID || $unread_for_receiver == $this->author->ID ) ? ' unread' : '';
			$total = ( is_array($messages) ) ? count( $messages ) : 1;

			?>
			<div class="td-row<?php echo $unread; ?> clearfix">
				<div class="td userphoto">
					<a href="<?php echo $url; ?>"><span class="td-in"><?php echo get_avatar( absint($last_message['from']), 24 ); ?></span></a>
				</div>
				<div class="td username">
					<a href="<?php echo $url; ?>"><span class="td-in"><?php 
						echo get_the_author_meta( 'display_name', absint($last_message['from']) );
						echo ( $total > 1 ) ? ' ('. $total .')' : ''; 
					?></span></a>
				</div>
				<div class="td content">
					<a href="<?php echo $url; ?>"><span class="td-in">
					<?php
						echo $this->excerpt( $last_message['message'] );
					?>
					</span></a>
				</div>
				<div class="td time"><span class="td-in"><?php echo $this->discussionTime(); ?></span></div>
				<div class="td important">
					<span class="td-in">
					<?php 

						$receiver_id = get_post_meta( $post_id, 'smk_pm_receiver', true );
						$sender_id = get_post_meta( $post_id, 'smk_pm_sender', true );
						$imp_receiver = get_post_meta( $post_id, 'smk_pm_important_for_receiver', true );
						$imp_sender = get_post_meta( $post_id, 'smk_pm_important_for_sender', true );

						if( in_array($this->author->ID, array($receiver_id, $sender_id)) && in_array($this->author->ID, array($imp_receiver, $imp_sender)) ){
							$active = ' active';
							$icon = '<i class="fa fa-check-circle"></i>';
						}
						else{
							$active = '';
							$icon = '<i class="fa fa-circle-o"></i>';
						}
						echo '<span data-post="'. $post_id .'" class="pm-mark-as-important'. $active .'" title="'. __('Mark as important', 'smk_theme') .'">
							'. $icon .'
						</span>'; 
					?>
					</span>
				</div>
			</div>
			<?php
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Show messages page
		 *
		 * Show the massages list or a discussion, based on $_GET
		 *
		 * @return string The HTML 
		 */
		public function show(){
			$user = Smk_Theme_User::currentUser();
			$form = new Smk_Private_Messages_Form;
			if( $user->ID == $this->author->ID || current_user_can('create_users') ){
				$this->getHeader();
				if( isset($_GET['pm-id']) ){
					$id = ( absint($_GET['pm-id']) == $_GET['pm-id']) ? absint($_GET['pm-id']) : false;
					$this->getDiscussion( $id );
				}
				elseif( isset($_GET['pm-type']) ){
					if( $_GET['pm-type'] == 'received' ){
						$this->getReceived();
					}
					elseif( $_GET['pm-type'] == 'sent' ){
						$this->getSent();
					}
					elseif( $_GET['pm-type'] == 'important' ){
						$this->getImportant();
					}
				}
				else{
					$this->getReceived();
				}
				$this->getFooter();

				// If the current user is brwsing the inbox, mark as no new messages available
				if( $user->ID == $this->author->ID ){
					$form->removeNewPms( $user->ID );
				}
			}	
			else{
				echo '<div class="profile-section-message clearfix">' . __('Error.', 'smk_theme') .'</div>';
			}
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * The discussion time
		 *
		 * Build the discussion human readable time
		 *
		 * @return string 
		 */
		public function discussionTime(){
			$stamp = get_the_time( 'U' );
			$time = (int) abs( time() - $stamp );
			if( $time < WEEK_IN_SECONDS ){
				return human_time_diff( get_the_time( 'U' ), current_time('timestamp') ) . ' '. __('ago', 'smk_theme');
			}
			else{
				return get_the_time( 'M d, Y' );
			}
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get a disscusion
		 *
		 * Get a discussion HTML. Displays all messages.
		 *
		 * @param string $id The ID of a discussion  
		 * @return string The HTML 
		 */
		public function getDiscussion( $id ){
			// If post exists
			if ( false !== get_post_status( $id ) ) {

				$user = Smk_Theme_User::currentUser();
				$form = new Smk_Private_Messages_Form;
				$the_sender_id = get_post_meta($id, 'smk_pm_sender', true);
				$the_receiver_id = get_post_meta($id, 'smk_pm_receiver', true);
				$saved_messages = get_post_meta($id, 'smk_private_messages_list', true);
				$unread_for_sender = get_post_meta($id, 'smk_pm_unread_for_sender', true);
				$unread_for_receiver = get_post_meta($id, 'smk_pm_unread_for_receiver', true);

				// If this user is the author.
				if( in_array($user->ID, array($the_sender_id, $the_receiver_id) ) ){

					echo '<div class="private-messages-single">';
							$this->theMessages($saved_messages, $id);
					echo '</div>';
				
					if( $unread_for_sender == $this->author->ID ){
						delete_post_meta($id, 'smk_pm_unread_for_sender');
					}
					elseif( $unread_for_receiver == $this->author->ID ){
						delete_post_meta($id, 'smk_pm_unread_for_receiver');
					}
					$form->removeNewPm( $user->ID, $id );
					$form->form( $this->author, 'reply', $id );
				}


			} else {
			}
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * The Messages
		 *
		 * Display the messages from a discussion.
		 *
		 * @param array $the_messages The array with all messages  .
		 * @param string $discussion_id The discussion ID to get messages from.
		 * @return string The messages HTML
		 */
		public function theMessages( $the_messages, $discussion_id = false ){
			if( !empty($the_messages) ){
				if( is_array($the_messages) ){
					$date = '';
					$user_av = '';
					$me = '';
					$the_avatar = '';
					foreach ($the_messages as $key => $message) {
						
						if( date('d F Y', $message['date'] ) != $date ){
							$date = date('d F Y', $message['date'] );
							$date_echo = (date('d F Y', $message['date'] ) == date('d F Y') ) ? __('Today', 'smk_theme') : date('d F Y', $message['date'] );
							$user_av = '';

							echo '<div class="pm-single-month"><span>'. $date_echo .'</span></div>';
						}

						$me = ( $this->author->ID == $message['from'] ) ? ' me' : '';
						$discussion_id = ($discussion_id) ? $discussion_id : '';

						?>
						<div class="single-message<?php echo $me; ?>" data-id="<?php echo $key; ?>">
							<?php 
								if( get_avatar( $message['from'], 50 ) != $user_av ){
									$user_av = get_avatar( $message['from'], 50 );
									$the_avatar = '<a href="'. get_author_posts_url( $message['from'] ) .'" title="'. get_the_author_meta( 'display_name', $message['from'] ) .'" class="msg-avatar">'. $user_av .'</a>';
									$continued = '';
								}
								else{
									$the_avatar = '';
									$continued = ' continued';
								}
							?>
							<div class="msg-body<?php echo $continued; ?>">
								<?php 
									if( ( $this->author->ID == $message['from'] || current_user_can('create_users') ) && $key != 0 ) {
										echo '<div class="msg-controls">';
											// echo '<span class="msg-edit" data-id="'. $key .'" data-post="'. $discussion_id .'"><i class="fa fa-pencil"></i></span>';
											echo '<span class="msg-delete" data-id="'. $key .'" data-post="'. $discussion_id .'"><i class="fa fa-trash"></i></span>';
										echo '</div>';
									}
									echo $the_avatar; 
								?>
								<div class="content">
									<span class="msg-date"><?php echo date('H:i', $message['date'] ); ?></span>
									<?php echo convert_smilies( wpautop( $message['message'] ) ); ?>
								</div>
							</div>
						</div>
						<?php
					}
				}
			}
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Excerpt
		 *
		 * Get the excerpt
		 *
		 * @param string $text  
		 * @param int $len Number of words 
		 * @param string $trim 
		 * @return string
		 */
		public function excerpt($text = '', $len = 20, $trim = "..."){
			$limit = $len+1;
			$text = wp_strip_all_tags( $text );
			$excerpt = explode(' ', $text, $limit);
			$num_words = count($excerpt);

			if($num_words >= $len){
				$last_item = array_pop($excerpt);
			}
			else{
				$trim = '';
			}
			$excerpt = implode(" ", $excerpt) . $trim;
			
			return $excerpt;
		}

	}
}