<?php
/*
-------------------------------------------------------------------------------
Create the custom post type
-------------------------------------------------------------------------------
*/
class Smk_User_Reputation{
	public $id;
	public $regcpt = 'register_post_type';

	public function __construct( $id ){
		$this->id = $id;
		add_action( 'init', array( $this, 'postType' ) );
	}

	//------------------------------------//--------------------------------------//
			
	/**
	 * Register Post type
	 *
	 * Register Custom Post Type
	 * 
	 * @action-hook init
	 * 
	 * @return void 
	 */
	public function postType(){

		// Create The Labels (Output) For The Post Type
		$labels = array(
			'name'               => __('Reputation', 'smk_theme'), 
			'singular_name'      => __('Reputation', 'smk_theme'),
			'add_new'            => _x('Add Reputation', 'portfolio', 'smk_theme'), 
			'edit_item'          => __('Edit Reputation', 'smk_theme'),
			'new_item'           => __('New Reputation', 'smk_theme'), 
			'view_item'          => __('View Reputation', 'smk_theme'),
			'search_items'       => __('Search Reputation', 'smk_theme'), 
			'not_found'          => __('No Reputation Found', 'smk_theme'),
			'not_found_in_trash' => __('No Reputation Found In Trash', 'smk_theme'),
			'parent_item_colon'  => '' 
		);
		
		// Set Up The Arguements
		$args = array(
			'labels'             => $labels, 
			'public'             => false, 
			'has_archive'        => false,
			'publicly_queryable' => false, 
			'show_ui'            => false, 
			'query_var'          => true, 
			'rewrite'            => array(
				'slug' => 'smk-user-reputation',
			),
			'capability_type'    => 'post',
			'hierarchical'       => false, 
			'show_in_nav_menus'  => false,
			'show_in_menu'       => 'users.php',
			'menu_position'      => 20, 
			'supports'           => array(
				'title',
			),
		);
		
		// Register post type
		$this->regCpt( $args );
	}

	public function regCpt( $args ){
		$fn = $this->regcpt;
		$fn( $this->id, $args );
	}

}
new Smk_User_Reputation( 'smk_user_reputation' );

/*
-------------------------------------------------------------------------------
Create the post for today
-------------------------------------------------------------------------------
*/
class Smk_Create_Reputation_Post_For_Today{
	public $user_id;
	public $the_date;
	
	public function __construct( $user_id, $the_date = false ){
		$this->user_id = $user_id;
		$this->the_date = ( $the_date ) ? $the_date : time();

		$last_post_id = $this->lastUserPost();
		if( $last_post_id == 0 ){
			$this->createNewPost();
		}
	}

	public function lastUserPost(){
		$last_id = false;
		$args = array(
			'author' => $this->user_id, 
			'post_type' => 'smk_user_reputation',
			'orderby' => 'date',
			'order' => 'DESC',
			'posts_per_page' => 1,
			'meta_query' => array(
				array(
					'key'     => 'smk_reputation_day',
					'value'   => date("j-n-Y", $this->the_date),
					'compare' => 'IN',
				),
			),
		);
		$the_query = get_posts( $args );

		if( !empty($the_query) ){
			$the_post = $the_query[0];
			$last_id = $the_post->ID;
		}

		return absint($last_id);
	}

	public function createNewPost(){
		$date   = date("j-n-Y", $this->the_date);
		$author = $this->user_id;

		$post_data = array(
			'post_title'     => $date,
			'post_status'    => 'publish',
			'post_type'      => 'smk_user_reputation',
			'post_author'    => $author,
			'ping_status'    => 'closed',
			'comment_status' => 'closed',
			'post_date'      => date("Y-m-d H:i:s", $this->the_date),
		); 
		$post_id = @wp_insert_post( $post_data );

		if( !empty($post_id) && $post_id > 0 ){
			update_post_meta( $post_id, 'smk_reputation_day', date("j-n-Y", $this->the_date) );
			update_post_meta( $post_id, 'smk_reputation_total', '0' );
		}
	}

}

/*
-------------------------------------------------------------------------------
Create the reputation for today
-------------------------------------------------------------------------------
*/
class Smk_Add_User_Reputation{
	public $user_id;
	public $value;
	public $reason;
	public $other_settings;
	public $the_date;

	public function __construct( $user_id, $post_id, $value, $reason = '', $other_settings = false, $the_date = false ){
		$this->user_id        = $user_id;
		$this->value          = $value;
		$this->reason         = $reason;
		$this->other_settings = $other_settings;
		$this->the_date       = ( $the_date ) ? $the_date : time();

		$this->updateMeta( $post_id );
		$this->updateUserRep();
	}

	public function updateMeta( $post_id = false ){
		$post_id = ( $post_id ) ? $post_id : false;
		if( !empty($post_id) ){
			$total_per_today = get_post_meta( $post_id, 'smk_reputation_total', true );
			$post_reasons    = get_post_meta( $post_id, 'smk_reputation_reasons', true );
			$post_reasons    = ( is_array($post_reasons) ) ? $post_reasons : array();
			$post_reasons[]  = array(
				'value'  => $this->value,
				'time'   => $this->the_date,
				'reason' => $this->reason,
				'other_settings' => $this->other_settings
			);
			update_post_meta( $post_id, 'smk_reputation_reasons', $post_reasons );
			update_post_meta( $post_id, 'smk_reputation_total', intval( $total_per_today ) + $this->value );
		}
	}

	public function updateUserRep(){
		$previous_rep = get_user_meta( $this->user_id, 'st_reputation', true );
		$new_rep = absint( $previous_rep ) + $this->value;
		$new_rep = ( $new_rep > 1 )	? $new_rep : 1;
		update_user_meta( $this->user_id, 'st_reputation', $new_rep );
	}

}

/*
-------------------------------------------------------------------------------
The short function to insert the reputation
-------------------------------------------------------------------------------
*/
function smk_insert_user_reputation( $user_id, $value, $reason = '', $other_settings = false, $the_date = false ){
	if( $value != 0 ){
		$the_main_post = new Smk_Create_Reputation_Post_For_Today( $user_id, $the_date );
		$main_post_id  = $the_main_post->lastUserPost();
		
		new Smk_Add_User_Reputation( $user_id, $main_post_id, $value, $reason, $other_settings, $the_date );
	}
}


/*
-------------------------------------------------------------------------------
Remove reputation
-------------------------------------------------------------------------------
*/
function smk_recipes_remove_reputation(){
	if( !empty($_GET['action']) && 'smk_recipes_remove_reputation' == $_GET['action'] ){
		if( current_user_can('edit_users') && !empty($_GET['activity']) && isset( $_GET['key']) && !empty($_GET['_nonce']) ){
			$id    = (int) $_GET['activity'];
			$key   = (int) $_GET['key'];
			$nonce = esc_html( $_GET['_nonce'] );
			if( wp_verify_nonce( $nonce, 'smk_recipes_remove_reputation' ) ){
				$total_per_today = get_post_meta( $id, 'smk_reputation_total', true );
				$post_msg        = get_post_meta( $id, 'smk_reputation_reasons', true );
				$points_value    = isset($post_msg[ $key ]['value']) ? (int) $post_msg[ $key ]['value'] : 0;
				$user_id         = get_post_field('post_author', $id);

				if( isset($post_msg[ $key ]) ){
					unset( $post_msg[ $key ] );

					/* Update meta or remove the post
					------------------------------------------------*/
					if( !empty($post_msg) ){
						$post_msg = array_values($post_msg);
						// Update meta
						update_post_meta( $id, 'smk_reputation_reasons', $post_msg );
						update_post_meta( $id, 'smk_reputation_total', intval( $total_per_today ) - intval( $points_value ) );

					}
					else{
						// Delete the post
						wp_delete_post( $id, true );
					}

					/* Update user reputation
					------------------------------------------------*/
					$previous_rep = get_user_meta( $user_id, 'st_reputation', true );
					$new_rep = absint( $previous_rep ) - intval( $points_value );
					$new_rep = ( $new_rep > 1 )	? $new_rep : 1;
					update_user_meta( $user_id, 'st_reputation', $new_rep );
				}

			}
		}
	}
}
add_action('init', 'smk_recipes_remove_reputation');

/*
-------------------------------------------------------------------------------
Remove reputation via ajax
-------------------------------------------------------------------------------
*/
add_action('wp_ajax_smk_recipes_remove_reputation', 'smk_recipes_remove_reputation_ajax');
function smk_recipes_remove_reputation_ajax(){
	wp_die( 'ok' );
}