<?php 
if( !class_exists('Smk_User_Settings_Form') ){
	class Smk_User_Settings_Form{

		public $author;

		public function __construct( $author ){
			$this->author = $author;
			add_action('wp_ajax_smk_user_settings_form_ajax_handler', array( $this, 'ajaxFormHandler' ));
		}

		public function fields(){
			return apply_filters('smk_user_settings_form_fields', array());
		}

		public function showForm(){
			$current_user = Smk_Theme_User::currentUser();
			if( $current_user->ID == $this->author->ID || current_user_can('edit_users') ){
				echo '<div class="grid-container clearfix">';
				echo '<form method="post" id="smk-theme-user-settings-form">';
				echo '<input type="hidden" name="user_id" value="'. $this->author->ID .'" />';
					do_action('smk_user_settings_form', $this->author);
				echo '<button id="smk-theme-user-settings-submit-button" type="submit" href="#" class="button primary">'. __('Submit', 'smk_theme') .'</button>';
				echo '</form>';
				echo '</div>';
			}
		}

		public function ajaxFormHandler(){
			echo 'ok' . $this->author->ID;
			die();
		}

	}
}

if( !class_exists('Smk_User_Settings_Add_Field') ){
	class Smk_User_Settings_Add_Field{

		public function __construct( $id, $settings = array() ){
			$this->id       = $id;
			$this->settings = $settings;
			add_action( 'smk_user_settings_form', array($this, 'addRow') );
			add_filter( 'smk_user_settings_form_fields', array($this, 'regField') );
		}

		public function addRow( $author ){
			$defaults = array(
				'label' => '',
				'desc'  => '',
				'grid'  => '12',
				'header' => '',
				'clear' => false,
			);
			$settings = wp_parse_args( $this->settings, $defaults );

			$output = '';
			if( !empty($settings['header']) ){
				$output .='<p></p><h5>'. $settings['header'] .'</h5>';
			}
			$output .= '<div class="grid desk-'. $settings['grid'] .'">';
				if( !empty($settings['label']) ){
					$output .='<div class="form-label">'. $settings['label'] .'</div>';
				}
				if( !empty($settings['desc']) ){
					$output .='<div class="form-description">'. $settings['desc'] .'</div>';
				}
				$output .= $this->inputField( $author, $this->id, $settings );
			$output .='</div>';
			if( strpos($settings['grid'], 'both') || strpos($settings['grid'], 'omega') || $settings['clear'] ){
				$output .='<div class="clear"></div>';
			}
			echo  $output;
		}

		public function inputField( $author, $id, $settings = array() ){
			$defaults = array(
				'value' => '',
				'field_type' => 'text',
				'class' => '',
				'id' => '',
			);
			$s = wp_parse_args( $settings, $defaults );
			$value = $this->getMeta($author, $id);
			$value = !empty($value) ? $value : '';
			$field_id = !empty($s['field_id']) ? ' id="'. $s['field_id'] .'"' : '';

			switch ($s['field_type']) {
				case 'text':
				case 'email':
				case 'password':
					return '<input'. $field_id .' type="'. $s['field_type'] .'" name="'. $id .'" value="'. $value .'" class="smk-field smk-field-'. $id .' '. $s['class'] .'">';
					break;
				
				case 'avatar':
					return smk_submit_recipe_upload($id, $value, 'size-medium', 'smk-field-' . $id);
					break;

				case 'textarea':
					return '<textarea'. $field_id .' name="'. $id .'" class="smk-field smk-field-'. $id .' '. $s['class'] .'">'. $value .'</textarea>';
					break;

				case 'display_name':
					$display_name_select = '<select'. $field_id .' name="'. $id .'" class="smk-field smk-field-'. $id .' '. $s['class'] .'">';
		
						$public_display = array();
						$public_display['display_nickname']  = $author->nickname;
						$public_display['display_username']  = $author->user_login;

						if ( !empty($author->first_name) )
							$public_display['display_firstname'] = $author->first_name;

						if ( !empty($author->last_name) )
							$public_display['display_lastname'] = $author->last_name;

						if ( !empty($author->first_name) && !empty($author->last_name) ) {
							$public_display['display_firstlast'] = $author->first_name . ' ' . $author->last_name;
							$public_display['display_lastfirst'] = $author->last_name . ' ' . $author->first_name;
						}

						if ( !in_array( $author->display_name, $public_display ) ) // Only add this if it isn't duplicated elsewhere
							$public_display = array( 'display_displayname' => $author->display_name ) + $public_display;

						$public_display = array_map( 'trim', $public_display );
						$public_display = array_unique( $public_display );

						foreach ( $public_display as $id => $item ) {
							$display_name_select .= '<option '. selected( $author->display_name, $item, false ) .'>'. $item .'</option>';
						}
					$display_name_select .= '</select>';
					return $display_name_select;
					break;
					
				case 'user_email':
					$value = get_the_author_meta( 'user_email', $author->ID );
					return '<input'. $field_id .' type="text" name="'. $id .'" value="'. $value .'" class="smk-field smk-field-'. $id .' '. $s['class'] .'">';
					break;

				case 'user_url':
					$value = get_the_author_meta( 'user_url', $author->ID );
					return '<input'. $field_id .' type="text" name="'. $id .'" value="'. $value .'" class="smk-field smk-field-'. $id .' '. $s['class'] .'">';
					break;

				case 'password_meter':
					return '<div'. $field_id .' class="smk-password-meter"><div class="meter-ind"></div></div>';
					break;
				
			}
		}

		public function getMeta( $author, $id ){
			return get_user_meta( $author->ID, $id, true );
		}

		public function regField( $fields ){
			$fields[$this->id] = $this->settings;
			return $fields;
		}

	}
}

if( !class_exists('Smk_User_Settings') ){
	class Smk_User_Settings{

		public function initAjax(){
			add_action('wp_ajax_smk_user_settings_form_ajax_handler', array( $this, 'ajaxFormHandler' ));
		}

		public function ajaxFormHandler(){
			$messages     = array();
			$current_user = Smk_Theme_User::currentUser();
			$all_fields   = $this->fields();
			$form_data    = !empty($_POST['data']) ? $_POST['data'] : false;

			if( empty( $form_data ) ) die();
			parse_str($form_data, $data); // Convert jQuery serialized data to a PHP array
			if( empty($data['user_id']) ) die();

			if( $current_user->ID == $data['user_id'] || current_user_can('edit_users') ){
				$new_data = array();

				foreach ($all_fields as $field_id => $field_value) {
					if( in_array($field_id, array( 'pass1', 'pass2', 'password_meter', 'display_nickname' )) ) continue;

					switch ($field_value['field_type']) {
						case 'text':
							if( $field_id == 'nickname' ){
								$new_data[ $field_id ] = sanitize_text_field( $data[ $field_id ] );
								if( empty($new_data[ $field_id ]) ) {
									$messages[ $field_id ] = __('Invalid nickname', 'smk_theme');
								}
							}
							else{
								$new_data[ $field_id ] = sanitize_text_field( $data[ $field_id ] );
							}
							break;
						
						case 'avatar':
							$avatar_url = ( !empty($data[ $field_id ]) ) ? $data[ $field_id ] : '';
							$new_data[ $field_id ] = esc_url( $avatar_url );
							break;
						
						case 'user_url':
							$user_url = ( !empty($data[ $field_id ]) ) ? $data[ $field_id ] : '';
							$new_data[ $field_id ] = esc_url( $user_url );
							break;
						
						case 'textarea':
							$allowed_html = wp_kses_allowed_html( 'user_description' );
							$new_data[ $field_id ] = wp_kses( $data[ $field_id ], $allowed_html );
							break;
						
						case 'user_email':
							if( is_email( $data[ $field_id ] ) ){
								if( email_exists( $data[ $field_id ] ) ){
									if( get_the_author_meta( 'user_email', $data['user_id'] ) != $data[ $field_id ] ){
										$messages[ $field_id ] = __('This email address is already in use by another user.', 'smk_theme');
									}
								}
								else{
									$new_data[ $field_id ] = $data[ $field_id ];
								}
							}
							else{
								$messages[ $field_id ] = __('Invalid email address.', 'smk_theme');
							}
							break;
						
						default:
							$new_data[ $field_id ] = sanitize_text_field( $data[ $field_id ] );
							break;
					}

				}

				if( !empty($data[ 'pass1' ]) ){
					$pass2 = empty($data[ 'pass2' ]) ? '' : $data[ 'pass2' ];
					if( $data[ 'pass1' ] !== $pass2 ){
						$messages[ 'pass2' ] = __('Password mismatch.', 'smk_theme');
					}
				}

				if( empty($messages) ){
					foreach ($all_fields as $field_id => $field_value) {
						if( in_array($field_id, array( 'email', 'pass1', 'pass2', 'password_meter', 'display_nickname', 'url' )) ) continue;
						update_user_meta( $data['user_id'], $field_id, $new_data[ $field_id ] );
					}


					if( !empty($data[ 'display_nickname' ]) ){
						$args = array(
							'ID'           => $data['user_id'],
							'display_name' => $data[ 'display_nickname' ],
						);
						wp_update_user( $args );
					}

					if( !empty($new_data[ 'email' ]) ){
						if( get_the_author_meta( 'user_email', $data['user_id'] ) != $new_data[ 'email' ] ){
							$args = array(
								'ID'         => $data['user_id'],
								'user_email' => $new_data[ 'email' ],
							);
							wp_update_user( $args );
						}
					}

					if( !empty($new_data[ 'url' ]) ){
						$args = array(
							'ID'         => $data['user_id'],
							'user_url'   => $new_data[ 'url' ],
						);
						wp_update_user( $args );
					}

					if( !empty($data[ 'pass1' ]) ){
						$args = array(
							'ID'         => $data['user_id'],
							'user_pass'  => $data[ 'pass1' ],
						);
						wp_update_user( $args );
					}
					$messages[ 'msg_type' ] = 'success';
					$messages[ 'message' ] = __('Your profile settings has been successfully updated.', 'smk_theme');
					echo json_encode( $messages );
				}
				else{
					$messages[ 'msg_type' ] = 'error';
					echo json_encode( $messages );
				}
				// print_r($messages);
				// print_r($new_data);
				// print_r($data);

				
			} // If is this user or can edit these settings

			die();
		}

		public function fields(){
			return apply_filters('smk_user_settings_form_fields', array());
		}

		public function addField( $id, $settings = array() ){
			$addField = new Smk_User_Settings_Add_Field( $id, $settings );
		}
	}
}

$form    = new Smk_User_Settings();
$form->initAjax();


$form->addField('custom_user_avatar', array(
	'label'      => __('Custom avatar image', 'smk_theme'),
	'field_type' => 'avatar',
	'grid'       => '12 both',
));
$form->addField('first_name', array(
	'label'      => __('First Name', 'smk_theme'),
	'field_type' => 'text',
	'grid'       => '6 alpha',
	'class'      => 'fullwidth',
));
$form->addField('last_name', array(
	'label'      => __('Last Name', 'smk_theme'),
	'field_type' => 'text',
	'grid'       => '6 omega',
	'class'      => 'fullwidth',
));
$form->addField('nickname', array(
	'label'      => __('Nickname (required)', 'smk_theme'),
	'field_type' => 'text',
	'grid'       => '6 alpha',
	'class'      => 'fullwidth',
));
$form->addField('display_nickname', array(
	'label'      => __('Display name publicly as', 'smk_theme'),
	'field_type' => 'display_name',
	'grid'       => '6 omega',
	'class'      => 'fullwidth',
));
$form->addField('email', array(
	'label'      => __('Email (required)', 'smk_theme'),
	'field_type' => 'user_email',
	'grid'       => '6 alpha',
	'class'      => 'fullwidth',
));
$form->addField('url', array(
	'label'      => __('Website', 'smk_theme'),
	'field_type' => 'user_url',
	'grid'       => '6 omega',
	'class'      => 'fullwidth',
	// 'desc'    => __('If you have your personal website, add its address here.', 'smk_theme'),
));
$form->addField('st_location', array(
	'label'      => __('Location', 'smk_theme'),
	'field_type' => 'text',
	'grid'       => '6 both',
	'class'      => 'fullwidth',
	'desc'       => __('Share your location. Write the country name followed by the city name.', 'smk_theme'),
));
$form->addField('description', array(
	'label'      => __('Biographical Info', 'smk_theme'),
	'field_type' => 'textarea',
	'grid'       => '12 both',
	'class'      => 'fullwidth normal',
	'header'     => __('About Yourself', 'smk_theme'),
	'desc'       => __('Share a little biographical information to fill out your profile.', 'smk_theme'),
));

$soc = array(
	'st_social_facebook'    => __('Facebook', 'smk_theme'),
	'st_social_twitter'     => __('Twitter', 'smk_theme'),
	'st_social_google_plus' => __('Google+', 'smk_theme'),
	'st_social_vimeo'       => __('Vimeo', 'smk_theme'),
	'st_social_youtube'     => __('Youtube', 'smk_theme'),
);

$count = 1;
foreach ($soc as $key => $value) {
	$sett = array(
		'label'      => $value,
		'field_type' => 'text',
		'grid'       => '8 both',
		'class'      => 'fullwidth',
	);
	$sett['header'] = ( $count == 1 ) ? __('Social networks', 'smk_theme') : '';

	$form->addField($key, $sett);
	$count++;
}

$form->addField('pass1', array(
	'field_type' => 'password',
	'field_id'   => 'smk-user-settings-password',
	'label'      => __('New Password', 'smk_theme'),
	'grid'       => '6 alpha',
	'class'      => 'fullwidth',
	'header'     => __('Change your password', 'smk_theme'),
	'desc'       => __('If you would like to change the password type a new one. Otherwise leave this blank.', 'smk_theme'),
));
$form->addField('pass2', array(
	'field_type' => 'password',
	'field_id'   => 'smk-user-settings-password-confirm',
	'label'      => __('Repeat New Password', 'smk_theme'),
	'grid'       => '6 omega',
	'class'      => 'fullwidth',
	'desc'       => __('Type your new password again.', 'smk_theme'),
));
$form->addField('password_meter', array(
	'field_type' => 'password_meter',
	'field_id'   => 'smk-user-settings-password-meter',
	'grid'       => '6 alpha',
	'clear'      => true,
));