<?php
if( class_exists( 'Smk_Theme_User' ) && ! class_exists('Smk_Theme_User_LastVisit') ){
	class Smk_Theme_User_LastVisit extends Smk_Theme_User{
		
		public function settings(){

			$current_user = $this->currentUser();
			$regdate      = $current_user->user_registered;
			$date         = date_create($regdate);
			$new_regdate  = date_format($date, 'U');

			return array(
				'id'    => 'st_last_visit',
				'std'   => $new_regdate,
				'title' => __('Last visit', 'smk_theme'),
			);
		}
		
		//------------------------------------//--------------------------------------//
				
		/**
		 * Validate date
		 *
		 * Validate date if it is a real date.
		 *
		 * @param string $date The date to be validated  
		 * @param string $format The date format  
		 * @return bool
		 */
		public function validateDate( $date, $format = 'Y-m-d H:i:s' ){
			if( !is_string($date) ) 
				return false;
			$d = DateTime::createFromFormat($format, $date);
			return $d && $d->format($format) == $date;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get the saved date
		 *
		 * Get the saved unix date
		 * 
		 * @return string 
		 */
		public function getSavedDate(){
			$meta = $this->getMeta();
			if( !empty( $meta ) ){
				if( $this->validateDate( $meta, 'U' ) ){
					$date = $meta;
				}
				else{
					$this->deleteMeta();
					$date = $this->getMeta();
				}
			}
			return $date;
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Get last user visit period
		 *
		 * Display how much time passed since last user visit
		 *
		 * @param bool $array Return array or string. false = string
		 * @return string|array 
		 */
		public function show(){

			$date = $this->getSavedDate();
			
			if(empty($date)) {
				return __('Unknown', 'smk_theme');
			}
			
			$periods_single = array(
				__('second', 'smk_theme'), 
				__('minute', 'smk_theme'), 
				__('hour', 'smk_theme'), 
				__('day', 'smk_theme'), 
				__('week', 'smk_theme'), 
				__('month', 'smk_theme'), 
				__('year', 'smk_theme'), 
				__('decade', 'smk_theme')
			);
			$periods_plural = array(
				__('seconds', 'smk_theme'), 
				__('minutes', 'smk_theme'), 
				__('hours', 'smk_theme'), 
				__('days', 'smk_theme'), 
				__('weeks', 'smk_theme'), 
				__('months', 'smk_theme'), 
				__('years', 'smk_theme'), 
				__('decades', 'smk_theme')
			);

			$lengths    = array("60", "60", "24", "7", "4.35", "12", "10");
			$now        = time();
			$unix_date  = $date;
			
			// check validity of date
			if(empty($unix_date)) {    
				return __('Bad date', 'smk_theme');
			}

			// is it future date or past date
			if($now > $unix_date) {    
				$difference    = $now - $unix_date;
				$tense         = __('ago', 'smk_theme');
				
			} else {
				$difference    = $unix_date - $now;
				$tense         = __('from now', 'smk_theme');
			}
			
			for($j = 0; $difference >= $lengths[$j] && $j < count($lengths)-1; $j++) {
				$difference /= $lengths[$j];
			}
			
			$difference = round($difference);
			$period     = ($difference != 1) ? $periods_plural[$j] : $periods_single[$j];
			
			if( ( $period == __('second', 'smk_theme') || $period == __('seconds', 'smk_theme') ) && $difference < 45 ){
				return __('just now', 'smk_theme');
			}
			else{
				return $difference . ' ' . $period . ' ' . $tense;
			}
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Get last user visit color
		 *
		 * Display the color based on the last user visit. Green: < 2 hour; Orange: < 5 hours; Gray: < 1 day; Light Gray: > 1 day;
		 *
		 * @return string 
		 */
		public function color(){
			$last_visit = $this->getSavedDate();
			$now = time();
			$difference = $now - $last_visit;
			$difference = !empty( $difference ) ? $difference : 0;
			$color = false;

			if( $difference >= 0 && $difference < 60*60*2 ){ // 2hours
				$color = 'green';
			}
			elseif( $difference >= 60*60*2 && $difference < 60*60*5 ){ // >2hours, <5hours
				$color = 'orange';
			}
			elseif( $difference >= 60*60*5 && $difference < 60*60*24 ){ // >5hours, <24hours
				$color = 'gray';
			}
			else{
				$color = 'light-gray';
			}
			return $color;
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Get last user visit in date&time format
		 *
		 * Display the last visit date and time
		 *
		 * @return string 
		 */
		public function dateAndTime( $format = 'd F Y H:i:s'){
			$date = $this->getSavedDate();
			return date_i18n($format , $date);
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Update last visit date
		 *
		 * Update last visit date
		 *
		 * @return string 
		 */
		public function updateLastVisit(){
			if( is_user_logged_in() ){
				$current_user = $this->currentUser();
				update_user_meta( $current_user->ID, 'st_last_visit', time() );
			}
		}

	}
}