<?php
if( !class_exists( 'Smk_Theme_User' ) ){
	class Smk_Theme_User{

		/**
		 * UserID
		 *
		 * Get the user id
		 * 
		 * @return string 
		 */
		public $userId;

		/**
		 * Meta key
		 *
		 * Field meta key
		 *
		 * @return string 
		 */
		public $field;

		public function __construct( $user_id = false ){
			if( $user_id !== false ){
				$this->userId = $user_id;
			}
			elseif( is_author() ){
				$this_user = $this->currentAuthor();
				$this->userId = $this_user->ID;
			}
			$this->field = $this->settings();
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Current author
		 *
		 * Get the current author on which profile page we are
		 *
		 * @return object 
		 */
		public static function currentAuthor(){
			global $wp_query;
			$curauth = $wp_query->get_queried_object();
			return $curauth;
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Current author
		 *
		 * Get the current author on which profile page we are
		 *
		 * @return int 
		 */
		public static function currentAuthorId(){
			$current_author = self::currentAuthor();
			return $current_author->ID;
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Current profile ID
		 *
		 * Get the current profile ID
		 *
		 * @return int 
		 */
		public static function currentProfileId(){
			$author_name = get_query_var( 'author_name' );
			$author = get_user_by( 'slug', $author_name );
			return ( is_object( $author ) ) ? $author->ID : 0;
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Current user
		 *
		 * Get the current user that is currently logged and is browsing the site.
		 *
		 * @return object 
		 */
		public static function currentUser(){
			global $current_user;
			get_currentuserinfo();
			return $current_user;
		}

		//------------------------------------//--------------------------------------//
		
		/**
		 * Current user
		 *
		 * Get the current user that is currently logged and is browsing the site.
		 *
		 * @return int 
		 */
		public static function currentUserId(){
			$current_user = self::currentUser();
			return $current_user->ID;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Field settings
		 *
		 * All fields settings
		 *
		 * @return array 
		 */
		public function settings(){}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Show
		 *
		 * Show the saved, formated value
		 *  
		 * @return mixed 
		 */
		public function show(){
			return $this->getMeta();
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get user meta
		 *
		 * Get the saved value or update the field if the value does not exist and return it.
		 *  
		 * @return mixed 
		 */
		public function getMeta(){
			$saved = get_user_meta($this->userId, $this->field['id'], true);
			if( empty($saved) ){
				update_user_meta( $this->userId, $this->field['id'], $this->field['std'] );
				$saved = get_user_meta($this->userId, $this->field['id'], true);
			}
			return $saved;
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Delete user meta
		 *
		 * Delete the saved value
		 *  
		 * @return mixed 
		 */
		public function deleteMeta(){
			delete_user_meta( $this->userId, $this->field['id'] );
		}

		//------------------------------------//--------------------------------------//
				
		/**
		 * Get field title
		 *
		 * Get the title set for this field.
		 *  
		 * @return string 
		 */
		public function getTitle( $custom_title = false ){
			$title = '';
			if( $custom_title ){
				$title = $custom_title;
			}
			else{
				$title = ! empty($this->field['title']) ? $this->field['title'] : '';
			}
			return $title;
		}

	}
}