<?php
/* 
 * Smk Toolkit Log page
 *
 * Display development errors in log.
 *
 * -------------------------------------------------------------------------------------
 * @Author: Smartik
 * @Author URI: http://smartik.ws/
 * @Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 * @Date:   2014-06-26 21:51:11
 * @Last Modified by:   Smartik
 * @Last Modified time: 2014-07-05 10:12:21
 *
 */
if( ! class_exists('Smk_ToolkitLogPage') ){
	class Smk_ToolkitLogPage extends Smk_AdminPage{
		public function settings(){
			return array(
				'parent_slug' => 'smk_toolkit',
				'menu_title'  => __('Log', 'smk_toolkit'),
			);
		}

		public function enqueue(){
			wp_register_style( 'smk_log_page_style', SMK_TOOLKIT_URI . 'admin/log/css/log.css', false );
			wp_enqueue_style( 'smk_log_page_style' );
		}

		public function logMsgRow($msg){
			return '<div class="smk-log-msg-row">'. $msg .'</div>';
		}

		public function logInfoTotal($label, $total = '0', $class = ''){
			$class = trim($class) !== false && absint($total) > 0 ? ' ' . $class : '';
			return '<div class="smk-log-info-total'. $class .'">'. $label .'<span>'. $total .'</span></div>';
		}

		public function page(){
			
			$log = smk_toolkit_log_messages();
			$total_messages = count($log);
			$total_e = $total_w = $total_n = $total_u = 0;

			foreach ($log as $one_msg) {
				switch ( strtolower( $one_msg['type'] ) ) {
					case 'e':
					case 'error':
						$total_e++;
						break;
					
					case 'w':
					case 'warning':
						$total_w++;
						break;
					
					case 'n':
					case 'notice':
						$total_n++;
						break;
					
					default:
						$total_u++;
						break;
				}
			}

			// Display a total info about all messages
			echo '<div class="smk-log-info-total-block">';
				echo $this->logInfoTotal('All', $total_messages, 'total-all');
				echo $this->logInfoTotal('Errors', $total_e, 'total-errors');
				echo $this->logInfoTotal('Warnings', $total_w, 'total-warnings');
				echo $this->logInfoTotal('Notices', $total_n, 'total-notices');
				echo $this->logInfoTotal('Unknown', $total_u, 'total-unknown');
			echo '</div>';

			//Display messages
			echo '<div class="smk-log">';
			if( !empty($log) && is_array($log) ){
				foreach ($log as $key => $value) {

					$msg_type = '';

					if( !empty($value['type']) ){
						switch ( strtolower( $value['type'] ) ) {
							case 'e':
							case 'error':
								$msg_type = '<span class="message-label error-label">Error:</span>';
								break;
							
							case 'w':
							case 'warning':
								$msg_type = '<span class="message-label warning-label">Warning:</span>';
								break;
							
							case 'n':
							case 'notice':
								$msg_type = '<span class="message-label notice-label">Notice:</span>';
								break;
							
							default:
								$msg_type = '<span class="message-label unknown-label">'. ucfirst( $value['type'] ) .':</span>';
								break;
						}
					}

					echo $this->logMsgRow( $msg_type . $value['msg'] );
				}
			}
			else{
				echo $this->logMsgRow( '<span class="message-label ok-label">Good:</span>'. __('Everything seems to be OK. No errors detected.', 'smk_toolkit') );
			}
			echo '</div>';

		}
	}
}
$log_page = new Smk_ToolkitLogPage('smk_log');
$log_page->init();