<?php
/* 
 * System Info
 *
 * Display detailed information about the current system.
 *
 * -------------------------------------------------------------------------------------
 * @Author: Smartik
 * @Author URI: http://smartik.ws/
 * @Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 * @Date:   2014-06-26 21:41:59
 * @Last Modified by:   Smartik
 * @Last Modified time: 2014-07-05 07:34:17
 *
 */
if( ! function_exists('add_action') ) die();

if( ! class_exists('Smk_SysInfo') ){
	class Smk_SysInfo{

		################################################################################
		
		/**
		 * Active Theme
		 *
		 * Active theme name and version.
		 *
		 * @return string 
		 */
		public function activeTheme(){
			$theme_data = wp_get_theme();
			$theme      = $theme_data->Name . ' ' . $theme_data->Version;
			return $theme;
		}

		public function sysArray(){
			$sys = array();

			$sys[] = array( 'Active theme', $this->activeTheme() );
			$sys[] = array( 'Site URL', site_url() );
			$sys[] = array( 'Home URL', home_url() );
			$sys[] = array( 'Multisite', ( is_multisite() ? 'Yes' : 'No' ) );

			$cur = get_preferred_from_update_core();
			$wp_version_gb = ( version_compare($cur->current, get_bloginfo( 'version' )) > 0 ) ? 'bad' : 'good';
			$sys[] = array( 'WordPress Version', get_bloginfo( 'version' ), $wp_version_gb, 'The latest WP version is ' . $cur->current );

			$sys[] = array( 'WordPress Language', ( defined( 'WPLANG' ) && WPLANG ? WPLANG : 'en_US' ) );
			$sys[] = array( 'Permalink Structure', ( get_option( 'permalink_structure' ) ? '<code>'. get_option( 'permalink_structure' ) .'</code>' : 'Default' ) );
			$sys[] = array( 'Show On Front', get_option( 'show_on_front' ) );
			$sys[] = array( 'PHP Version', PHP_VERSION, ( version_compare(PHP_VERSION, '5.3.0') >= 0 ) ? 'good' : 'bad', 'Required PHP 5.3+' );

			// Plugins info
			if ( ! function_exists( 'get_plugins' ) ) {
				require_once ABSPATH . 'wp-admin/includes/plugin.php';
			}

			$all_plugins = get_plugins();
			$all_available_plugins = '';
			foreach ($all_plugins as $plugin_key => $plugin_value) {
				$all_available_plugins .= '<strong>'. $plugin_value['Name'] .' '. $plugin_value['Version'] .'</strong><br>';
				$all_available_plugins .= $plugin_key . '<br><br>';
			}

			$sys[] = array( 'All available plugins', $all_available_plugins );

			return $sys;
		}

	}
}