/**
 * SMK Modal Window Plugin
 * ----------------------------------------------------
 * Author: Smartik
 * Author URL: http://smartik.ws/
 * Copyright: (c) Smartik. All rights reserved
 */
;(function ( $ ) {

	"use strict";

	$.fn.smk_Modal = function( options ) {

		/* Defaults
		-----------------------------------------------------------------*/
		var settings = $.extend({
			animationName: 'scaleUp',          // Animation name (string)
			closeBtnText: 'X',                 // Modal window close button text (string)
			closeBtn: '.sm_close',             // Modal window close button selector (string)
			targetBtn: '.smk_modal_target',    // Selector that will open modal window on click (string)
			targetBtnParent: 'body',           // Selector parent, useful if the selector which open modal window was generated by JS (string)
			contentMargin: false,              // Set content margins. Inline CSS. Accepts an integer. (integer)(a number from 0 to 100)
			maxWidth: false,                   // Maximum width in pixels. Ex: 450 (int)
			maxHeight: false,                  // Maximum width in pixels. Ex: 200 (int)
			beforeOpen: function(){},          // Execute function before modal window if open (anonymous function)
			afterOpen: function(){},           // Execute function after modal window if open (anonymous function)
			beforeClose: function(){},         // Execute function before modal window if closed (anonymous function)
			afterClose: function(){},          // Execute function after modal window if closed (anonymous function)

			//Non functional options, under development
			animation: true,                   // Enable animation (boolean) 

		}, options );

		/* Cache current instance
		// To avoid scope issues, use 'plugin' instead of 'this'
		// to reference this class from internal events and functions.
		-----------------------------------------------------------------*/
		var plugin    = this,
			plugin_id = $(this).selector,
			unique;

		/* "Constructor"
		-----------------------------------------------------------------*/
		var init = function() {
			unique = plugin.unique_id(10);
			plugin.create();
			plugin.openOnClick(settings.targetBtn, settings.targetBtnParent);
			plugin.closeOnClick(settings.closeBtn);
		}

		/* Structure
		-----------------------------------------------------------------*/
		plugin.create = function() {

			var _cm = settings.contentMargin,
				_style;
			_style = (_cm && _cm >=0 && _cm <=100) ? ' style="top: '+_cm+'px; right: '+_cm+'px; bottom: '+_cm+'px; left: '+_cm+'px;"' : '';

			plugin.html('<div class="sm_content"'+ _style +'>'+ plugin.html() +'</div>');
			plugin.addClass('smk_modal ' + settings.animationName);
			if( settings.closeBtn === '.sm_close' || 
				settings.closeBtn === '' ||
				settings.closeBtn === 'undefined' ||
				settings.closeBtn === false ){
				plugin.prepend('<div class="sm_close">'+ settings.closeBtnText +'</div>');
			}
			plugin.after('<div class="smk_modal_overlay overlay_' + unique +'"></div>');

			plugin.centerModal();
			$(window).resize(function(){
				plugin.centerModal();
			});

		}

		/* Open modal window on click
		-----------------------------------------------------------------*/
		plugin.centerModal = function() {

			var _win_width = $(window).width(),
			    _win_height = $(window).height(),
			    _pl_pos_r = parseInt(plugin.css("right"), 10),
			    _pl_pos_b = parseInt(plugin.css("bottom"), 10),
			    max_w = settings.maxWidth,
			    max_h = settings.maxHeight,
			    css_mw = "",
			    css_mh = "",
			    css_left = "",
			    css_top = "";

			//Horizontal
			if( max_w !== false && max_w >= 0 ){
				
				css_mw = max_w;
				if( _win_width - _pl_pos_r * 2 > max_w ){
					css_left = (_win_width - max_w) / 2;
				}

			}

			//Vertical			
			if( max_h !== false && max_h >= 0 ){
				
				css_mh = max_h;
				if( _win_height - _pl_pos_b * 2 > max_h ){
					css_top = (_win_height - max_h) / 2;
				}

			}

			plugin.css({
				"max-width": css_mw,
				"max-height": css_mh,
				"left": css_left,
				"top": css_top
			});

		}

		/* Open modal window on click
		-----------------------------------------------------------------*/
		plugin.openOnClick = function(_targetBtn, _targetBtn_parent) {
		 	
			if( ! _targetBtn ) _targetBtn = settings.targetBtn;
			if( ! _targetBtn_parent ) _targetBtn_parent = settings.targetBtnParent;

		 	$(_targetBtn_parent).on('click', _targetBtn, function(e){
				e.preventDefault();
				plugin.openWindow();
				plugin.centerModal();
			});

		}

		/* Close modal window on click
		-----------------------------------------------------------------*/
		plugin.closeOnClick = function(_closeSelector) {

			if(_closeSelector == 'undefined') _closeSelector = settings.closeBtn;

			plugin.on('click', _closeSelector, function(e){
				e.preventDefault();
				plugin.closeWindow();
			});
			
		}

		/* Open modal window
		-----------------------------------------------------------------*/
		plugin.openWindow = function() {
		 	
			//Execute a function before window open
			if( typeof settings.beforeOpen === "function" ){
				settings.beforeOpen.call(this);
			}

			$(plugin_id).addClass('sm_show');
			$('.smk_modal_overlay.overlay_' + unique).fadeIn('fast');
			setTimeout(function(){
				$('body').addClass('smk_modal_body_scroll_none');
			}, 150);
			
			//Execute a function after window open
			if( typeof settings.afterOpen === "function" ){
				settings.afterOpen.call(this);
			}

		}

		/* Close modal window
		-----------------------------------------------------------------*/
		plugin.closeWindow = function() {

			//Execute a function before window close
			if( typeof settings.beforeClose === "function" ){
				settings.beforeClose.call(this);
			}

			plugin.removeClass('sm_show');
			$('.smk_modal_overlay.overlay_' + unique).fadeOut('fast');
			$('body').removeClass('smk_modal_body_scroll_none');

			//Execute a function after window close
			if( typeof settings.afterClose === "function" ){
				settings.afterClose.call(this);
			}
			
		}

		/* Add CSS class to modal window
		-----------------------------------------------------------------*/
		plugin.addModalClass = function(_class) {
			plugin.addClass(_class);
		}
		/* Remove CSS class from modal window
		-----------------------------------------------------------------*/
		plugin.removeModalClass = function(_class) {
			plugin.removeClass(_class);
		}

		/* Generate a multipurpose unique string(per instance)
		-----------------------------------------------------------------*/
		plugin.unique_id = function(_nr){
			var possible = "abcdefghijklmnopqrstuvwxyz0123456789", text="";
			if( _nr < 4 ) _nr = 4;
			for( var i=0; i < _nr; i++ ){
				text += possible.charAt(Math.floor(Math.random() * possible.length));
			}
			return text;
		}

		/* "Constructor" init
		-----------------------------------------------------------------*/
		init();
		return this;

	};

}( jQuery ));
