/**
 * SMK Page Builder Module Plugin
 * ----------------------------------------------------
 * Author: Smartik
 * Author URL: http://smartik.ws/
 * Copyright: (c) Smartik. All rights reserved
 */
;(function ( $ ) {

	"use strict";

	$.fn.smk_PB_Module = function( options ) {

		/* Defaults
		-----------------------------------------------------------------*/
		var settings = $.extend({
			optionX: '',          // (string)
			pbContainer: '.smk_page_builder_container',       // Page Builder container (selector)
			newModBtn: '.pb_module_add_new',                  // Default selector to add a new module (selector)
			editModBtn: '.smk_module_edit',                   // Default selector to edit a module (selector)
			cloneModBtn: '.smk_module_clone',                 // Default clone selector (selector)
			removeModBtn: '.smk_module_delete',               // Default remove selector (selector)

		}, options );

		/* Cache current instance
		// To avoid scope issues, use 'plugin' instead of 'this'
		// to reference this class from internal events and functions.
		-----------------------------------------------------------------*/
		var plugin = this;

		/* "Constructor"
		-----------------------------------------------------------------*/
		var init = function() {
			plugin.cloneModOnClick(settings.cloneModBtn, settings.pbContainer);
			plugin.removeMod(settings.removeModBtn, settings.pbContainer);
			plugin.newModOnClick(settings.newModBtn, settings.pbContainer);
			plugin.editModOnClick(settings.editModBtn, settings.pbContainer);
		}

		/* Structure
		-----------------------------------------------------------------*/
		plugin.createMod = function(_data, response) {
			// alert(response);
			var mod = "";
			var hidden_name = 'smk_page_builder_data[rows]['+ _data['row'] +'][row_sections]['+ _data['section'] +'][column]['+ _data['col'] +'][column_modules]['+ _data['cm_key'] +']';
			mod += '<div class="pb_module" id="'+ _data['cm_key'] +'">';
				mod += '<span class="pb_module_title">';
					mod += '<div class="pbm_icon">';
						mod += '<span class="'+ _data['icon'] +'"></span>';
					mod += '</div>';
					mod += '<span class="type">'+ _data['type'] +'</span>';
					mod += '<span class="title">'+ _data['title'] +'</span></span>';
				mod += '</span>';
				mod += '<input type="hidden" class="tk_module_title" value="'+ _data['title'] +'" name="'+ hidden_name +'[title]">';
				mod += '<input type="hidden" class="tk_module_value" value="'+ response +'" name="'+ hidden_name +'[val]">';
				mod += '<input type="hidden" class="tk_module_class" value="'+ _data['php_class'] +'" name="'+ hidden_name +'[class]">';
				mod += '<div class="module_controls">';
					mod += '<div class="mc_child">';
						mod += '<span class="smk_module_edit" data-modal="module_modal" data-class="'+ _data['php_class'] +'" data-mode="edit" data-action="smk_page_builder_module_form" title="Edit"></span>';
						mod += '<span class="smk_module_clone" title="Clone"></span>';
						mod += '<span class="smk_module_delete" title="Delete"></span>';
					mod += '</div>';
				mod += '</div>';
			mod += '</div>';
			return mod;
		}

		/* New module on click
		-----------------------------------------------------------------*/
		plugin.newModOnClick = function( _selector, pb_container ) {
			if( ! _selector ) _selector = settings.newModBtn;
			if( ! pb_container ) pb_container = settings.pbContainer;
			
			$(pb_container).on('click', _selector, function(){
				
				var _data = new Array();
					_data['mod']  = $(this).prev('.pb_modules'),
					_data['row']  = $(this).data('row-key').toString(),
					_data['section']  = $(this).data('section-key').toString(),
					_data['col']  = $(this).data('col-key').toString();
				
				plugin.newMod(_data);

			});
		}

		/* Edit module on click
		-----------------------------------------------------------------*/
		plugin.editModOnClick = function( _selector, pb_container ) {
			if( ! _selector ) _selector = settings.editModBtn;
			if( ! pb_container ) pb_container = settings.pbContainer;
			
			$(pb_container).on('click', _selector, function(){
				
				var _data = new Array();
					var _mod  = $(this).parents('.pb_modules');
					_data['row']  = _mod.data('row-key').toString(),
					_data['section']  = _mod.data('section-key').toString(),
					_data['col']  = _mod.data('col-key').toString();
				
				plugin.newMod(_data);

			});
		}

		/* New module
		-----------------------------------------------------------------*/
		plugin.newMod = function(_data) {
			$('#smk_pb_modal_module_colid').val('block_' + _data['section'] + '_' + _data['col']).change();
			$('#smk_pb_modal_module_rowkey').val(_data['row']).change();
			$('#smk_pb_modal_module_sectionkey').val(_data['section']).change();
			$('#smk_pb_modal_module_colkey').val(_data['col']).change();
			$('#smk_pb_modal_module_title').val('').change();
		}

		/* Clone module on click
		-----------------------------------------------------------------*/
		plugin.cloneModOnClick = function( _selector, pb_container ) {

			if( ! _selector ) _selector = settings.cloneModBtn;
			if( ! pb_container ) pb_container = settings.pbContainer;

			$(pb_container).on('click', _selector, function(){
				var _data             = new Array(), _id;
					_data['id']       = $(this).parents('.pb_module').attr('id'),
					_data['append']   = $(this).parents('.pb_modules'),
					_id               = _data['id'],
					_data['row_key']  = $(this).parents('.pb_modules').data('row-key'),
					_data['finder']   = _id.replace(_data['row_key'] + '_'),
					_data['clone']    = $(this).parents('.pb_module').clone(),
					_data['new_key']  = _data['row_key'] +'_'+ smk_generate_string(5, true);
					
					plugin.cloneMod(_data);
			});
		}

		/* Clone module
		-----------------------------------------------------------------*/
		plugin.cloneMod = function(_data) {

			var _clone  = _data['clone'],
				_append = _data['append'],
				after_this = _data['id'];

			_clone.attr('id', _data['new_key']);
			_clone.find('input').each(function(){
				var _t_name = $(this).attr('name');
				$(this).attr('name', _t_name.replace(_data['id'], _data['new_key']));
			});
			$("#" + after_this).after(_clone);
		}

		/* Remove module
		-----------------------------------------------------------------*/
		plugin.removeMod = function(_selector, pb_container) {

			if( ! _selector ) _selector = settings.removeModBtn;
			if( ! pb_container ) pb_container = settings.pbContainer;

			$(pb_container).on('click', _selector, function(){
				$(this).parents('.pb_module').remove();
			});

		}
		
		/* "Constructor" init
		-----------------------------------------------------------------*/
		init();
		return this;

	};

}( jQuery ));