/**
 * SMK Page Builder Row Plugin
 * ----------------------------------------------------
 * Author: Smartik
 * Author URL: http://smartik.ws/
 * Copyright: (c) Smartik. All rights reserved
 */
;(function ( $ ) {

"use strict";

$.fn.smk_PB_Row = function( options ) {

	/* Defaults
	-----------------------------------------------------------------*/
	var opt = $.extend({
		optionX:         '',                                    // (string)
		pbName:          'smk_page_builder_data',               // Page Builder name attribute. Used for name="?[]". (selector)
		pbContainer:     '.smk_page_builder_container',         // Page Builder container (selector)
		pbGrid:          '.smk_pbuilder_admin_grid',            // Page Builder grid container (selector)
		counterId:       '#smk_page_builder_counter',           // Default 'counter' ID (selector)
		rowClass:        '.smk_pb_admin_row',                   // Default row class (selector)
		sectionClass:    '.smk_pb_section',                     // Default row class (selector)

	}, options );

	/* Keep all in one place. Define some usefull variables
	-----------------------------------------------------------------*/
	var plugin  = this,
		
		txt_rowClassAttr    = 'tk_container_12 smk_pb_admin_row clearfix',
		txt_rRemove         = opt.rowClass + ' .row_controls > .remove',
		txt_rClone          = opt.rowClass + ' .row_controls > .clone',
		txt_rCollapse       = opt.rowClass + ' .row_controls > .collapse',
		txt_rDisable        = opt.rowClass + ' .row_controls > .disable',
		txt_rMove           = '.row_controls > .move',
		txt_sRemove         = opt.rowClass + ' ' + opt.sectionClass + ' .section_controls > .remove_section';

	/* "Constructor"
	-----------------------------------------------------------------*/
	var init = function() {
		plugin.newRowOnClick('.smk_pbrow_blocks .rblock');
		plugin.removeRow(txt_rRemove, opt.pbGrid);
		plugin.removeSection(txt_sRemove, opt.pbGrid);
		plugin.sortableRows(opt.pbGrid);
		plugin.collapseRow(txt_rCollapse, opt.pbGrid);
		plugin.disableRow(txt_rDisable, opt.pbGrid);
		plugin.cloneRow(txt_rClone, opt.pbGrid);
	}

	/* New row on click
	-----------------------------------------------------------------*/
	plugin.newRowOnClick = function( _selector ) {
		$(_selector).on('click', function(event){
			plugin.newRow(this);

  			event.stopImmediatePropagation();
		});
	}

	/* New row
	-----------------------------------------------------------------*/
	plugin.newRow = function(obj) {
					
		var block, 
			cols       = $(obj).data('columns'),
			_row_key   = smk_generate_string(6, true),
			_section_key = _row_key + smk_generate_string(6, true),
			cols_array = new Array();
			cols_array = (cols.toString().indexOf(':') === -1) ? [ parseInt(cols, 10) ] : cols.split(":");


		block = plugin.one_complete_row_html(cols_array, _row_key, _section_key);
		$(opt.pbGrid).append(block);
		
		plugin.re_initAll();
	}

	/* New section
	-----------------------------------------------------------------*/
	plugin.newSection = function(cols, row_id, _mode) {
					
		var block,
			_section_key = row_id + smk_generate_string(6, true),
			cols_array   = new Array();
			cols_array   = (cols.toString().indexOf(':') === -1) ? [ parseInt(cols, 10) ] : cols.split(":");

			console.log(this);
			console.log(cols);
		block = plugin.one_section_html(cols_array, row_id, _section_key);
		if(_mode == 'prepend'){
			$('#' + row_id).prepend(block);
		}
		else{
			$('#' + row_id).append(block);
		}
		
		plugin.re_initAll();
	}

	/* Remove row
	-----------------------------------------------------------------*/
	plugin.removeRow = function(_selector, pb_grid) {
			$(pb_grid).on('click', _selector, function(event){
			if( confirm(smk_tk_lang.pb.confirm_remove_row) ){
				$(this).parents(opt.rowClass).remove();
			}
  			event.stopImmediatePropagation();
		});
	}

	/* Remove row
	-----------------------------------------------------------------*/
	plugin.removeSection = function(_selector, pb_grid) {
			$(pb_grid).on('click', _selector, function(event){
			if( confirm(smk_tk_lang.pb.confirm_remove_section) ){
				$(this).parents(opt.sectionClass).remove();
			}
  			event.stopImmediatePropagation();
		});
	}

	/* Collapse row
	-----------------------------------------------------------------*/
	plugin.collapseRow = function(_selector, pb_grid) {
		$(pb_grid).on('click', _selector, function(event){
			console.log('ya');
			event.preventDefault();
			var the_row = $(this).parents(opt.rowClass),
			    collapsed_input = the_row.find('.smk_pb_row_collapsed');
			if( the_row.hasClass('row_close') ){
				the_row.removeClass('row_close');
				collapsed_input.val('n').change();
			}
			else{
				the_row.addClass('row_close');
				collapsed_input.val('y').change();
			}
			event.stopImmediatePropagation();
		});
	}

	/* Disable row
	-----------------------------------------------------------------*/
	plugin.disableRow = function(_selector, pb_grid) {
		$(pb_grid).on('click', _selector, function(event){
			event.preventDefault();
			var the_row = $(this).parents(opt.rowClass),
			    disable_input = the_row.find('.smk_pb_row_disabled'),
			    collapsed_input = the_row.find('.smk_pb_row_collapsed');
			if( the_row.hasClass('row_disabled') ){//enable
				the_row.removeClass('row_close row_disabled');
				disable_input.val('n').change();
				collapsed_input.val('n').change();
			}
			else{//disable
				the_row.addClass('row_close row_disabled');
				disable_input.val('y').change();
				collapsed_input.val('y').change();
			}
			event.stopImmediatePropagation();
		});
	}

	/* Sortable rows
	-----------------------------------------------------------------*/
	plugin.sortableRows = function(pb_grid) {
		$(pb_grid).sortable({
			opacity: 0.6,
			items: opt.rowClass,
			handle: txt_rMove,
			cursor: 'move',
			axis: 'y',
		});
	}

	/* Clone row
	-----------------------------------------------------------------*/
	plugin.cloneRow = function( _selector, pb_grid ) {

		$(pb_grid).on('click', _selector, function(event){
			var _this    = $(this).parents(opt.rowClass),
				old_id   = _this.attr('id'),
				new_id   = smk_generate_string(6, true),
				cloned   = $( _this.clone() ).html(),
				new_html = smk_replace_all_instring(old_id, new_id, cloned),
				_addClass = _this.attr('class') + ' new_row_added';

				setTimeout(function(){
					$(opt.pbGrid).find('.new_row_added').removeClass('new_row_added');
				},300);

			$(_this).after( plugin.row_div_html(new_id, new_html, _addClass) );
			plugin.re_initAll();
			event.stopImmediatePropagation();
		});
	}

	/* When adding a new row or after clone, we must re-init other components
	-----------------------------------------------------------------*/
	plugin.re_initAll = function(){
		smk_toolkit_pb_columns_sortable();
		smk_toolkit_pb_columns_resizable();
		smk_toolkit_pb_modules_sortable();
		smk_toolkit_pb_sections_sortable();
	}

	/**
	 * ---------------------------------------------------------------
	 *
	 * Row HTML Structure
	 *
	 * one_complete_row_html
	 *  > row_controls_html
	 *  > `for` loop
	 *    > single_column_html
	 *      > column_controls_html
	 *      > modules_html
	 * ---------------------------------------------------------------
	 */

	/* Remove controls HTML
	-----------------------------------------------------------------*/
	plugin.row_controls_html = function() {
		var block = "";

		block += '<div class="row_controls clearfix">';
			block += '<div class="prepend_section" title="'+ smk_tk_lang.pb.prepend_section +'"><div class="section_rblock"></div></div>';
			block += '<div class="append_section" title="'+ smk_tk_lang.pb.append_section +'"><div class="section_rblock"></div></div>';
			block += '<div class="move" title="'+ smk_tk_lang.pb.move +'"></div>';
			block += '<div class="clone" title="'+ smk_tk_lang.pb.clone +'"></div>';
			block += '<div class="settings" title="'+ smk_tk_lang.pb.settings +'"></div>';
			block += '<div class="collapse" title="'+ smk_tk_lang.pb.collapse +'"></div>';
			block += '<div class="disable" title="'+ smk_tk_lang.pb.disable +'"></div>';
			block += '<div class="remove" title="'+ smk_tk_lang.pb.delete +'"></div>';
		block += '</div>';

		return block;
	}

	/* Column controls HTML
	-----------------------------------------------------------------*/
	plugin.column_controls_html = function() {
		var block = "";

		//Left aligned controls
		block += '<div class="tk_col_controls_l">';
			block += '<div class="resize_minus" title="'+ smk_tk_lang.pb.decrease +'"></div>';
			block += '<div class="resize_plus" title="'+ smk_tk_lang.pb.increase +'"></div>';
			block += '<div class="col_settings" title="'+ smk_tk_lang.pb.settings +'"></div>';
			block += '<div class="sortable_handle" title="'+ smk_tk_lang.pb.move +'"></div>';
		block += '</div>';

		//Right aligned controls
		block += '<div class="tk_col_controls_r">';
			block += '<div class="col_remove" title="'+ smk_tk_lang.pb.delete +'"></div>';
		block += '</div>';

		return block;
	}

	/* Column modueles HTML. 
	 * We just generate the "holder" DIV and the "Add new" DIV
	------------------------------------------------------------------*/
	plugin.modules_html = function(_row_key, _section_key, i) {
		var block = "";

		block += '<div class="pb_modules" id="block_'+ _section_key +'_'+ i +'" data-row-key="'+ _row_key  +'" data-section-key="'+ _section_key  +'" data-col-key="'+ i +'"></div>';
		block += '<div class="pb_module_add_new" data-row-key="'+ _row_key  +'" data-section-key="'+ _section_key  +'" data-col-key="'+ i +'" data-modal="module_modal" title="'+ smk_tk_lang.pb.add_new_module +'"></div>';

		return block;
	}

	/* Columns container HTML
	-----------------------------------------------------------------*/
	plugin.single_column_html = function(grid, _row_key, _section_key, i) {
		var block = "";

		block += '<div class="tk_sortable_grid tk_grid_'+ grid +'">';
			block += '<div class="tk_col">';
				block += plugin.column_controls_html();
				block += '<input type="hidden" class="tk_column_grid" value="'+ grid +'" name="'+ opt.pbName +'[rows]['+ _row_key +'][row_sections]['+ _section_key +'][column]['+ i +'][grid]">';
				block += '<input type="hidden" class="tk_column_id" value="" name="'+ opt.pbName +'[rows]['+ _row_key +'][row_sections]['+ _section_key +'][column]['+ i +'][id]">';
				block += '<input type="hidden" class="tk_column_settings" value="" name="'+ opt.pbName +'[rows]['+ _row_key +'][row_sections]['+ _section_key +'][column]['+ i +'][column_settings]">';
				block += plugin.modules_html(_row_key, _section_key, i);
			block += '</div>';
		block += '</div>';

		return block;
	}

	/* One section
	-----------------------------------------------------------------*/
	plugin.one_section_html = function(cols_array, _row_key, _section_key) {
		var block = "";

		block += '<div id="'+ _section_key +'" class="smk_pb_section">';
			block += '<div class="section_controls">';
				block += '<div class="remove_section" title="' + smk_tk_lang.pb.remove_section + '"></div>';
			block += '</div>';
			block += '<div class="content ui-sortable">';
					
					for (var i = 0; i < cols_array.length; i++) {
						block += plugin.single_column_html(cols_array[i], _row_key, _section_key, i);
					}

				block += '<div class="clear"></div>';
			block += '</div>';
			block += '<div class="clear"></div>';
		block += '</div>';

		return block;
	}

	/* One complete row HTML
	-----------------------------------------------------------------*/
	plugin.one_complete_row_html = function(cols_array, _row_key, _section_key) {
		var block = "";

		block = '<div id="'+ _row_key +'" class="'+ txt_rowClassAttr +'">';
			block += plugin.row_controls_html();
			block += '<input type="hidden" class="smk_pb_row_settings" value="" name="'+ opt.pbName +'[rows]['+ _row_key +'][row_settings]">';
			block += '<input type="hidden" class="smk_pb_row_disabled" value="" name="'+ opt.pbName +'[rows]['+ _row_key +'][row_disabled]">';
			block += '<input type="hidden" class="smk_pb_row_collapsed" value="" name="'+ opt.pbName +'[rows]['+ _row_key +'][row_collapsed]">';
			block += plugin.one_section_html(cols_array, _row_key, _section_key);
			block += '<div class="clear"></div>';
		block += '</div>';

		return block;
	}

	/* Row DIV. Required for clone
	-----------------------------------------------------------------*/
	plugin.row_div_html = function(_row_key, _html, _addClass) {
		var block = "";
		_addClass = (_addClass) ? _addClass : txt_rowClassAttr;

		block = '<div id="'+ _row_key +'" class="'+ _addClass + '">';
			block += _html;
		block += '</div>';

		return block;
	}


	/* "Constructor" init
	-----------------------------------------------------------------*/
	init();
	return this;

};

}( jQuery ));