<?php
if( ! class_exists('Smk_Validate') ){
	class Smk_Validate {

		/**
		 * ---------------------------------------------------------------
		 * Validate input text.
		 *
		 * @param  $data the value to be sanitized
		 * @return string
		 * ---------------------------------------------------------------
		 */
		public static function input($data){
			$data = trim($data); // remove any blank spaces before and after

			if( isset($data) && ! empty($data) ){
				$data = wp_kses( $data, Smk_Validate::allowed_tags('inline') );
			}
			else{
				$data = "";
			}

			return esc_html( $data );
		}
		
		/**
		 * ---------------------------------------------------------------
		 * Validate textarea.
		 *
		 * @param  $data the value to be sanitized
		 * @return string
		 * ---------------------------------------------------------------
		 */
		public static function textarea($data){

			$data = trim($data); // remove any blank spaces before and after

			if( isset($data) && ! empty($data) ){
				$data = wp_kses( $data, Smk_Validate::allowed_tags('all') );
			}
			else{
				$data = "";
			}

			return $data;
		}


		/**
		 * -------------------------------------------------------------------------
		 *
		 * Functions destinated to work along with other methods of this class.
		 * The following functions are not for validation, they are used as helpers.
		 * 
		 * -------------------------------------------------------------------------
		 */

		/**
		 * ---------------------------------------------------------------
		 * Allowed HTML tags
		 *
		 * @param  $type Tags type. `inline` HTML elements, `all` safe HTML tags, including block elements
		 * @return array
		 * ---------------------------------------------------------------
		 */
		public static function allowed_tags($type = "inline"){
			$tags = "";

			//Safe inline HTML Tags
			if( $type = "inline"){
				$tags = array(
					'address' => array(),
					'a' => array(
						'href' => true,
						'rel' => true,
						'rev' => true,
						'name' => true,
						'target' => true,
						),
					'abbr' => array(),
					'acronym' => array(),
					'b' => array(),
					'br' => array(),
					'blockquote' => array(
						'cite' => true,
					),
					'button' => array(
						'type' => true,
						'disabled' => true,
						'name' => true,
					),
					'cite' => array(),
					'code' => array(),
					'del' => array(
						'datetime' => true,
					),
					'em' => array(),
					'h1' => array(
						'align' => true,
					),
					'h2' => array(
						'align' => true,
					),
					'h3' => array(
						'align' => true,
					),
					'h4' => array(
						'align' => true,
					),
					'h5' => array(
						'align' => true,
					),
					'h6' => array(
						'align' => true,
					),
					'hr' => array(
						'align' => true,
						'noshade' => true,
						'size' => true,
						'width' => true,
					),
					'i' => array(),
					'img' => array(
						'alt' => true,
						'align' => true,
						'border' => true,
						'height' => true,
						'hspace' => true,
						'longdesc' => true,
						'vspace' => true,
						'src' => true,
						'usemap' => true,
						'width' => true,
					),
					'ins' => array(
						'datetime' => true,
						'cite' => true,
					),
					'q' => array(
						'cite' => true,
					),
					'p' => array(),
					'pre' => array(),
					'strike' => array(
					),
					'sup' => array(),
					'small' => array(),
					'strike' => array(),
					'strong' => array(),
					'sub' => array(),
					'span' => array(),
					'div' => array(),
				);
				$tags = array_map( '_wp_add_global_attributes', $tags );
			}
			elseif( $type = "all"){
				global $allowedposttags;
				$tags = $allowedposttags;
			}
			else{
				global $allowedtags;
				$tags = $allowedtags;
			}
		
			return $tags;
		}

	}
}