<?php
/* 
 * Smk Toolkit Fields
 *
 * -------------------------------------------------------------------------------------
 * @Author: Smartik
 * @Author URI: http://smartik.ws/
 * @Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 * @Date:   2013-10-29 13:04:57
 * @Last Modified by:   Smartik
 * @Last Modified time: 2014-07-22 18:19:38
 *
 */
if( ! class_exists('Smk_Field') ) {
class Smk_Field {

	//----------------------------------//--------------------------------------//
	
	/**
	 * Field ID
	 *
	 * The field ID, also known as `type`.
	 * 
	 * @return string 
	 */
	protected $id;

	//------------------------------------//--------------------------------------//
	
	/**
	 * Fields
	 *
	 * All registered fields
	 * 
	 * @return array 
	 */
	protected $fields;

	//------------------------------------//--------------------------------------//
	
	/**
	 * Settings
	 *
	 * Current field settings
	 *
	 * @return array 
	 */
	protected $settings;

	//------------------------------------//--------------------------------------//
	
	/**
	 * HTML
	 *
	 * HTML helper. Allows to quickly create HTML elements
	 *
	 * @return object 
	 */
	protected $html;

	//------------------------------------//--------------------------------------//
	
	/**
	 * Construct
	 *
	 * Construct base object
	 *
	 * @return void 
	 */
	public function __construct(){
				
		$this->html     = new Smk_Html;
		$this->settings = $this->settings();

		if( !empty($this->settings['id']) ){
			$this->id = $this->settings['id'];
			$this->fields = smk_registered_fields();
			if( !isset( $this->fields[ $this->id ] ) ){
				add_filter( 'smk_register_field', array( $this, 'registerField' ) );
			}
		}
		
		$this->validateIntegrity();
	}

	//------------------------------------//--------------------------------------//
	
	/**
	 * Settings
	 *
	 * Current field settings
	 *
	 * @return array 
	 */
	public function settings(){
		return array();
	}

	//------------------------------------//--------------------------------------//
	
	/**
	 * Get field name
	 *
	 * Get field name
	 *
	 * @return string 
	 */
	public function getFieldName(){
		return !empty($this->settings['name']) ? $this->settings['name'] : $this->settings['id'];
	}

	//------------------------------------//--------------------------------------//
	
	/**
	 * Get field type
	 *
	 * Get field type
	 *
	 * @return string 
	 */
	public function getFieldType(){
		return $this->settings['id'];
	}

	//------------------------------------//--------------------------------------//
	
	/**
	 * Register field
	 *
	 * The filter hook that register the field
	 *
	 * @param array $fields Previous registered fields 
	 * @return array New fields via hook. void if called directly.
	 */
	public function registerField($fields){
		$fields[$this->id] = get_class($this);
		return $fields;
	}

	//------------------------------------//--------------------------------------//
	
	/**
	 * Validate Integrity
	 *
	 * Validate integrity add messages to log if errors detected
	 *
	 * @return void 
	 */
	public function validateIntegrity(){

		// If the ID already exists
		if( isset( $this->fields[ $this->id ] ) ){
			if( $this->fields[ $this->id ] !== get_class($this) ){
				smk_log('error', 
					'Can not register a field with the ID <strong>'. $this->id .'</strong> from class <strong>'. get_class($this) .'</strong>,
					because it is already registered by <strong>'. $this->fields[ $this->id ] .'</strong>.'
				);
			}
		}

		// If the ID is not specified
		if( !isset($this->id) || !is_string($this->id) ){
			smk_log( 'warning', 
				'The class <strong>'. get_class($this) .'</strong> must have a valid ID. Right now it is not set or is not a valid string.'
			);
		}
	}

















	/*
	-----------------------------------------------------------------------------------
	Input
	- $size = (string) min, small, full
	-----------------------------------------------------------------------------------
	*/
	public static function input( $id, $name, $value, $args=array() ) {
		
		$size   = ( isset( $args['size'] ) && !empty( $args['size'] ) ) ? trim( sanitize_html_class($args['size']) ) : 'full';
		$size   = ($size) ? $size : 'full';
		$class  = ( isset( $args['class'] ) && !empty( $args['class'] ) ) ? ' ' . sanitize_html_class($args['class']) : '';
		$output = '<input type="text" id="'.esc_attr($id).'" class="stk_field widefat size_'.esc_attr($size) . esc_attr($class).'" value="'.esc_html($value).'" name="'.esc_attr($name).'" />';
		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Textarea
	- $rows = <number> (string) 
	-----------------------------------------------------------------------------------
	*/
	public static function textarea($id, $name, $value, $args=array()) {

		$rows = ( isset( $args['rows'] ) && is_numeric( $args['rows'] ) ) ? esc_attr($args['rows']) : 5;
		$class = ( isset( $args['class'] ) && !empty( $args['class'] ) ) ? ' ' . sanitize_html_class($args['class']) : '';

		$output = '<textarea rows="'. $rows .'" id="'.esc_attr($id).'" class="stk_field widefat tk_textarea '.esc_attr($class).'" name="'.esc_attr($name).'">'.esc_textarea($value).'</textarea>';
		
		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Checkbox
	- 
	-----------------------------------------------------------------------------------
	*/
	public static function checkbox($id, $name, $value) {

		$output = '<input type="hidden" name="'.esc_attr($name).'" value="0" />';
		// $output .= '<input type="checkbox" id="'.esc_attr($id).'" class="stk_field tk_checkbox" name="'.esc_attr($name).'" '. checked( 1, $value, false ) .' value="1"/>';
		
		ob_start();
		$view = new Smk_Template(
			SMK_TOOLKIT_PATH . 'fields/view/checkbox.php',
			array(
				'id' => esc_attr($id),
				'name' => esc_attr($name),
				'value' => esc_attr($value),
			)
		);
		$view->render();
		$output .= ob_get_contents();
		ob_end_clean();
		
		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Select
	- $options - (array)
	-----------------------------------------------------------------------------------
	*/
	public static function select($id, $name, $value, $options = array()) {

		$output = '';

		if(is_array($options)) {
			$output .= '<select class="stk_field widefat" name="'.esc_attr($name).'" id="'.esc_attr($id).'">';	 
			 
			foreach ($options as $key => $val) 
			{
				$the_value = $val;
				//if ( ! is_numeric($key) )
					$the_value = $key;

				if( is_array($val) ){
					if( isset($val['label']) ){
						$output .= '<optgroup label="'. $val['label'] .'">';
							if( isset($val['options']) && is_array( $val['options'] ) && !empty( $val['options'] ) ){
								foreach ($val['options'] as $o_key => $o_value) {
									$output .= '<option value="'. esc_html( $o_key ) .'" ' . selected(esc_html( $value ), esc_html( $o_key ), false) . ' >'. esc_attr($o_value) .'</option>';
								}
							}
						$output .= '</optgroup>';
					}
				}
				else{
					$output .= '<option value="'. esc_html( $the_value ) .'" ' . selected(esc_html( $value ), esc_html( $the_value ), false) . ' >'. esc_attr($val) .'</option>';	 
				}

			 }

			$output .= '</select>';
		}
		else
		{
			$output .= '<span class="tk_error_message">You have not defined options. It MUST be an <strong>array</strong>.</span>';
		}
		
		
		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Radio
	- $options - (array)
	- $inlne - (string) 0 display each option in the same line, 1 display each option in a new line
	-----------------------------------------------------------------------------------
	*/
	public static function radio($id, $name, $value, $options = array(), $inline = 0) {

		$output = '';

		$inline = (isset($inline) && $inline == 0) ? '<br />' : '';

		if(is_array($options)) {
			foreach ($options as $key => $val) {
				$output .= '<div class="tk_radio_row clearfix">';
				$output .= '<input class="tk_radio" type="radio" name="' . esc_attr( $name ) . '" id="' . esc_attr( $id ) .'_'. $key .'" value="'. esc_html( $key ) . '" '. checked( $value, $key, false) .' /><label class="smk_tk_radio_label" for="' . esc_attr( $id ) .'_'. $key .'">' . esc_html( $val ) . '</label>'. $inline;
				$output .= '</div>';
			}
		}
		else
		{
			$output .= '<span class="tk_error_message">You have not defined options. It MUST be an <strong>array</strong>.</span>';
		}
		
		
		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Multicheck
	- $options - (array) an array with all choices. Required
	- $saved_instance - (array) saved data
	- $inline (string) 0 or 1
	-----------------------------------------------------------------------------------
	*/
	public static function multicheck($id, $name, $value, $options = array(), $saved_instance = array(), $inline = 0, $widget_clear_id = '') {

		$output = '';


		$inline = (isset($inline) && $inline == 0) ? '<br />' : '';

		if(is_array($options)) {

			foreach ($options as $key => $val) {
				$checked = '';
				$label = $val;

				$val = preg_replace('/[^a-zA-Z0-9._\-]/', '', strtolower($key));

				$clear_id = ( ! $widget_clear_id) ? $id : $widget_clear_id;

				if( is_array($saved_instance) && array_key_exists($clear_id, $saved_instance) ){
					if( is_array( $saved_instance[$clear_id] ) && isset( $saved_instance[$clear_id] ) ){
						if(in_array($key, $saved_instance[$clear_id]))
							$checked = ' checked="checked"';
					}
				}
				

				$the_id = $id . '_' . $key;
				$output .= '<div class="tk_checkbox_row clearfix">';
				$output .= '<label class="tk_checkbox_label">';
				$output .= '<input id="' . esc_attr( $the_id ) . '" class="tk_checkbox" type="checkbox" value="'. $key .'" name="' . esc_attr( $name ) . '[]" ' . $checked . ' />';
				$output .= esc_html( $label ) . '</label>';
				$output .= '</div>';
			}
		}
		else
		{
			$output .= '<span class="tk_error_message">You have not defined options. It MUST be an <strong>array</strong>.</span>';
		}
	

		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Switch
	- $labels - (array) Labels ON/OFF Example: array('on'=>'Enable', 'off'=>'Disable')
	-----------------------------------------------------------------------------------
	*/
	public static function xswitch($id, $name, $value, $labels, $widget_clear_id = '') {
		
		if ( ! isset($value) || empty($value) ) {
			$value = 0;
		}
		
		$clear_id = ( ! $widget_clear_id) ? $id : $widget_clear_id;

		//Get selected
		if ($value == 1){
			$cb_enabled = ' selected';
			$cb_disabled = '';
		}else{
			$cb_enabled = '';
			$cb_disabled = ' selected';
		}
		
		//Labels
		$on = ( ! isset($labels['on']) ) ? __("On", "smk_toolkit") : $labels['on'];
		$off = ( ! isset($labels['off']) ) ? __("Off", "smk_toolkit") : $labels['off'];
		$text = ( ! isset($labels['text']) ) ? "" : "<strong>" . $labels['text'] . "</strong>";

		$output = '';
		
		$output .= '<div class="stk_field tk_switch_options" data-id="'. $id .'">';
		
			$output .= '<span class="enable'. $cb_enabled .'">'. $on .'</span>';
			$output .= '<span class="disable'. $cb_disabled .'">'. $off .'</span>';
			$output .= $text;			
			
			$output .= '<input type="hidden" class="tk_switch_val" name="'. $name .'" id="'. $id .'" value="'. $value .'"/>';
			
		$output .= '</div>';

		return $output;
	}


	/*
	-----------------------------------------------------------------------------------
	Color Picker
	- 
	-----------------------------------------------------------------------------------
	*/
	public static function color($id, $name, $value, $live_bg=false) {

		$output = '';
		$default_color = '';

		if ( isset($value) ) {
				$default_color = ' data-default-color="'. esc_attr($value) .'" ';
		}
		if ( isset($live_bg) ) {
				$live_bg = ' data-live-bg="'. esc_attr($live_bg) .'" ';
		}
		$output .= '<div class="smk_color_picker"><input name="'. esc_attr($name) .'" id="'. esc_attr($id) .'" class="tk_color_picker tk_color"  type="text" value="'. esc_attr($value) .'"'. $default_color . $live_bg .' /></div>';
		
		
		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	WP Native Media Uploader(3.5+)
	- $mod - (string) min
	-----------------------------------------------------------------------------------
	*/
	public static function upload($id, $name, $value) {

		$output = '';
		$hide = '';
		$value = trim($value);
		
		$output .= '<div class="stk_field tk_upload_field_main_section">';

			$output .= '<div class="file_result">
				<input type="hidden" class="widefat tk_upload_input_result" name="'. $name .'" id="'. $id .'" value="'. $value .'" />
			</div>';	
			
			$image = $show_thumb = $ext = $uploaded = '';
			$name = '<em>(please select a file)</em>';
			if(!empty($value) && $value != ''){
				$image = preg_match( '/(^.*\.jpg|jpeg|png|gif|ico*)/i', $value );
				$ext = '-' . pathinfo($value, PATHINFO_EXTENSION);
				if( $image ){
					$show_thumb = '<a href="'. $value .'" target="_blank"><img src="'. smk_resize($value, 50, 50, true) .'" alt="" /></a>';
					$ext = '-image';
				}
				$uploaded = 'file_uploaded';
				$name = '<a href="'. $value .'" target="_blank">' . basename($value) .'</a>';
			}

			if ( function_exists( 'wp_enqueue_media' ) ) {
				$output .= '<div class="upload_field '. $uploaded .'">';
					$output .= '<span class="select_file" title="Select File"></span>';
				$output .= '</div>';

				$output .= '<div class="uploaded_file">';
					$output .= '<span class="file ext'. $ext .'">'. $show_thumb .'</span>';
				$output .= '</div>';

				$output .= '<div class="uploaded_file_info">';
					$output .= '<span class="title">'. $name .'</span>';
					
					$hide = (empty( $value ) || !isset( $value )) ? ' smk_tk_hide_element' : '';
					$output .= '<span class="remove'. $hide .'">Remove</span>';
					$output .= '<span class="default'. $hide .'" data-default="'. $value .'">Default</span>';
				$output .= '</div>';
			}
			else{
				$output .= '<span class="tk_error_message">Upgrade your version of WordPress for full media support.</span>';
			}

		$output .= '</div>';
		$output .= '<div class="clear"></div>' . "\n"; 
	
		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Slider UI
	- $min - <number> (string) integer non-negative
	- $max - <number> (string) integer non-negative
	- $step - <number> (string) integer non-negative and greater than 0(zero)
	-----------------------------------------------------------------------------------
	*/
	public static function sliderui($id, $name, $value, $min, $max, $step) {

		$output = '';
		
		$min = ( isset($min) ) ? absint($min) : '0';
		$max = ( isset($max) ) ? absint($max) : $min + 100;
		$step = ( isset($step) ) ? absint($step) : '1';
		$value = ( isset($value) ) ? absint($value) : $min;
		
		//values
		$data = 'data-id="'.esc_attr($id).'" data-val="'.$value.'" data-min="'.$min.'" data-max="'.$max.'" data-step="'.$step.'"';
		
		//html output

		$output .= '<div class="stk_field smk_toolkit_jqueryui_block">';
			$output .= '<input type="text" name="'.esc_attr($name).'" id="'.esc_attr($id).'" value="'. $value .'" class="smk_sliderui_input" />';
			$output .= '<div id="'.esc_attr($id).'-slider" class="smk_toolkit_sliderui" style="margin-left: 7px;" '. $data .'></div>';
		$output .= '</div>';		

		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Visual Select
	- $options - (array) the options containing "val", "label" and "block"
	- $mode - (string) 'text' or 'image'
	-----------------------------------------------------------------------------------
	*/
	public static function visual_select($id, $name, $value, $options = array(), $mode = 'text'){

		$output = '';

		if( isset($options) && !empty($options) && is_array($options) ){
			
			if( ('text' || 'image' || 'icon_font' || 'color') == $mode ){

				foreach ($options as $val) {
					$blocks[] = ( isset($val['block']) && !empty($val['block']) ) ? '.smk_tab_block_'. $val['block'] : null;
				}
				$blocks = array_filter($blocks);

				if( 'image' == $mode ){
					$label = ' label_image';
				}
				elseif( 'icon_font' == $mode ){
					$label = ' label_icon_font';
				}
				elseif( 'color' == $mode ){
					$label = ' label_color';
				}
				else{
					$label = '';
				}

				// If mode is set to icon font add filter field
				if( 'icon_font' == $mode ){
					$output .= '<div class="tk_tab_select_filter">'. __('Filter:', 'smk_toolkit') . ' <input type="text" value="" /></div>';
				}				

				$output .= '<div class="stk_field tk_tab_select'. $label .'" data-blocks="'. join(", ", $blocks) .'">';

				// Show options
				foreach ($options as $val) {

					$block = ( isset($val['block']) ) ? '.smk_tab_block_'. $val['block'] : '';
					$selected = ( $val['val'] == $value ) ? 'selected' : '';
					if( 'image' == $mode ) {
						$the_val = '<img src="'. $val['img'] .'" title="'. $val['label'] .'" alt="" />';
					}
					elseif( 'icon_font' == $mode ){
						$the_val = '<i class="fa '. $val['label'] .'" title="'. $val['label'] .'"></i>';
					} 
					elseif( 'color' == $mode && Smk_Check::is_hex_color( $val['color'] ) ){
						$the_val = '<div class="visual_select_color_mode" title="'. $val['label'] .'" style="background: '. $val['color'] .';"></div><div class="color_mode_text">'. $val['label'] .'</div>';
					} 	
					else{
						$the_val = $val['label'];
					} 	
					$output .= '<span class="tk_tab_select_label '. $selected .'" data-val="'. $val['val'] .'" data-block="'. $block .'">'. $the_val .'</span>';

				}

				$output .= '<input type="hidden" id="'.esc_attr($id).'" class="tk_tab_select_val" value="'.esc_attr($value).'" name="'.esc_attr($name).'" />';
				$output .= '</div>';
			}
			else{
				$output .= '';
			}

		}

		return $output;
	}

	/*
	-----------------------------------------------------------------------------------
	Image Select
	- $images - (array) the images to select.
	- $options - (array), other options, like upload, bg_position...
	-----------------------------------------------------------------------------------
	*/
	public static function image_select($id, $name, $value, $images = array(), $options = array()){

		$img_set        = (isset($value['image']) && !empty($value['image'])) ? $value['image'] : '';
		$color_set      = (isset($value['background-color']) && !empty($value['background-color'])) ? $value['background-color'] : '';
		$position_set   = (isset($value['background-position']) && !empty($value['background-position'])) ? $value['background-position'] : 'center center';
		$repeat_set     = (isset($value['background-repeat']) && !empty($value['background-repeat'])) ? $value['background-repeat'] : 'repeat';
		$attachment_set = (isset($value['background-attachment']) && !empty($value['background-attachment'])) ? $value['background-attachment'] : 'scroll';
		$size_set       = (isset($value['background-size']) && !empty($value['background-size'])) ? $value['background-size'] : 'auto';
		$img_uploaded   = (isset($value[0]) && !empty($value[0])) ? $value[0] : '';

		$img_bg 		= ($img_set != '') ? 'background-image: url(' . $img_set . ');' : '';
		$color_bg 		= ($color_set != '') ? 'background-color: ' . $color_set . ';' : '';
		$position_bg    = ($position_set != '') ? 'background-position: ' . $position_set . ';' : '';
		$repeat_bg 		= ($repeat_set != '') ? 'background-repeat: ' . $repeat_set . ';' : '';
		
		$style 			= 'style="'. $img_bg . $color_bg . $position_bg . $repeat_bg .'"';

		$defaults = array(
				'show_preview'  => true,
				'allow_upload'  => true,
				'allow_deselect'=> false,
				'background-color'      => false,
				'background-position'   => false,
				'background-repeat'     => false,
				'background-attachment' => false,
				'background-size' => false,
			);
		$options      = wp_parse_args($options, $defaults);
		$o_preview    = is_bool($options['show_preview']) ? $options['show_preview'] : true ;
		$o_upload     = is_bool($options['allow_upload']) ? $options['allow_upload'] : true ;
		$o_deselect   = is_bool($options['allow_deselect']) ? $options['allow_deselect'] : false ;
		$o_color      = is_bool($options['background-color']) ? $options['background-color'] : false ;
		$o_position   = is_bool($options['background-position']) ? $options['background-position'] : false ;
		$o_repeat     = is_bool($options['background-repeat']) ? $options['background-repeat'] : false ;
		$o_attachment = is_bool($options['background-attachment']) ? $options['background-attachment'] : false ;
		$o_size       = is_bool($options['background-size']) ? $options['background-size'] : false ;

		$deselect = ($o_deselect) ? ' data-deselect="yes"' : ' data-deselect="no"';
		
		$output  = '';
		$output .= '<div class="stk_field smk_tk_image_select"'. $deselect .'>';
			
			if($o_preview){
				$output .= '<div class="isl_preview">
					<div class="isl_preview_set_height">
						<div class="isl_preview_height" data-height="default">default</div>
						<div class="isl_preview_height" data-height="200px">200px</div>
						<div class="isl_preview_height" data-height="300px">300px</div>
						<div class="isl_preview_height" data-height="400px">400px</div>
						<div class="isl_preview_height" data-height="500px">500px</div>
					</div>
					<div class="isl_live_preview" id="'. $id .'-preview" '. $style .'></div>';
					// if($o_color || $o_position || $o_repeat || $o_attachment || $o_size){
					// 	$output .= '<span class="isl_other_options_button" data-id="'. $id .'_other_options">'. __('Other Options','smk_toolkit') .'</span>';
					// }
				$output .= '</div>';
			}
			// else{
			// 	if($o_color || $o_position || $o_repeat || $o_attachment || $o_size){
			// 		$output .= '<div class="isl_other_button2"><span class="isl_other_options_button" data-id="'. $id .'_other_options">'. __('Other Options','smk_toolkit') .'</span></div>';
			// 	}
			// }

			//This help metabox to save data(this fix the bug: sometimes data is not saved if [0] is not present)
			if($img_uploaded == '' || !isset($img_uploaded)){
				$output .= '<input type="hidden" id="'.esc_attr($id).'_hidden" class="tk_isl_val_hidden" value="" name="'.esc_attr($name).'[0]" />';
			}
			
			//Image setted
			$output .= '<input type="hidden" id="'.esc_attr($id).'" class="tk_isl_val" value="'.esc_attr($img_set).'" name="'.esc_attr($name).'[image]" />';

			if($o_color || $o_position || $o_repeat || $o_attachment || $o_size){
				$output .= '<div id="'. $id .'_other_options" class="isl_other_options">';

					if($o_color){
						$output .= '<div class="'. Smk_xHelper::grid(12) .'">
							<div class="title">'. __('Background color:','smk_toolkit') . '</div>' . 
							Smk_Field::color($id . '_bg_color', $name.'[background-color]', $color_set, '#'. $id .'-preview') .
						'</div>';
					}
					$output .= Smk_xHelper::clear_float();

					$output .= '<div class="'. Smk_xHelper::grid(3) .'">';
					
						if($o_position){
							$bg_position_opt = array(
								'center center' => 'center center',
								'center top'    => 'center top',
								'center bottom' => 'center bottom',
								'left top'      => 'left top',
								'left center'   => 'left center',
								'left bottom'   => 'left bottom',
								'right top'     => 'right top',
								'right center'  => 'right center',
								'right bottom'  => 'right bottom',
							);
							$output .= '<div class="title">'. __('Background position:','smk_toolkit') . '</div>' . Smk_Field::select($id . '_bg_position', $name.'[background-position]', $position_set, $bg_position_opt) .'';
						}
					$output .= '</div>';
					$output .= '<div class="'. Smk_xHelper::grid(3) .'">';
						if($o_repeat){
							$bg_repeat_opt = array(
								'repeat' => 'repeat',
								'repeat-x' => 'repeat-x',
								'repeat-y' => 'repeat-y',
								'no-repeat' => 'no-repeat',
							);
							$output .= '<div class="title">'. __('Background repeat:','smk_toolkit') . '</div>' . Smk_Field::select($id . '_bg_repeat', $name.'[background-repeat]', $repeat_set, $bg_repeat_opt) .'';
						}
					$output .= '</div>';
					$output .= '<div class="'. Smk_xHelper::grid(3) .'">';
						if($o_attachment){
							$bg_attachment_opt = array(
								'scroll' => 'scroll',
								'fixed' => 'fixed'
							);
							$output .= '<div class="title">'. __('Background attachment:','smk_toolkit') . '</div>' . Smk_Field::select($id . '_bg_attachment', $name.'[background-attachment]', $attachment_set, $bg_attachment_opt) .'';
						}
					$output .= '</div>';
					$output .= '<div class="'. Smk_xHelper::grid(3) .'">';
						// if($o_size){
							$bg_size_opt = array(
								'auto' => 'auto',
								'cover' => 'cover',
								'contain' => 'contain',
							);
							$output .= '<div class="title">'. __('Background size:','smk_toolkit') . '</div>' . Smk_Field::select($id . '_bg_size', $name.'[background-size]', $size_set, $bg_size_opt) .'';
						// }
					$output .= '</div>';

				$output .= '</div><!--.isl_other_options-->';
			}

			//Delete selected images message
			$output .= '<div class="isl_remove_selected">
				<em>'. __('Remove selected images?', 'smk_toolkit') .'</em>
				<span class="remove_all_imgs">'. __('remove', 'smk_toolkit') .'</span>
			</div>';
			
			$output .= '<div class="isl_all_options">';
			//Default image set from options
			if( isset($images) && !empty($images) && is_array($images) ){
				foreach ($images as $val) {
					$selected = ( $img_set == $val ) ? ' label_selected' : '';
					$output .= '<span class="isl_item'. $selected .'"><img src="'. $val .'" alt="" /></span>';
				}
			}

			//Additional images uploaded by user
			if( isset($img_uploaded) && !empty($img_uploaded) && is_array($img_uploaded) ){
				foreach ($img_uploaded as $val) {
					$selected = ( $img_set == $val ) ? ' label_selected' : '';
					$output .= '<span class="isl_item'. $selected .'">
						<span class="delete"></span>
						<img src="'. $val .'" alt="" />
						<input type="hidden" value="'. $val .'" name="'.esc_attr($name).'[0][]" />
					</span>';
				}
			}
			if($o_upload){
				$output .= '<span class="isl_upload"></span>';
			}
			$output .= '</div>';


		$output .= '</div>';

		return $output;
	}


	/*
	-----------------------------------------------------------------------------------
	Editor
	- $settings - (array) http://codex.wordpress.org/Function_Reference/wp_editor
	-----------------------------------------------------------------------------------
	*/
	public static function editor( $id, $name, $value, $settings = array() ) {

		$output = '';
		
		$settings = ( isset($settings) ) ? $settings : array();

		//Some settings, if they are not overwriten by options.
		$not_set = array(
			'textarea_rows' => 17,
			'media_buttons' => false,
		);

		//Do not allow these settings to be overwriten by options.
		$default_settings = array(
			'textarea_name' => $name,
			'tinymce' => array( 'plugins' => 'wordpress' )
		);

		//Final editor settings
		$editor_settings = array();
		if ( isset( $settings ) ) {
			$editor_settings = $settings;
		}
			$editor_settings = array_merge($not_set, array_merge($editor_settings, $default_settings) ) ;


		//Start the object
		ob_start();

		wp_editor( $value, esc_attr($id), $editor_settings);

		$output = '<div class="stk_field smk_toolkit_editor">' . ob_get_contents() . '</div>';

		ob_end_clean();

		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Post Types
	- $exclude - (array) items to exclude from list
	- $mode - (string) select or checkbox
	- $saved_instance - (array) data from database
	- $widget_clear_id - (string) clear id defined by user, not generated by widgets(it's only required if used in widgets)
	-----------------------------------------------------------------------------------
	*/
	public static function post_types($id, $name, $value, $exclude = '', $mode = '', $saved_instance, $widget_clear_id = ''){

		$output = '';

		$pt_opt = get_post_types( '', 'names' );

		//Exclude post types
		if( is_array($exclude) ) {
			foreach ( $exclude as $ex ) {
			    $index = array_search($ex, $pt_opt );
			    unset( $pt_opt[$index] );
			}
		}

		$output .= '<div>';

			if( 'select' == $mode ){
				$output .= Smk_Field::select($id, $name, $value, $pt_opt);
			}
			else{
				$output .= Smk_Field::multicheck($id, $name, $value, $pt_opt, $saved_instance, 0, $widget_clear_id);
			}

		$output .= '</div>';

		return $output;

	}

	/*
	-----------------------------------------------------------------------------------
	Pages
	- $mode - (string) select or checkbox
	- $saved_instance - (array) data from database
	- $custom_args - (array) http://codex.wordpress.org/Function_Reference/get_pages
	- $widget_clear_id - (string) clear id defined by user, not generated by widgets(it's only required if used in widgets)
	-----------------------------------------------------------------------------------
	*/
	public static function pages($id, $name, $value, $mode = '', $saved_instance, $custom_args = array(), $widget_clear_id = ''){

		$output = '';

		$args = array(
			'sort_order' => 'ASC',
			'sort_column' => 'post_title',
			'hierarchical' => 1,
			'exclude' => '',
			'include' => '',
			'meta_key' => '',
			'meta_value' => '',
			'authors' => '',
			'child_of' => 0,
			'parent' => -1,
			'exclude_tree' => '',
			'number' => '',
			'offset' => 0,
			'post_type' => 'page',
			'post_status' => 'publish'
		);

		$new_args = wp_parse_args($custom_args, $args);

		$pages = get_pages($new_args);

		$opt = array();
		foreach ( $pages as $page ) {
			$opt[ $page->ID ] = $page->post_title;
		}

		$output .= '<div>';

			if( 'select' == $mode ){
				$output .= Smk_Field::select($id, $name, $value, $opt);
			}
			else{
				$output .= Smk_Field::multicheck($id, $name, $value, $opt, $saved_instance, 0, $widget_clear_id);
			}

		$output .= '</div>';

		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Posts
	- $mode - (string) select or checkbox
	- $saved_instance - (array) data from database
	- $custom_args - (array) http://codex.wordpress.org/Function_Reference/get_posts
	- $widget_clear_id - (string) clear id defined by user, not generated by widgets(it's only required if used in widgets)
	-----------------------------------------------------------------------------------
	*/
	public static function posts($id, $name, $value, $mode = '', $saved_instance, $custom_args = array(), $widget_clear_id = ''){

		$output = '';

		$args = array(
			'posts_per_page'  => -1,
			'offset'          => 0,
			'category'        => '',
			'orderby'         => 'post_date',
			'order'           => 'DESC',
			'include'         => '',
			'exclude'         => '',
			'meta_key'        => '',
			'meta_value'      => '',
			'post_type'       => 'post',
			'post_mime_type'  => '',
			'post_parent'     => '',
			'post_status'     => 'publish',
			'suppress_filters' => true
		);

		$new_args = wp_parse_args($custom_args, $args);

		$all_posts = get_posts($new_args);

		$opt = array();
		foreach ( $all_posts as $one_post ) {
			$opt[ $one_post->ID ] = $one_post->post_title;
		}

		$output .= '<div>';

			if( 'select' == $mode ){
				$output .= Smk_Field::select($id, $name, $value, $opt);
			}
			else{
				$output .= Smk_Field::multicheck($id, $name, $value, $opt, $saved_instance, 0, $widget_clear_id);
			}

		$output .= '</div>';

		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Tags
	- $mode - (string) select or checkbox
	- $saved_instance - (array) data from database
	- $custom_args - (array) http://codex.wordpress.org/Function_Reference/get_tags
	- $widget_clear_id - (string) clear id defined by user, not generated by widgets(it's only required if used in widgets)
	-----------------------------------------------------------------------------------
	*/
	public static function tags($id, $name, $value, $mode = '', $saved_instance, $custom_args = array(), $return = 'term_id', $widget_clear_id = ''){

		$output = '';

		$all_tags = get_tags($custom_args);
		$return = ('term_id' || 'name' || 'slug' == $return) ? $return : 'term_id';

		$opt = array();
		foreach ( $all_tags as $tag ) {
			$opt[ $tag->$return ] = $tag->name;
		}

		$output .= '<div>';

			if( 'select' == $mode ){
				$output .= Smk_Field::select($id, $name, $value, $opt);
			}
			else{
				$output .= Smk_Field::multicheck($id, $name, $value, $opt, $saved_instance, 0, $widget_clear_id);
			}

		$output .= '</div>';

		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Categories
	- $mode - (string) select or checkbox
	- $saved_instance - (array) data from database
	- $custom_args - (array) http://codex.wordpress.org/Function_Reference/get_categories
	- $widget_clear_id - (string) clear id defined by user, not generated by widgets(it's only required if used in widgets)
	-----------------------------------------------------------------------------------
	*/
	public static function categories($id, $name, $value, $mode = '', $saved_instance, $custom_args = array(), $widget_clear_id = ''){

		$output = '';

		$args = array(
				'type'           => 'post',
				'child_of'       => 0,
				'parent'         => '',
				'orderby'        => 'name',
				'order'          => 'ASC',
				'hide_empty'     => 0,
				'hierarchical'   => 1,
				'exclude'        => '',
				'include'        => '',
				'number'         => '',
				'taxonomy'       => 'category',
				'pad_counts'     => false 
			);

		$new_args = wp_parse_args($custom_args, $args);

		$all_cats = get_categories($new_args);

		$opt = array();
		foreach ( $all_cats as $one_cat ) {
			$opt[ $one_cat->term_id ] = $one_cat->name;
		}

		$output .= '<div>';

			if( 'select' == $mode ){
				$output .= Smk_Field::select($id, $name, $value, $opt);
			}
			else{
				$output .= Smk_Field::multicheck($id, $name, $value, $opt, $saved_instance, 0, $widget_clear_id);
			}

		$output .= '</div>';

		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Taxonomy
	- $mode - (string) select or checkbox
	- $tax - (string) the taxonomies to retrieve terms from. http://codex.wordpress.org/Function_Reference/get_terms
	- $saved_instance - (array) data from database
	- $custom_args - (array) http://codex.wordpress.org/Function_Reference/get_terms
	- $widget_clear_id - (string) clear id defined by user, not generated by widgets(it's only required if used in widgets)
	-----------------------------------------------------------------------------------
	*/
	public static function taxonomy($id, $name, $value, $mode = '', $tax=null, $saved_instance, $custom_args = array(), $widget_clear_id = ''){

		$output = '';

		$args = array(
				'orderby'       => 'name', 
				'order'         => 'ASC',
				'hide_empty'    => false, 
				'exclude'       => array(), 
				'exclude_tree'  => array(), 
				'include'       => array(),
				'number'        => '', 
				'fields'        => 'all', 
				'slug'          => '', 
				'parent'         => '',
				'hierarchical'  => true, 
				'child_of'      => 0, 
				'get'           => '', 
				'name__like'    => '',
				'pad_counts'    => false, 
				'offset'        => '', 
				'search'        => '', 
				'cache_domain'  => 'core'
			); 

		$new_args = wp_parse_args($custom_args, $args);

		if($tax){
			if( taxonomy_exists($tax) ){

				$all_tax = get_terms( $tax, $new_args);

				$opt = array();
				foreach ( $all_tax as $one_tax ) {
					$opt[ $one_tax->term_id ] = $one_tax->name;
				}

				$output .= '<div>';

					if( 'select' == $mode ){
						$output .= Smk_Field::select($id, $name, $value, $opt);
					}
					else{
						$output .= Smk_Field::multicheck($id, $name, $value, $opt, $saved_instance, 0, $widget_clear_id);
					}

				$output .= '</div>';

				return $output;

			}
		}

	}


	/*
	-----------------------------------------------------------------------------------
	Combine
	- $saved_instance - (array) data from database
	- $widget_clear_id - (string) clear id defined by user, not generated by widgets(it's only required if used in widgets)
	-----------------------------------------------------------------------------------
	*/
	public static function combine($id, $name, $saved_instance, $comb_fields, $block_label='', $widget_clear_id = ''){
		
		$the_id = ( empty($widget_clear_id) ) ? $id : $widget_clear_id;
		$the_name = $name;

		$output = '<div class="stk_field tk_combine">';

		/* If the user has defined the fields in an array, proceed.
		-----------------------------------------------*/
		if( is_array($comb_fields) ){

			/* Combine Fields Unordered List Start
			-----------------------------------------------*/
			$output .= '<ul class="smk_toolkit_combine" data-theid="'. $the_id .'" data-id-name="'. $the_name .'[0]">';

				if( isset($saved_instance[$the_id]) && is_array($saved_instance[$the_id]) ){

			   		/*If we have already saved this option in DB
					-----------------------------------------------*/
					if( isset($saved_instance[$the_id][0]) ){

						foreach($saved_instance[$the_id][0] as $s_key => $saved){
							$output .= Smk_Field::combine_single_li($the_id, $the_name, $saved, $saved, $comb_fields, $s_key, $block_label);
						}

					}

				}

				$output .= '</ul>';

				$output .= '<span data-fields="'. esc_html( json_encode( $comb_fields ) ) .'" data-name="'. $the_name .'" data-block-label="'. $block_label .'" class="smk_toolkit_combine_new_'. $the_id .'">Add new</span>';
			

		} //if( is_array($comb_fields) ){

		$output .= '</div>';


		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	Combine single LI section
	-----------------------------------------------------------------------------------
	*/
	public static function combine_single_li($id, $name, $defaults, $saved, $comb_fields, $s_key, $block_label=''){

		$comb_block_label = ( isset($saved[$block_label]) && !empty($saved[$block_label]) ) ? $saved[$block_label] : '';

		$output = '<li class="cb_item">';
			
			//Header
			$output .= '
				<div class="cb_head">
					<div class="cb_head_label">
						<span class="block_label" data-block-label="'. $block_label . $s_key .'_comb_field">'. $comb_block_label .'</span>
					</div>
					<div class="cb_handle"></div>
					<div class="cb_collapse"></div>
				</div>
			';

			//Fields
			/*Combine block, create the body with fields
			-----------------------------------------------*/
			$output .= '<div class="cb_body clearfix" data-block-label="'. $block_label .'">';
				
				$output .= smk_toolkit_options_global(
					array(
						'object' => $name .'[0]['. $s_key .']',
						'fields' => $comb_fields,
						'defaults' => $defaults,
						'saved' => $saved,
						'module' => 'combine',
						'id_key' => $s_key,
					)
				);
			

			$output .= '<div class="smk_toolkit_combine_remove_block_container">
							<a href="#" class="smk_toolkit_combine_remove">Remove</a>
						</div>';

			$output .= '</div>';


		$output .= '</li>';

		return $output;

	}

	/*
	-----------------------------------------------------------------------------------
	Combine single LI section AJAX Call
	-----------------------------------------------------------------------------------
	*/
	public static function combine_single_li_ajax(){
		$comb_fields = ( isset($_POST['fields']) && is_array($_POST['fields']) ) ? $_POST['fields'] : false;
		if( $comb_fields ){
			$the_id = $_POST['theid'];
			$the_name = $_POST['thename'];
			$block_label = $_POST['block_label'];
			echo Smk_Field::combine_single_li($the_id, $the_name, '', '', $comb_fields, strtolower( Smk_Helper::random_string(5) . Smk_Helper::random_string(5) ), $block_label );
		}

		die();
	}


	/*
	-----------------------------------------------------------------------------------
	Font
	-----------------------------------------------------------------------------------
	*/
	public static function font_icon($id, $name, $value) {
		$font = Smk_Helper::fontAwesome(SMK_ASSETS_PATH . 'fonts/font-awesome/css/font-awesome.css');
		$font_keys = array_keys($font);
		$output = Smk_Field::select($id, $name, $value, array_combine($font_keys, $font_keys) );
		$output .= '<input type="hidden" id="'.esc_attr($id).'" class="stk_field" value="'.esc_html($value).'" name="'.esc_attr($name).'" />';
		// $output = '';
		// foreach ($font as $class => $unicode) {
		// 	$output .= '<i class="fa '. $class .'" style="font-size: 24px; padding: 5px;"></i>';
		// }

		return $output;

	}


	/*
	-----------------------------------------------------------------------------------
	DevInfo
	-----------------------------------------------------------------------------------
	*/
	public static function dev_info() {
		function smk_dev_roundsize($size){
			$i=0;
			$iec = array("B", "Kb", "Mb", "Gb", "Tb");
			while (($size/1024)>1) {
				$size=$size/1024;
				$i++;
			}
			return(round($size,1)." ".$iec[$i]);
		}
		$n = "\n";

		$output = '';
		$output .= '<pre>';
			$output .= 'Current PHP version: ' . phpversion() .$n;
			$wp_debug = (WP_DEBUG == true) ? 'true' : 'false';
			$output .= 'WP_DEBUG: ' . $wp_debug . $n;
			$output .= 'Total disk space: ' . smk_dev_roundsize( disk_total_space("/") ) . $n;
			$output .= 'Free disk space: ' . smk_dev_roundsize( disk_free_space("/") ) . $n;
		$output .= '</pre>';
		
		return $output;

	}


}
} //if( ! class_exists('Smk_Field') ) {