<?php
/**
 * SMK Toolkit Options Global
 *
 * @todo Wrap this in a PHP Class  
 */

/*
-----------------------------------------------------------------------------------
Check the type and render the content
-----------------------------------------------------------------------------------
*/
if( ! function_exists('smk_toolkit_options_global')){

	function smk_toolkit_options_global( $args ) {

		$defaults = array(
			'object' => '',
			'fields' => array(),
			'defaults' => '',
			'saved' => '',
			'module' => 'plugin'
		);
		$args = wp_parse_args($args, $defaults);
		
		$obj            = $args['object'];
		$options        = $args['fields'];
		$the_instance   = $args['defaults']; 
		$saved_instance = $args['saved'];
		$module         = $args['module'];
		$id_key         = ( isset($args['id_key']) && !empty($args['id_key']) ) ? trim($args['id_key']) : '';

		//Used to sanitize fields
		global $allowedposttags;
		
		/*
		---------------------------------------------
		Options Loop
		---------------------------------------------
		*/
		$output = '';
		foreach ($options as $option) {

			//Check everything
			$option['std'] = ( isset($option['std']) ) ? $option['std'] : '';
			$label         = ( isset($option['label']) ) ? esc_attr( $option['label'] ) : '';			
			$id            = ( isset($option['id']) ) ? esc_attr($option['id']) : '';//Get the right id and name
			$desc          = ( isset($option['desc']) && !empty($option['desc']) ) ? wp_kses($option['desc'], $allowedposttags) : false;

			//Field settings
			$set_field     = ( isset($option['set']) && is_array($option['set']) && !empty($option['set'])  ) ? $option['set'] : false;

			$set_size      = ( Smk_Check::array_val($set_field, 'size') ) ? esc_attr( $set_field['size'] ) : false;
			$set_class     = ( Smk_Check::array_val($set_field, 'class') ) ? sanitize_html_class($set_field['class']) : '';
			$set_rows      = ( Smk_Check::array_val($set_field, 'rows', 'i') ) ? absint($set_field['rows']) : 5;
			$set_grid      = ( Smk_Check::array_val($set_field, 'grid', 'i') ) ? absint($set_field['grid']) : '';
			$set_grid_pos  = ( Smk_Check::array_val($set_field, 'grid_pos') ) ? $set_field['grid_pos'] : '';
			

			/*
			---------------------------------------------
			Module check
			---------------------------------------------
			*/
			//Check the module and set the appropiate values for each
			//At this moment supported modules are widget, plugin and metabox
			switch ($module) {
				case 'widget':
					
					$the_id 		= $obj->get_field_id( $id );
					$the_name 		= $obj->get_field_name( $id );
					$val 			= isset($the_instance[$id]) ? $the_instance[$id] : '';
					$row_fold 		= ( isset($option['fold']) && !empty($option['fold']) ) ? 'smk_fold_'. $obj->get_field_id( esc_attr( $option['fold'] ) ) : '';
				
					break;
				
				case 'plugin':
							
					$the_id 		= $id;
					$the_name 		= $obj .'['. $id .']';

					if( false === get_option( $obj ) ){
						$val = $option['std'];
					}
					else{
						$val = isset($the_instance[$id]) ? $the_instance[$id] : '';
					}

					$row_fold 		= ( isset($option['fold']) && !empty($option['fold']) ) ? 'smk_fold_'. esc_attr( $option['fold'] ) : '';
				
					break;
				
				case 'metabox':
					
					$the_id 		= $id;
					$the_name 		= $id;
					$val 			= Smk_Get::value( $the_instance, $id, '' );
					$row_fold 		= ( isset($option['fold']) && !empty($option['fold']) ) ? 'smk_fold_'. esc_attr( $option['fold'] ) : '';
				
					break;
				
				case 'combine':
						
					$the_id 		= $id . $id_key .'_comb_field';
					$the_name 		= $obj .'['. $id .']';

					$val 			= ( isset($the_instance[$id]) && !empty($the_instance[$id]) ) ? $the_instance[$id] : $option['std'];
					$row_fold 		= ( isset($option['fold']) && !empty($option['fold']) ) ? 'smk_fold_'. esc_attr( $option['fold'] ) : '';
				
					break;
				
				default:
					
					$the_id 		= $id;
					$the_name 		= $id;

					$val 			= ( isset( $the_instance[$id] ) ) ? $the_instance[$id] : '';
					$row_fold 		= ( isset($option['fold']) && !empty($option['fold']) ) ? 'smk_fold_'. esc_attr( $option['fold'] ) : '';
				
					break;
			}

			/*
			---------------------------------------------
			Specific elements
			---------------------------------------------
			*/
			//Start row
			$row_id = ( $the_id && !empty($the_id) ) ?  ' id="tk_row_'. $the_id .'"' : '';
			if( $set_grid_pos == 'first' ){
				$output .= Smk_xHelper::clear_float();
			}
			$output .= '<div'. $row_id .' class="tk_row '. $row_fold . Smk_xHelper::grid($set_grid, $set_grid_pos) .' clearfix">';


			//Field Label
			if(isset($option['label']) && $option['type'] !== 'checkbox' && $option['type'] !== 'section' && $option['type'] !== 'info'){
				
				//Title block
				$output .= '<div class="tk_block_title">';
					$output .= '<div class="label">'. $label .'</div>';
				$output .= '</div>';

			}

			//Wide elements
			switch ($option['type']) {
				case 'section':
				case 'info':
				case 'editor':
				case 'combine':
					$wide_control = ' wide_control'; 
					break;
				
				default:
					$wide_control = ''; 
					break;
			}

			if( $module == 'metabox' ) $wide_control = '';
			//Control block
			$output .= '<div class="tk_block_control '. $wide_control .'">';

			/*
			---------------------------------------------
			Switch field types
			---------------------------------------------
			*/
			switch ($option['type']) {
				
				/*
				------------------------------------
				Input
				------------------------------------
				*/
				case 'input':
					
					$args = array(
						'size' => $set_size, 
						'class' => $set_class
					);

					// $output .= Smk_Field::input( $the_id, $the_name, $val, $args );
					$field = new Smk_Field_Input;
					$output .= $field->render( $the_id, $the_name, $val, $args );

					break;
				
				/*
				------------------------------------
				Textarea
				------------------------------------
				*/
				case 'textarea':
					
					$args = array(
						'rows' => $set_rows, 
						'class' => $set_class
					);

					$output .= Smk_Field::textarea($the_id, $the_name, $val, $args);

					break;
				
				/*
				------------------------------------
				Checkbox
				------------------------------------
				*/
				case 'checkbox':
					
					$output .= '<div class="input_checkbox_row clearfix">';

						$output .= Smk_Field::checkbox($the_id, $the_name, $val);
						
						if( isset($option['label']) ){
							$output .= '<label for="'. $the_id .'" class="tk_checkbox_label">'. $option['label'] .'</label>';
						}

					$output .= '</div>';

					break;
				
				/*
				------------------------------------
				Select
				------------------------------------
				*/
				case 'select':
					
					$opt = ( isset($option['options']) ) ? $option['options'] : '';

					$output .= '<div>';

						$output .= Smk_Field::select($the_id, $the_name, $val, $opt);

					$output .= '</div>';

					break;
				
				/*
				------------------------------------
				Radio
				------------------------------------
				*/
				case 'radio':
					
					$opt = ( isset($option['options']) ) ? $option['options'] : '';
					$inline = ( isset($option['inline']) ) ? $option['inline'] : 0;

					$output .= '<div>';

						$output .= Smk_Field::radio($the_id, $the_name, $val, $opt, $inline);

					$output .= '</div>';

					break;
				
				/*
				------------------------------------
				Multicheck
				------------------------------------
				*/
				case 'multicheck':
					
					$opt = ( isset($option['options']) ) ? $option['options'] : array();
					$inline = ( isset($option['inline']) ) ? $option['inline'] : 0;

					$output .= '<div>';
						
						$output .= Smk_Field::multicheck($the_id, $the_name, $val, $opt, $saved_instance, $inline, $id);
						
					$output .= '</div>';

					break;

				/*
				------------------------------------
				Switch
				------------------------------------
				*/
				case 'switch':
					
					$labels = ( isset($option['labels']) && is_array($option['labels']) ) ? $option['labels'] : array();
					if ( ! isset($val) || empty($val) ) {
						$val = 0;
					}

					$output .= '<div>';
						
						$output .= Smk_Field::xswitch($the_id, $the_name, $val, $labels, $id);
						
					$output .= '</div>';

					break;

				/*
				------------------------------------
				Visual select
				------------------------------------
				*/
				case 'visual_select':
					
					$options = $option['options'];					

					//If the value is not set we need one.
					if ( ! isset($val) || empty($val) ) {

						$val = $options[0]['val'];//get the first VALUE from array
					}

					$mode = ( isset( $option['mode'] ) && ( ('text' || 'image' || 'icon_font') == $option['mode'] ) ) ? $option['mode'] : 'text';

					$output .= '<div>';
						
						$output .= Smk_Field::visual_select($the_id, $the_name, $val, $options, $mode);
						
					$output .= '</div>';

					break;

				/*
				------------------------------------
				Image select
				------------------------------------
				*/
				case 'image_select':
					
					$images = $option['images'];	
					$options = (isset($option['options']) && is_array($option['options']) ) ? $option['options'] : array();		
					
					$output .= '<div>';
						
						$output .= Smk_Field::image_select($the_id, $the_name, $val, $images, $options);
						
					$output .= '</div>';

					break;

				/*
				------------------------------------
				Color picker
				------------------------------------
				*/
				case "color":
					$output .= '<div class="tk_color_picker_wrap_in">';
					$output .= Smk_Field::color($the_id, $the_name, $val);
					$output .= '</div>';
		 	
					break;

				/*
				------------------------------------
				Upload
				------------------------------------
				*/
				case "upload":

					$output .= '<div class="smk_wgt_upload_wrap_in">';
					$output .= Smk_Field::upload($the_id, $the_name, $val);
					$output .= '</div>';
		 	
					break;
				
				/*
				------------------------------------
				SliderUI
				------------------------------------
				*/
				case "sliderui":

					$min = ( isset($option['min']) ) ? absint($option['min']) : '0';
					$max = ( isset($option['max']) ) ? absint($option['max']) : $min + 100;
					$step = ( isset($option['step']) ) ? absint($option['step']) : '1';
					$val = ( isset($val) ) ? absint($val) : $min;

					$output .= Smk_Field::sliderui($the_id, $the_name, absint($val), absint($min), absint($max), absint($step));
		 	
					break;

				/*
				------------------------------------
				Editor
				------------------------------------
				*/
				case "editor":

					//Do not allow the editor usage in widgets. It's not supported because of ajax/js conflicts.
					if( $module != 'widget' ){

						$settings = ( isset($option['settings']) && is_array($option['settings']) ) ? $option['settings'] : array();

						$output .= Smk_Field::editor( $the_id, $the_name, $val, $settings);
					}
					else
					{
						$output .= '<span class="smk_toolkit_error_message">The editor is not supported by widgets.</span>';
					}
			 	
					break;


				/*
				------------------------------------
				Post types
				------------------------------------
				*/
				case 'post_types':
					
					$exclude = ( isset($option['exclude']) && is_array($option['exclude']) ) ? $option['exclude'] : '';
					$mode = ( isset($option['mode']) && ('select' && 'checkbox' == $option['mode']) ) ? $option['mode'] : 'select';

					$output .= Smk_Field::post_types($the_id, $the_name, $val, $exclude, $mode, $saved_instance, $id);

					break;

				/*
				------------------------------------
				Pages
				------------------------------------
				*/
				case 'pages':
					
					$mode = ( isset($option['mode']) && ('select' && 'checkbox' == $option['mode']) ) ? $option['mode'] : 'select';
					$pages_args = ( isset($option['args']) && is_array($option['args']) ) ? $option['args'] : '';

					$output .= Smk_Field::pages($the_id, $the_name, $val, $mode, $saved_instance, $pages_args, $id);

					break;

				/*
				------------------------------------
				Posts
				------------------------------------
				*/
				case 'posts':
					
					$mode = ( isset($option['mode']) && ('select' && 'checkbox' == $option['mode']) ) ? $option['mode'] : 'select';
					$posts_args = ( isset($option['args']) && is_array($option['args']) ) ? $option['args'] : '';

					$output .= Smk_Field::posts($the_id, $the_name, $val, $mode, $saved_instance, $posts_args, $id);

					break;

				/*
				------------------------------------
				Tags
				------------------------------------
				*/
				case 'tags':
					
					$mode = ( isset($option['mode']) && ('select' && 'checkbox' == $option['mode']) ) ? $option['mode'] : 'select';
					$tags_args = ( isset($option['args']) && is_array($option['args']) ) ? $option['args'] : '';
					$return = ( isset($option['return']) && ! is_array($option['return']) ) ? $option['return'] : 'term_id';

					$output .= Smk_Field::tags($the_id, $the_name, $val, $mode, $saved_instance, $tags_args, $return, $id);

					break;

				/*
				------------------------------------
				Categories
				------------------------------------
				*/
				case 'categories':
					
					$mode = ( isset($option['mode']) && ('select' && 'checkbox' == $option['mode']) ) ? $option['mode'] : 'select';
					$cats_args = ( isset($option['args']) && is_array($option['args']) ) ? $option['args'] : '';

					$output .= Smk_Field::categories($the_id, $the_name, $val, $mode, $saved_instance, $cats_args, $id);

					break;

				/*
				------------------------------------
				Taconomy
				------------------------------------
				*/
				case 'taxonomy':
					
					$mode = ( isset($option['mode']) && ('select' && 'checkbox' == $option['mode']) ) ? $option['mode'] : 'select';
					$tax = ( isset($option['tax']) ) ? $option['tax'] : null;
					$tax_args = ( isset($option['args']) && is_array($option['args']) ) ? $option['args'] : '';

					$output .= Smk_Field::taxonomy($the_id, $the_name, $val, $mode, $tax, $saved_instance, $tax_args, $id);

					break;

				/*
				------------------------------------
				Section
				------------------------------------
				*/
				case "section":

					//Align
					if( isset($option['align']) ){
						$option['align'] = trim($option['align']);
						$align = ( in_array($option['align'], array('left', 'center', 'right') ) ) ? $option['align'] : 'center';
					}
					else{
						$align = 'center';
					}

					if( isset($option['style']) ){
						$section_style = sanitize_html_class( trim($option['style']) );
						$section_style = ( in_array($section_style, array('simple', 'fancy') ) ) ? ' '. $section_style : ' fancy';
					}
					else{
						$section_style = ' fancy';
					}

					if( isset($module) && '' != $module ){
						$module = trim($module);
						$section_module =  (in_array($module, array( 'plugin', 'theme', 'metabox', 'widget', 'page_builder' ) )) ? trim($module) : 'plugin';
					}
					else{
						$module = 'plugin';
					}
					
					$content = ( isset($option['content']) ) ? wp_kses( $option['content'], $allowedposttags ) : '';

					if( '' != $content ){
						$output .= '<div id="'. $the_id .'_section" class="stk_field smk_toolkit_section smk_'. $section_module .'_section '. $align . $section_style .'">';
						$output .= '<div class="section">
							<span class="final_text">'. $content .'</span>
						</div>';
						$output .= '</div>';
				 	}
					break;

				/*
				------------------------------------
				Info
				------------------------------------
				*/
				case "message":

					$content = ( isset($option['content']) ) ? wp_kses( $option['content'], $allowedposttags ) : '';
					$align = ( isset($option['align']) && ( 'left' or 'center' or 'right' == $option['align']) ) ? $option['align'] : 'left';
					if( isset($option['mode']) && !empty($option['mode'])){
						$option['mode'] = trim($option['mode']);
						$mode = ( in_array($option['mode'], array( 'info', 'help', 'error', 'success', 'warning' ) ) ) ? $option['mode'] : 'info';
					}
					else{
						$mode = 'info';
					}
					$msg_id = ( $the_id && !empty($the_id) ) ? ' id="'. $the_id .'_alert"' : '';

					if( !empty( $content ) ){
						$output .= '<div'. $msg_id .' class="stk_field message msg_'. trim($mode) .'">';
						$output .= '<div class="msg_inner">'. $content .'</div>';
						$output .= '</div>';
				 	}
					break;

				/*
				------------------------------------
				Combination
				------------------------------------
				*/
				case 'combine':

						$comb_fields = $option['fields'];
						$comb_block_label = ( isset( $option['block_label'] ) && ! empty( $option['block_label'] ) ) ? $option['block_label'] : '';
						$output .= Smk_Field::combine($the_id, $the_name, $saved_instance, $comb_fields, $comb_block_label, $id);

					break;
				 
				/*
				------------------------------------
				Dev Info
				------------------------------------
				*/
				case 'dev_info':
						$output .= Smk_Field::dev_info();
					break;
				 	
				/*
				------------------------------------
				Font Icon
				------------------------------------
				*/
				case 'font_icon':
					
					$output .= '<div>';

						$output .= Smk_Field::font_icon($the_id, $the_name, $val);

					$output .= '</div>';

					break;
				
				/*
				------------------------------------
				Let's set a default to none :P
				------------------------------------
				*/
				default:
					// code...
					break;
			} //switch ($option['type']) { ...

			/*
			---------------------------------------------
			Specific elements CLOSE
			---------------------------------------------
			*/
			$output .= '</div>';//End Control block

			/*
			---------------------------------------------
			Description
			---------------------------------------------
			*/
			if( $desc ){
				$output .= '<div class="tk_block_description">'. $desc .'</div>';
			}

			$output .= '</div>';//End row

			if( $set_grid_pos == 'last' ){
				$output .= Smk_xHelper::clear_float(true, true);
			}

		}//foreach ($options as $option) {

		return $output;
	
	}
}