<?php
if( ! class_exists('Smk_xGet') ){
	class Smk_xGet{

		/**
		 * Get defaults(std) from options array.
		 *
		 * @param array $options Options array
		 * @return array
		 */
		public static function options_std($options){

			$result = array();
			
			if( is_array( $options ) && count( $options ) > 0 ){
				foreach ($options as $field) {
					if( isset($field['id']) && !empty($field['id']) ){
						$std = ( isset($field['std']) && ! empty($field['std']) ) ? $field['std'] : '';
						$result[$field['id']] = $std;
					}
					else{
						continue;
					}
				}
			}

			return $result;
		}

		################################################################################

		/**
		 * Get types from options array.
		 *
		 * @param array $options Options array
		 * @return array
		 */
		public static function options_type($options){

			$result = array();
			
			if( is_array( $options ) && count( $options ) > 0 ){
				foreach ($options as $field) {
					if( isset($field['id']) && !empty($field['id']) ){
						$type = ( isset($field['type']) && ! empty($field['type']) ) ? $field['type'] : '';
						$fields = ( isset($field['fields']) && ! empty($field['fields']) ) ? $field['fields'] : '';
						$result[$field['id']]['type'] = $type;
						if( $type == 'combine' ){
							$result[$field['id']]['fields'] = static::options_type($fields);
						}
					}
					else{
						continue;
					}
				}
			}

			return $result;
		}

		################################################################################

		/**
		 * Get specific types from options array.
		 *
		 * This will return a multidimensional array `id => val`, 
		 * where val contains the type and other settings. For example a select field will also have
		 * also options set with all possible values. So we can make sure we get only the expected
		 * data saved and not some custom input by user
		 *
		 * @param array $options Options array
		 * @return array
		 */
		public static function options_type_specific($options){

			$result = array();
			
			if( is_array( $options ) && count( $options ) > 0 ){
				foreach ($options as $field) {
					if( isset($field['id']) && !empty($field['id']) ){

						$id = $field['id'];
						$type = ( isset($field['type']) && ! empty($field['type']) ) ? $field['type'] : 'unknown';
						$result[$id]['type'] = $type;

						switch ($type) {
							case 'select':
								$possible_val = array_keys( Smk_Get::value( $field, 'options', array() ) );
								$result[$id]['possible_val'] = $possible_val;
								break;
							
							case 'combine':
								$combine_fields = Smk_Get::value($field, 'fields', false);
								$result[$id]['fields'] = static::options_type_specific($combine_fields);
								break;
							
							default:
								//...
								break;
						}
					}
					else{
						continue;
					}
				}
			}

			return $result;
		}

		################################################################################

		/**
		 * Unset tabs from options array and return only fields with a valid ID
		 *
		 * @param array $options Oprions array
		 * @return array
		 */
		public static function unset_tabs($options, $count = 0){
			
			$all   = array();
			$count = ( is_numeric($count) ) ? absint($count) : 0;

			foreach ($options as $tabs) {
				if( isset( $tabs['type'] ) && $tabs['type'] == 'tab' ){
					foreach ($tabs['fields'] as $field) {
						if( isset($field['id']) ){
							$all[$count++] = $field;
						}
					}
				}
				else{
					continue; // next iteration if type is not 'tab';
				}
				
			}

			return $all;

		}

		################################################################################

		/**
		 * Get only fields with a valid ID an type
		 *
		 * @param array $fields Fields array
		 * @return array
		 */
		public static function only_fields($fields, $count = 0){

			$result = array();
			
			if(is_array( $fields )){
				foreach ($fields as $field) {
					
					if( !isset($field['id']) && empty($field['id']) ) 
						continue; //if no valid ID
					if( !isset($field['type']) && empty($field['type']) ) 
						continue; //if no valid type

					$result[$count++] = $field;

				}
			}
			
			return $result;
		}

	}//class
}//class_exists