<?php
/* 
 * Return an array list of standart and google fonts with the complete family
 *
 * -------------------------------------------------------------------------------------
 * @Author: Smartik
 * @Author URI: http://smartik.ws/
 * @Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 * @Date:   2014-06-19 15:39:10
 * @Last Modified by:   Smartik
 * @Last Modified time: 2014-06-21 23:15:19
 *
 */

if( ! function_exists('smk_toolkit_fonts') ){
	function smk_toolkit_fonts(){
		// Get all fonts in a php array
		if( false === ( $fonts_array = get_transient('smk_toolkit_fonts') ) ){
			$all = file_get_contents( dirname(__FILE__) .'/gfonts.json');
			$fonts_array = json_decode($all, true);
			$fonts_array = set_transient('smk_toolkit_fonts', $fonts_array, 60*60*24);
		}

		// Google fonts list
		$serif_fonts = $monospace_fonts = $sans_serif_fonts = $handwriting_fonts = $display_fonts = array();
		if( isset($fonts_array['items']) ){
			foreach ($fonts_array['items'] as $value) {
				$family = $value['category'];

				switch ($family) {
					case 'sans-serif':
						$font_family = 'Helvetica, Arial, sans-serif';
						$sans_serif_fonts['"'. $value['family'] .'", '. $font_family] = $value['family'];
						break;
					
					case 'handwriting':
						$font_family = 'Georgia, cursive';
						$handwriting_fonts['"'. $value['family'] .'", '. $font_family] = $value['family'];
						break;
					
					case 'display':
						$font_family = '"Trebuchet MS", "Lucida Grande", sans-serif';
						$display_fonts['"'. $value['family'] .'", '. $font_family] = $value['family'];
						break;
					
					case 'monospace':
						$font_family = 'Monaco, Courier New, monospace';
						$monospace_fonts['"'. $value['family'] .'", '. $font_family] = $value['family'];
						break;
					
					case 'serif':
					default:
						$font_family = '"Palatino Linotype", "Book Antiqua", Palatino, serif';
						$serif_fonts['"'. $value['family'] .'", '. $font_family] = $value['family'];
						break;
				}
			}

			// Complete fonts list
			$complete_fonts = array(
				'standard' => array(
					'label' => 'Standard system fonts',
					'options' => array(
						'Arial, "Helvetica Neue", Helvetica, sans-serif' => 'Arial',
						'"Arial Black", "Arial Bold", Gadget, sans-serif' => 'Arial Black',
						'"Arial Narrow", Arial, sans-serif' => 'Arial Narrow',
						'"Arial Rounded MT Bold", "Helvetica Rounded", Arial, sans-serif' => 'Arial Rounded MT Bold',
						'"Avant Garde", Avantgarde, "Century Gothic", CenturyGothic, "AppleGothic", sans-serif' => 'Avant Garde',
						'Calibri, Candara, Segoe, "Segoe UI", Optima, Arial, sans-serif' => 'Calibri',
						'Candara, Calibri, Segoe, "Segoe UI", Optima, Arial, sans-serif' => 'Candara',
						'"Helvetica Neue", Helvetica, Arial, sans-serif' => 'Helvetica Neue',
						'Impact, Haettenschweiler, "Franklin Gothic Bold", Charcoal, "Helvetica Inserat", "Bitstream Vera Sans Bold", "Arial Black", sans serif' => 'Impact',
						'"Lucida Grande", "Lucida Sans Unicode", "Lucida Sans", Geneva, Verdana, sans-serif' => 'Lucida Grande',
						'Optima, Segoe, "Segoe UI", Candara, Calibri, Arial, sans-serif' => 'Optima',
						'"Segoe UI", Frutiger, "Frutiger Linotype", "Dejavu Sans", "Helvetica Neue", Arial, sans-serif' => 'Segoe UI',
						'Tahoma, Verdana, Segoe, sans-serif' => 'Tahoma',
						'"Trebuchet MS", "Lucida Grande", "Lucida Sans Unicode", "Lucida Sans", Tahoma, sans-serif' => 'Trebuchet MS',
						'Verdana, Geneva, sans-serif' => 'Verdana',
						'Georgia, Times, "Times New Roman", serif' => 'Georgia',
						'Palatino, "Palatino Linotype", "Palatino LT STD", "Book Antiqua", Georgia, serif' => 'Palatino',
						'TimesNewRoman, "Times New Roman", Times, Baskerville, Georgia, serif' => 'TimesNewRoman',
						'Consolas, monaco, monospace' => 'Consolas',
						'"Courier New", Courier, "Lucida Sans Typewriter", "Lucida Typewriter", monospace' => 'Courier New',
						'"Lucida Console", "Lucida Sans Typewriter", Monaco, "Bitstream Vera Sans Mono", monospace' => 'Lucida Console',
					),
				),
				'sans-serif' => array(
					'label' => 'Sans Serif: Google Fonts',
					'options' => $sans_serif_fonts,
				),
				'serif' => array(
					'label' => 'Serif: Google Fonts',
					'options' => $serif_fonts,
				),
				'handwriting' => array(
					'label' => 'Handwriting: Google Fonts',
					'options' => $handwriting_fonts,
				),
				'display' => array(
					'label' => 'Display: Google Fonts',
					'options' => $display_fonts,
				),
				'monospace' => array(
					'label' => 'Monospace: Google Fonts',
					'options' => $monospace_fonts,
				),
			);
		
		}
		else{
			$complete_fonts = array();
		}
		return $complete_fonts;

	}
}