<?php
if( ! class_exists('Smk_Helper') ){
	class Smk_Helper{

		/**
		 * Same Hostname
		 * 
		 * Checks whether or not two given URLs have the same hostname
		 *
		 * @param string $a
		 * @param string $b
		 * @return bool Whether or not a and b share a hostname
		 *
		 */
		public static function same_hostname($a, $b) {
			return (parse_url($a, PHP_URL_HOST) == parse_url($b, PHP_URL_HOST));
		}

		################################################################################
		
		/**
		 * List array
		 *
		 * Takes a list delimited by a symbol(default comma), and turn it in an array
		 *
		 * @param string $list
		 * @param string $delimiter
		 * @return array
		 *
		 */
		public static function list_to_array($list, $delimiter = ","){
			$array = explode($delimiter, trim($list));
			$array = array_map(function($string) {
					return htmlspecialchars(trim($string), ENT_QUOTES);
				}, $array);
			return $array;
		}

		################################################################################
		
		/**
		 * Is the given url an image
		 *
		 * @param string $image The image url
		 * @return bool
		 *
		 */
		public static function is_image($image) {
			$image = strtolower($image);

			$extension = pathinfo($image, PATHINFO_EXTENSION);
			$allowed = array('jpg', 'png', 'gif', 'jpeg');
			if(!in_array($extension, $allowed)){
				return false;
			}
			else{
				return true;
			}
		}

		################################################################################
		
		/**
		 * Random string generator
		 *
		 * @param integer $length
		 * @return string
		 */
		public static function random_string($length = 10) {
			$characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
			$randomString = '';
			for ($i = 0; $i < $length; $i++) {
				$randomString .= $characters[rand(0, strlen($characters) - 1)];
			}
			return $randomString;
		}

		################################################################################
		
		/**
		 * Strip Slashes Deep
		 *
		 * @param $value array
		 * @return array
		 */
		public static function stripslashes_deep($value){
			$value = is_array($value) ? array_map('stripslashes_deep', $value) : str_ireplace(array("\'", "\\\""), array("'", "\""), $value);
			return $value;
		}

		################################################################################
		
		/**
		 * Font Awesome
		 *
		 * @param string $path font awesome css file path
		 * @return array
		 */
		public static function fontAwesome($path){

			$css = file_get_contents($path);
			$pattern = '/\.(fa-(?:\w+(?:-)?)+):before\s+{\s*content:\s*"(.+)";\s+}/';

			preg_match_all($pattern, $css, $matches, PREG_SET_ORDER);
			
			$icons = array();
			foreach ($matches as $match) {
				$icons[$match[1]] = $match[2];
			}
			return $icons;

		}

		################################################################################
		
		/**
		 * Font Awesome for Visual select
		 */
		public static function fontAwesome_VisualSelect(){
			
			$font = static::fontAwesome(SMK_ASSETS_PATH . 'fonts/font-awesome/css/font-awesome.css');
			// $font_keys = array_keys($font);

			$visual_font_keys = array();
			foreach ($font as $key => $value) {
				$visual_font_keys[] = array(
					'val' => $key,
					'label' => $key,
				);
			}
			return $visual_font_keys;

		}
		/**
		 * Font Awesome for Visual select
		 */
		public static function fontAwesomeSocial_VisualSelect(){
			
			$visual_font_keys = array(
				array(
					'val' => 'fa-adn',
					'label' => 'fa-adn',
				),
				array(
					'val' => 'fa-android',
					'label' => 'fa-android',
				),
				array(
					'val' => 'fa-apple',
					'label' => 'fa-apple',
				),
				array(
					'val' => 'fa-behance',
					'label' => 'fa-behance',
				),
				array(
					'val' => 'fa-behance-square',
					'label' => 'fa-behance-square',
				),
				array(
					'val' => 'fa-bitbucket',
					'label' => 'fa-bitbucket',
				),
				array(
					'val' => 'fa-bitbucket-square',
					'label' => 'fa-bitbucket-square',
				),
				array(
					'val' => 'fa-bitcoin',
					'label' => 'fa-bitcoin',
				),
				array(
					'val' => 'fa-btc',
					'label' => 'fa-btc',
				),
				array(
					'val' => 'fa-codepen',
					'label' => 'fa-codepen',
				),
				array(
					'val' => 'fa-css3',
					'label' => 'fa-css3',
				),
				array(
					'val' => 'fa-delicious',
					'label' => 'fa-delicious',
				),
				array(
					'val' => 'fa-deviantart',
					'label' => 'fa-deviantart',
				),
				array(
					'val' => 'fa-digg',
					'label' => 'fa-digg',
				),
				array(
					'val' => 'fa-dribbble',
					'label' => 'fa-dribbble',
				),
				array(
					'val' => 'fa-dropbox',
					'label' => 'fa-dropbox',
				),
				array(
					'val' => 'fa-drupal',
					'label' => 'fa-drupal',
				),
				array(
					'val' => 'fa-empire',
					'label' => 'fa-empire',
				),
				array(
					'val' => 'fa-facebook',
					'label' => 'fa-facebook',
				),
				array(
					'val' => 'fa-facebook-square',
					'label' => 'fa-facebook-square',
				),
				array(
					'val' => 'fa-flickr',
					'label' => 'fa-flickr',
				),
				array(
					'val' => 'fa-foursquare',
					'label' => 'fa-foursquare',
				),
				array(
					'val' => 'fa-ge',
					'label' => 'fa-ge',
				),
				array(
					'val' => 'fa-git',
					'label' => 'fa-git',
				),
				array(
					'val' => 'fa-git-square',
					'label' => 'fa-git-square',
				),
				array(
					'val' => 'fa-github',
					'label' => 'fa-github',
				),
				array(
					'val' => 'fa-github-alt',
					'label' => 'fa-github-alt',
				),
				array(
					'val' => 'fa-github-square',
					'label' => 'fa-github-square',
				),
				array(
					'val' => 'fa-gittip',
					'label' => 'fa-gittip',
				),
				array(
					'val' => 'fa-google',
					'label' => 'fa-google',
				),
				array(
					'val' => 'fa-google-plus',
					'label' => 'fa-google-plus',
				),
				array(
					'val' => 'fa-google-plus-square',
					'label' => 'fa-google-plus-square',
				),
				array(
					'val' => 'fa-hacker-news',
					'label' => 'fa-hacker-news',
				),
				array(
					'val' => 'fa-html5',
					'label' => 'fa-html5',
				),
				array(
					'val' => 'fa-instagram',
					'label' => 'fa-instagram',
				),
				array(
					'val' => 'fa-joomla',
					'label' => 'fa-joomla',
				),
				array(
					'val' => 'fa-jsfiddle',
					'label' => 'fa-jsfiddle',
				),
				array(
					'val' => 'fa-linkedin',
					'label' => 'fa-linkedin',
				),
				array(
					'val' => 'fa-linkedin-square',
					'label' => 'fa-linkedin-square',
				),
				array(
					'val' => 'fa-linux',
					'label' => 'fa-linux',
				),
				array(
					'val' => 'fa-maxcdn',
					'label' => 'fa-maxcdn',
				),
				array(
					'val' => 'fa-openid',
					'label' => 'fa-openid',
				),
				array(
					'val' => 'fa-pagelines',
					'label' => 'fa-pagelines',
				),
				array(
					'val' => 'fa-pied-piper',
					'label' => 'fa-pied-piper',
				),
				array(
					'val' => 'fa-pied-piper-alt',
					'label' => 'fa-pied-piper-alt',
				),
				array(
					'val' => 'fa-pied-piper-square',
					'label' => 'fa-pied-piper-square',
				),
				array(
					'val' => 'fa-pinterest',
					'label' => 'fa-pinterest',
				),
				array(
					'val' => 'fa-pinterest-square',
					'label' => 'fa-pinterest-square',
				),
				array(
					'val' => 'fa-qq',
					'label' => 'fa-qq',
				),
				array(
					'val' => 'fa-ra',
					'label' => 'fa-ra',
				),
				array(
					'val' => 'fa-rebel',
					'label' => 'fa-rebel',
				),
				array(
					'val' => 'fa-reddit',
					'label' => 'fa-reddit',
				),
				array(
					'val' => 'fa-reddit-square',
					'label' => 'fa-reddit-square',
				),
				array(
					'val' => 'fa-renren',
					'label' => 'fa-renren',
				),
				array(
					'val' => 'fa-share-alt',
					'label' => 'fa-share-alt',
				),
				array(
					'val' => 'fa-share-alt-square',
					'label' => 'fa-share-alt-square',
				),
				array(
					'val' => 'fa-skype',
					'label' => 'fa-skype',
				),
				array(
					'val' => 'fa-slack',
					'label' => 'fa-slack',
				),
				array(
					'val' => 'fa-soundcloud',
					'label' => 'fa-soundcloud',
				),
				array(
					'val' => 'fa-spotify',
					'label' => 'fa-spotify',
				),
				array(
					'val' => 'fa-stack-exchange',
					'label' => 'fa-stack-exchange',
				),
				array(
					'val' => 'fa-stack-overflow',
					'label' => 'fa-stack-overflow',
				),
				array(
					'val' => 'fa-steam',
					'label' => 'fa-steam',
				),
				array(
					'val' => 'fa-steam-square',
					'label' => 'fa-steam-square',
				),
				array(
					'val' => 'fa-stumbleupon',
					'label' => 'fa-stumbleupon',
				),
				array(
					'val' => 'fa-stumbleupon-circle',
					'label' => 'fa-stumbleupon-circle',
				),
				array(
					'val' => 'fa-tencent-weibo',
					'label' => 'fa-tencent-weibo',
				),
				array(
					'val' => 'fa-trello',
					'label' => 'fa-trello',
				),
				array(
					'val' => 'fa-tumblr',
					'label' => 'fa-tumblr',
				),
				array(
					'val' => 'fa-tumblr-square',
					'label' => 'fa-tumblr-square',
				),
				array(
					'val' => 'fa-twitter',
					'label' => 'fa-twitter',
				),
				array(
					'val' => 'fa-twitter-square',
					'label' => 'fa-twitter-square',
				),
				array(
					'val' => 'fa-vimeo-square',
					'label' => 'fa-vimeo-square',
				),
				array(
					'val' => 'fa-vine',
					'label' => 'fa-vine',
				),
				array(
					'val' => 'fa-vk',
					'label' => 'fa-vk',
				),
				array(
					'val' => 'fa-wechat',
					'label' => 'fa-wechat',
				),
				array(
					'val' => 'fa-weibo',
					'label' => 'fa-weibo',
				),
				array(
					'val' => 'fa-weixin',
					'label' => 'fa-weixin',
				),
				array(
					'val' => 'fa-windows',
					'label' => 'fa-windows',
				),
				array(
					'val' => 'fa-wordpress',
					'label' => 'fa-wordpress',
				),
				array(
					'val' => 'fa-xing',
					'label' => 'fa-xing',
				),
				array(
					'val' => 'fa-xing-square',
					'label' => 'fa-xing-square',
				),
				array(
					'val' => 'fa-yahoo',
					'label' => 'fa-yahoo',
				),
				array(
					'val' => 'fa-youtube',
					'label' => 'fa-youtube',
				),
				array(
					'val' => 'fa-youtube-play',
					'label' => 'fa-youtube-play',
				),
				array(
					'val' => 'fa-youtube-square',
					'label' => 'fa-youtube-square',
				),
			);
			
			return $visual_font_keys;

		}

	}//class
}//class_exists