<?php
/**
 * SMK Content Builder AJAX
 *
 * Ajax actions used in Content Builder
 *
 * -------------------------------------------------------------------------------------
 * Author: Smartik
 * Author URI: http://smartik.ws/
 * Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 */
if( ! class_exists('Smk_ContentBuilder_Ajax') ){
	class Smk_ContentBuilder_Ajax{

		function __construct(){
			add_action('wp_ajax_smk_page_builder_module_form', array(&$this, 'moduleFormLoad'));
			add_action('wp_ajax_save_page_builder_module', array(&$this, 'moduleFormSubmit'));
			add_action('wp_ajax_smk_content_builder_row_settings_form_load', array(&$this, 'rowFormLoad'));
			add_action('wp_ajax_smk_content_builder_row_settings_form_submit', array(&$this, 'rowFormSubmit'));
		}

		################################################################################
		
		/**
		 * Module form load
		 *
 		 * @return string HTML form on success, `fail` if there is an error 
		 */
		public function moduleFormLoad(){
			// smk_ppprint( $_POST['data'] );
			$post_data  = ( isset($_POST['data']) && !empty($_POST['data']) ) ? $_POST['data'] : false;
			$php_class  = ( isset($post_data['php_class']) && !empty($post_data['php_class']) ) ? $post_data['php_class'] : false;
			$saved_data = ( isset($post_data['saved_data']) && !empty($post_data['saved_data']) ) ? $post_data['saved_data'] : false;
			$reg_mod    = get_option('smk_page_builder_modules');
			
			if( $post_data !== false && $php_class !== false ){
				if($reg_mod && isset($reg_mod[$php_class])){
					if( class_exists($reg_mod[$php_class]) ){
						$the_main_class = $reg_mod[$php_class];
						$load = new $the_main_class('load');
						$form = $load->form();
						$load->addModuleForm($form, $saved_data);
					}
				}
			}
			else{
				echo 'fail';
			}
			
			die();
		}

		################################################################################
		
		/**
		 * Module form submit
		 *
 		 * @return string JSON Encoded and escaped
		 */
		public function moduleFormSubmit(){
			$data = $_POST['data'];
			$php_class = $data['php_class'];

			//Mode
			$row_key = Smk_Get::value($data, 'row_key', '');
			$section_key = Smk_Get::value($data, 'section_key', '');
			$column_key = Smk_Get::value($data, 'column_key', '0');
			$module_key = Smk_Get::value($data, 'module_key', '');

			//Form data
			$raw_form_data = rawurldecode( $data['form_data'] );
			parse_str($raw_form_data , $form_data);
			$reg_mod = get_option('smk_page_builder_modules');

			// Return content
			if(class_exists($reg_mod[$php_class])) {
				$final_class = $reg_mod[$php_class];
				$load = new $final_class('load');
				$form = $load->form();
				$fields_type = Smk_xGet::options_type_specific( $form );
				$form_data = Smk_Sanitize::options_array($form_data, $fields_type);
				
				$module_value = array(
					'class' => $php_class,
					'val'   => Smk_Data::encodeJsonE( $form_data ),
				);
				echo $load->showSavedModule($row_key, $section_key, $column_key, $module_key, $module_value);
				die();

			}

			//smk_ppprint($form_data);
			die();
		}

		################################################################################

		/**
		 * Ajax row settingsform load
		 *
		 * @return string HTML form on success, `fail` if there is an error 
		 */
		public function rowFormLoad(){
			// smk_ppprint( $_POST['data'] );
			
			$post_data  = ( isset($_POST['data'] ) && !empty($_POST['data']) ) ? $_POST['data'] : false;
			if( $post_data !== false ){
				
				$saved_data = ( isset($post_data['saved_data'] ) && !empty($post_data['saved_data']) ) ? $post_data['saved_data'] : '';
				$row_settings = new Smk_ContentBuilder_Form;
				$row_settings->createForm(
					smk_page_builder_row_settings_fields(), 
					$saved_data
				);

			}
			else{
				echo 'fail';
			}
			
			die();
		}

		################################################################################
		
		/**
		 * Row form submit
		 *
 		 * @return string JSON Encoded and escaped
		 */
		public function rowFormSubmit(){
			$data = $_POST['data'];
			$raw_form_data = rawurldecode( $data['form_data'] );
			parse_str($raw_form_data , $form_data);

			// Validate data before save
			$form = smk_page_builder_row_settings_fields();
			$fields_type = Smk_xGet::options_type_specific( $form );
			$form_data = Smk_Sanitize::options_array($form_data, $fields_type);

			//smk_ppprint($form_data);
			echo Smk_Data::encodeJsonE( $form_data );
			die();
		}

	}//Smk_ContentBuilder_Ajax class
}//class_exists 'Smk_ContentBuilder_Ajax'