<?php
/**
 * SMK Metabox
 * takes in a few pieces of data and creates a custom meta box
 *
 * @param	string			$id			meta box id
 * @param	string			$title		title
 * @param	array			$fields		array of each field the box should include
 * @param	string|array	$page		post type to add meta box to
 * @param 	string 			$context 	'normal', 'advanced', 'side'. Default: 'normal'
 * @param 	string 			$priority 	'high', 'core', 'default', 'low'. Default: 'high'
 */
if( ! class_exists('Smk_Metabox') ) {
class Smk_Metabox {
	
	var $id;
	var $title;
	var $fields;
	var $page;
	var $context;
    var $priority;
	
    public function __construct( $id, $title, $fields, $page, $context = '', $priority = '', $capability = false ) {

    	if( $capability && ! current_user_can( $capability ) )
    		return;

		$this->id = $id;
		$this->title = $title;
		$this->fields = $fields;
		$this->page = $page;
		
		if( ! is_array( $this->page ) )
			$this->page = array( $this->page );

		$this->context = ( 'normal' && 'advanced' && 'side' != $context) ? 'normal' : $context;
		$this->priority = ( 'high' && 'core' && 'default' && 'low' != $priority) ? 'default' : $priority;
		
		
		
		//add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		//add_action( 'admin_head',  array( $this, 'admin_head' ) );
		add_action( 'add_meta_boxes', array( &$this, 'add_box' ) );
		add_filter( 'pre_post_update',  array( &$this, 'before_save_box' ));
		add_action( 'save_post',  array( &$this, 'save_box' ));

		// Register metabox for global access
		add_action('smk_mod_all_metaboxes', array(&$this, 'registerMetaboxGlobal'));
    }
	
	/**
	 * enqueue necessary scripts and styles
	 */
	function admin_enqueue_scripts() {
		//code here
	}
	
	/**
	 * adds scripts to the head for special fields with extra js requirements
	 */
	function admin_head() {
		//code here
	}
	
	/**
	 * adds the meta box for every post type in $page
	 */
	function add_box() {
		foreach ( $this->page as $page ) {
			add_meta_box( $this->id, $this->title, array( &$this, 'meta_box_callback' ), $page, $this->context, $this->priority );
		}
	}
	
	/**
	 * outputs the meta box
	 */
	function meta_box_callback() {
		// Use nonce for verification
		wp_nonce_field( $this->id . '_nonce_action', $this->id . '_nonce_field' );

		//Get the current page. We'll use it later in conditional arguments
		global $pagenow;


		/*Saved values*/
		foreach ($this->fields as $value_tabs) {
			foreach ($value_tabs['fields'] as $value) {
				if( isset($value['id']) ){
					//Avoid errors
					$meta_val = false;
					$std = false;
					$meta = array();

					//Display the right values based on users action
					//If the post is already published and it can be updated, show saved values
					if( $pagenow == 'post.php' )
					{
						
						$meta_val = get_post_meta( get_the_ID(), $value['id'], true);

						$std = ( ! isset($meta_val[0]) ) ? '' : $meta_val;

					}
					//If the user is about to publish a post, show default values
					elseif( $pagenow == 'post-new.php' )
					{
						$meta_val = ( isset($value['std']) ) ? $value['std'] : '';

						$std = $meta_val;

					}

					//Store data in an array
					$output_id[] = $value['id'];
					$output_std[] = $std;
				}
			}
		}

		//Combine data, so we can use it later.
		$meta = array_combine($output_id, $output_std);

		//The metabox form
		echo '<div class="all_options_block_metabox">';

		foreach ($this->fields as $value_tabs) {
			echo '<section id="'. $value_tabs['id'] .'" class="tab_content active" >';

			// echo smk_toolkit_options_global('', $value_tabs['fields'], $meta, $meta, 'metabox');

			$args = array(
				'object' => '',
				'fields' => $value_tabs['fields'],
				'defaults' => $meta,
				'saved' => $meta,
				'module' => 'metabox'
			);

			echo smk_toolkit_options_global($args);

			echo '</section>';//End <div id="'. $the_id .'" class="smk_toolkit_plugin_tab_content">
		}//End foreach ($this->fields as $value_tabs) { ...
		echo '</div>';
		// echo get_post_meta(get_the_ID(), '_wp_page_template', true);
		// smk_ppprint($meta);

	}
	
	/**
	 * before save
	 *
	 * Apply a filter before the post is saved.
	 * This bug is specific after the theme switch, if previous theme has set a page template, but current theme
	 * does not use the page templates at all. So in order to allow metabox save, the page template should be removed,
	 * before save. 
	 *
	 */
	function before_save_box( $post_id ) {

		if ( ! isset( $_POST['_wp_page_template'] ) ){
			update_post_meta( $post_id, '_wp_page_template', '' );
		}
		
	}

	/**
	 * saves the captured data
	 */
	function save_box( $post_id ) {
		$post_type = get_post_type();
		
		// verify nonce
		if ( ! isset( $_POST[$this->id . '_nonce_field'] ) )
			return $post_id;
		if ( ! ( in_array( $post_type, $this->page ) || wp_verify_nonce( $_POST[$this->id . '_nonce_field'],  $this->id . '_nonce_action' ) ) ) 
			return $post_id;

		// check autosave
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;

		// check permissions
		if ( ! current_user_can( 'edit_page', $post_id ) )
			return $post_id;

		// loop through fields and save the data
		foreach ( $this->fields as $field_tabs ) {
			foreach ($field_tabs['fields'] as $value) {
				if( isset($value['id']) ){
					$new = false;
					$old = get_post_meta( $post_id, $value['id'], true );

					if ( isset( $_POST[$value['id']] ) )
						$new = $_POST[$value['id']];

					if ( isset( $new ) && '' == $new && $old ) 
					{
						delete_post_meta( $post_id, $value['id'], $old );
					}
					elseif ( ! $new || !isset( $new ) ) 
					{
						delete_post_meta( $post_id, $value['id'], $old );
					}
					elseif ( isset( $new ) && $new != $old ) 
					{
						update_post_meta( $post_id, $value['id'], $new );
					}
					elseif ( ! isset( $old ) && isset( $new ) ) 
					{
						add_post_meta( $post_id, $value['id'], $new );
					}
				}
			}
		} // end foreach

	}//End function save_box()

	//------------------------------------//--------------------------------------//
	
	/**
	 * Add metabox to the registered metaboxes list
	 *
	 * Add this metabox to the list of all registered metaboxes. Accesible via smk_mod_all_metaboxes()
	 *
	 * @hook smk_mod_all_metaboxes
	 * @param array $metaboxes All already registered metaboe
	 * @return void Called via a WP Hook 
	 */
	public function registerMetaboxGlobal($metaboxes){
		
		$metaboxes_id = $this->id .'_'. implode('_', $this->page);

		if( ! array_key_exists($this->id, $metaboxes) ){
			$metaboxes[ $metaboxes_id ] = array(
				'id'     => $this->id,
				'title'  => $this->title,
				'page'   => $this->page,
				'fields' => $this->fields,
			);
		}
		
		return $metaboxes;
	}
	
}//End class Smk_Metabox()
}//End "class_exists" check