<?php
/**
 * Smk Page Builder Base
 *
 * The main constructor. This class will create the page builder metabox with all 
 * necesary controls.
 *
 * -------------------------------------------------------------------------------------
 * Author: Smartik
 * Author URI: http://smartik.ws/
 * Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 */
if( ! class_exists('Smk_PageBuilder_Base') ) {
class Smk_PageBuilder_Base {
	
	public $id;
	public $title;
	public $fields;
	public $page;
	public $context;
    public $priority;
	
	################################################################################
	
	/**
	 * Page Builder Cnstructor
	 *
	 * @param	string			$id			meta box id
	 * @param	string			$title		title
	 * @param	string|array	$page		post type to add meta box to
	 * @param 	string 			$context 	'normal', 'advanced', 'side'. Default: 'normal'
	 * @param 	string 			$priority 	'high', 'core', 'default', 'low'. Default: 'high'
	 */
    public function __construct( $id, $title, $page, $context = '', $priority = '' ) {
		$this->id = $id;
		$this->title = $title;
		$this->page = $page;
		
		if( ! is_array( $this->page ) )
			$this->page = array( $this->page );

		$this->context = ( 'normal' && 'advanced' && 'side' != $context) ? 'normal' : $context;
		$this->priority = ( 'high' && 'core' && 'default' && 'low' != $priority) ? 'high' : $priority;
		
		// add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		add_action( 'admin_head',  array( &$this, 'admin_head' ) );
		add_action( 'add_meta_boxes', array( &$this, 'add_box' ) );
		add_filter( 'pre_post_update',  array( &$this, 'before_save_box' ));
		add_action( 'save_post',  array( &$this, 'save_box' ));

		new Smk_ContentBuilder_Ajax;
    }
	
	################################################################################
	
	/**
	 * Enqueue necessary scripts and styles
	 */
	function admin_enqueue_scripts() {
		//...
	}

	################################################################################
	
	/**
	 * Adds scripts to the head for special fields with extra js requirements
	 */
	function admin_head() {
		
		echo '<style type="text/css">';
			do_action( $this->id .'_modules_icon_css' );
		echo '</style>';

	}
	
	################################################################################
	
	/**
	 * Adds the meta box for every post type in $page
	 */
	function add_box() {
		foreach ( $this->page as $page ) {
			add_meta_box( $this->id, $this->title, array( &$this, 'meta_box_callback' ), $page, $this->context, $this->priority );
		}
	}

	################################################################################
	
	/**
	 * Get view
	 *
	 * Return the file full path
	 *
	 * @param string $name file name without extentsion
	 * @return string Full path
	 */
	public function view($name){
		return SMK_MOD_PATH . 'page-builder/view/'. $name .'.php';
	}

	################################################################################

	/**
	 * Outputs the meta box
	 */
	function meta_box_callback() {
		echo '<div class="smk_page_builder_container">';
		
			// Use nonce for verification
			wp_nonce_field( 'smk_toolkit_pbuilder_nonce_action', 'smk_toolkit_pbuilder_nonce_field' );

			$ModuleModal = new Smk_Template(
				$this->view('module-modal'), 
				array(
					'id'   => $this->id,
					'action' => array(
						'categories' => 'page_builder_module_categories',
						'menu' => $this->id . '_module_menu',
						'form' => $this->id . '_module_form',
					),
					'hidden' => array(
						'id_prefix' => 'smk_pb_modal_module_',//hidden fields ID prefix
						'fields' => array( 'colid', 'rowkey', 'sectionkey', 'colkey', 'icon', 'type', 'class' ),//hidden fields
					)
				)
			);
			$RowModal = new Smk_Template(
				$this->view('row-modal'), 
				array(
					'action' => array(
						'row_settings_form' => $this->id . '_row_settings_form',
					),
				)
			);
			$Header = new Smk_Template(
				$this->view('header'), 
				array(
					'id'   => $this->id,
				)
			);
			$RowControls = new Smk_Template(
				$this->view('row-controls'), 
				array()
			);
			$ModuleModal->render();
			$RowModal->render();
			$Header->render();

			$meta = get_post_meta( get_the_ID(), 'smk_page_builder_data' );
			// $pb_count = ( isset($meta[0]['count']) && is_numeric($meta[0]['count']) ) ? $meta[0]['count'] : 1;
			// echo $this->input('smk_page_builder_counter', 'smk_page_builder_data[count]', $pb_count, 'hidden');

			echo '<div class="smk_pbuilder_admin_grid">';
				$pb_rows = ( isset($meta[0]['rows']) && is_array($meta[0]['rows']) ) ? $meta[0]['rows'] : false;
				
				/*
				------------------------------------------------------------------------------------
				Rows
				------------------------------------------------------------------------------------
				*/
				if( is_array($pb_rows) ){
					foreach ($pb_rows as $row_key => $row) {

						$row_disabled = ( Smk_Get::value( $row, 'row_disabled', 'n') == 'y' ) ? ' row_disabled' : '';
						$row_collapsed = ( Smk_Get::value( $row, 'row_collapsed', 'n') == 'y' ) ? ' row_close' : '';

						echo '<div id="'. $row_key .'" class="tk_container_12 smk_pb_admin_row clearfix'. $row_disabled . $row_collapsed .'">';
							
							//Row controls
							$RowControls->render();
							echo $this->input(
									false, 
									'smk_page_builder_data[rows]['. $row_key .'][row_settings]', 
									Smk_Get::value( $row, 'row_settings', ''),
									'hidden',
									'smk_pb_row_settings'
								);
							echo $this->input(
									false, 
									'smk_page_builder_data[rows]['. $row_key .'][row_disabled]', 
									Smk_Get::value( $row, 'row_disabled', 'n'),
									'hidden',
									'smk_pb_row_disabled'
								);
							echo $this->input(
									false, 
									'smk_page_builder_data[rows]['. $row_key .'][row_collapsed]', 
									Smk_Get::value( $row, 'row_collapsed', 'n'),
									'hidden',
									'smk_pb_row_collapsed'
								);
							
							/*
							--------------------------------------------------------------------------------
							Sections
							--------------------------------------------------------------------------------
							*/
							if( $row_sections = Smk_Get::value($row, 'row_sections', false) ){

								foreach ($row_sections as $section_key => $section_value) {
									echo '<div id="'. $section_key .'" class="smk_pb_section">';
										echo '<div class="section_controls">
												<div class="remove_section" title="'. __('Remove section', 'smk_toolkit') .'"></div>
											</div>';
										echo '<div class="content">';

											$pb_columns = ( isset($section_value['column']) && is_array($section_value['column']) ) ? $section_value['column'] : false;
											
											/*
											--------------------------------------------------------------------------------
											Columns
											--------------------------------------------------------------------------------
											*/
											if( is_array($pb_columns) ){
												foreach ($pb_columns as $col_key => $col) {
													
													$grid    = ( isset($col['grid']) && is_numeric($col['grid']) ) ? $col['grid'] : 2;
													$id      = ( isset($col['id']) ) ? $col['id'] : '';
													$column_settings = ( isset($col['column_settings']) ) ? $col['column_settings'] : '';
													$column_modules  = ( isset($col['column_modules']) && is_array($col['column_modules']) ) ? $col['column_modules'] : false;
													$current_col_name = 'smk_page_builder_data[rows]['. $row_key .'][row_sections]['. $section_key .'][column]['. $col_key .']';

													echo '<div class="tk_sortable_grid tk_grid_'. $grid .'">';
														echo '<div class="tk_col">';
															echo '<div class="tk_col_controls_l"></div>';
															echo '<div class="tk_col_controls_r"></div>';
															echo $this->input(false, $current_col_name .'[grid]', $grid, 'hidden', 'tk_column_grid');
															echo $this->input(false, $current_col_name .'[id]', $id, 'hidden', 'tk_column_id');
															echo $this->input(false, $current_col_name .'[column_settings]', $column_settings, 'hidden', 'tk_column_settings');
																echo '<div class="pb_modules" id="block_' . $section_key .'_'. $col_key . '" data-section-key="'. $section_key .'" data-row-key="'. $row_key .'" data-col-key="'. $col_key .'">';
																
																/*
																--------------------------------------------------------------------------------
																Modules
																--------------------------------------------------------------------------------
																*/
																if(is_array($column_modules)){
																	foreach ($column_modules as $module_key => $module_value) {
																		
																		$type      = $module_value['class'];
																		$reg_mod   = get_option('smk_page_builder_modules');
																		if(isset($reg_mod[$type])){

																			if( class_exists($reg_mod[$type]) ){
																				$final_class = $reg_mod[$type];
																				$module_class = new $final_class('load');
																				$module_class->showSavedModule($row_key, $section_key, $col_key, $module_key, $module_value);
																			}//class_exists

																		}//Check if module is registered

																	}
																}
																echo '</div>';
															echo '<div class="pb_module_add_new" data-row-key="'. $row_key .'" data-section-key="'. $section_key .'" data-col-key="'. $col_key .'" data-modal="module_modal" title="'. __('Add new module', 'smk_toolkit') .'"></div>';
														echo '</div>';//tk_col
													echo '</div>';//tk_grid_?

												}
											}
										echo '<div class="clear"></div>';
										echo '</div>';//content
									echo '<div class="clear"></div>';
									echo '</div>';//smk_pb_section
								}
							}
						echo '<div class="clear"></div>';
						echo '</div>';//tk_container_12
					}
				}
			echo '</div>';//smk_pbuilder_admin_grid

			//$this->debug();

		echo '</div>';//smk_page_builder_container
	}
	
	################################################################################
	
	/**
	 * Before post save
	 *
	 * Apply a filter before the post is saved.
	 * This bug is specific after the theme switch, if previous theme has set a page template, but current theme
	 * does not use the page templates at all. So in order to allow metabox save, the page template should be removed,
	 * before save. 
	 *
	 */
	function before_save_box( $post_id ) {

		if ( ! isset( $_POST['_wp_page_template'] ) ){
			update_post_meta( $post_id, '_wp_page_template', '' );
		}
		
	}

	################################################################################
	
	/**
	 * Saves the captured data
	 */
	function save_box( $post_id ) {
		$post_type = get_post_type();
		
		// verify nonce
		if ( ! isset( $_POST['smk_toolkit_pbuilder_nonce_field'] ) )
			return $post_id;
		if ( ! ( in_array( $post_type, $this->page ) || wp_verify_nonce( $_POST['smk_toolkit_pbuilder_nonce_field'],  'smk_toolkit_pbuilder_nonce_action' ) ) ) 
			return $post_id;

		// check autosave
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;

		// check permissions
		if ( ! current_user_can( 'edit_page', $post_id ) )
			return $post_id;
		
		// save the data
		$new = false;
		$old = get_post_meta( $post_id, 'smk_page_builder_data', true );

		if ( isset( $_POST['smk_page_builder_data'] ) )
			$new = $_POST['smk_page_builder_data'];

		if ( isset( $new ) && '' == $new && $old ) 
		{
			delete_post_meta( $post_id, 'smk_page_builder_data', $old );
		}
		elseif ( ! $new || !isset( $new ) ) 
		{
			delete_post_meta( $post_id, 'smk_page_builder_data' );
		}
		elseif ( isset( $new ) ) 
		{
			update_post_meta( $post_id, 'smk_page_builder_data', $new );
		}

	}//End function save_box()

	################################################################################
	
	/**
	 * Static function to render a text input
	 */
	public static function input($id, $name, $value, $itype='text', $class = '') {
		$the_id = '';
		if(isset($id) && $id != ''){
			$the_id = 'id="'.esc_attr($id).'"';
		}

		$output = '<input type="'. $itype .'" '. $the_id .' class="'.esc_attr($class).'" value="'.esc_attr($value).'" name="'.esc_attr($name).'" />';
		return $output;

	}

	################################################################################
	
	/**
	 * Debug page builder array
	 */
	public function debug() {
		$all_meta = get_post_meta( get_the_ID() );
		$page_builder_dump = Smk_Get::value($all_meta, 'smk_page_builder_data', '');
		$page_builder_dump = Smk_Get::value($page_builder_dump, 0, '');
		if( !empty($page_builder_dump) ){
			smk_ppprint( unserialize($page_builder_dump) );
		}
		// smk_ppprint( $all_meta );
	}

	
}//End class Smk_PageBuilder_Base()
}//End "class_exists" check

new Smk_PageBuilder_Base( 'smk_page_builder', 'Page Builder', array('page'));