<?php
/* 
 * Page Builder Front-end Output 
 *
 * Page Builder front-end content output. This file contains the necesary
 * functions to get and render the page builder data on site for the end-user.
 *
 * -------------------------------------------------------------------------------------
 * @Author: Smartik
 * @Author URI: http://smartik.ws/
 * @Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 * @Date:   2014-04-24 19:04:02
 * @Last Modified by:   Smartik
 * @Last Modified time: 2014-05-21 14:07:17
 *
 */
################################################################################

/**
 * Convert page builder array to HTML.
 *
 * Display the HTML from multidimensional array $data.
 *
 * @param $data array Saved data 
 * @return string The HTML.
 */
if( ! function_exists('smk_pb_output') ) {
	function smk_pb_output($data = '') {
		echo '<div class="smk_page_builder smk_clearfix">' . SMK_EOL;
		
		//Rows
		if( isset($data['rows']) && is_array($data['rows']) ){
			foreach ($data['rows'] as $row_key => $row) {
				$row_disabled = Smk_Get::value( $row, 'row_disabled', 'n');
				$row_settings = Smk_Get::value( $row, 'row_settings', '');
				$row_settings = ( !empty($row_settings) ) ? Smk_Data::decodeJsonE($row_settings) : '';

				//Style
				$custom_row_styles = absint( Smk_Get::value( $row_settings, 'custom_row_styles', 0) );
				$row_style = Smk_Get::value( $row_settings, 'row_style', '');
				$row_style = ( !empty( $row_style ) && 'default' != $row_style && $custom_row_styles != 0 ) ? ' '. sanitize_html_class($row_style) : '';

				//Spacing
				$custom_row_spacing = absint( Smk_Get::value( $row_settings, 'custom_row_spacing', 0) );
				$row_spacing = Smk_Get::value( $row_settings, 'row_spacing', '');
				$row_spacing = ( !empty( $row_spacing ) && 'default' != $row_spacing && 'custom' != $row_spacing && $custom_row_spacing != 0 ) ? ' '. sanitize_html_class($row_spacing) : '';
				
				$force_fullwidth = absint( Smk_Get::value( $row_settings, 'force_fullwidth', 0) );
				$force_fullwidth = ( $force_fullwidth == 1 ) ? ' force_fullwidth' : '';
				$remove_grid_margins = absint( Smk_Get::value( $row_settings, 'remove_grid_margins', 0) );

				if( $row_disabled != 'y' ) :
					//A row
					echo '<!-- Row #'. $row_key .' start -->' . SMK_EOL;
					echo '<div id="'. $row_key .'" class="spb_row smk_clearfix'. $row_style . $row_spacing .'">' . SMK_EOL;
						echo '<div class="smk_toolkit_grid_container'. $force_fullwidth .' smk_clearfix">' . SMK_EOL;

						//Section
						if( $row_sections = Smk_Get::value($row, 'row_sections', false) ){
							$columns_count = 1;//set to 1. used to reset columns nr.
							foreach ($row_sections as $row_section_key => $row_section_value) {
								echo '<div class="spb_section smk_clearfix">' . SMK_EOL;
								//Columns
								if(isset($row_section_value['column']) && is_array($row_section_value['column'])){
									$columns_count = count($row_section_value['column']);//nr of columns in this section
									$columns_index = 1;
									foreach ($row_section_value['column'] as $col_key => $column) {

										//A column
										if(isset($column['grid']) && !empty($column['grid'])){
											if( $columns_count > 1 ){
												if(1 == $columns_index){
													$col_class = ($remove_grid_margins == 1) ? ' grid_first' : '';
												}
												elseif($columns_count == $columns_index){
													$col_class = ($remove_grid_margins == 1) ? ' grid_last' : '';
												}
												else{
													$col_class = '';
												}
											}
											else{
												$col_class = ($remove_grid_margins == 1) ? ' grid_both' : '';
											}
											
											echo '<div class="smk_tk_grid desk_'. absint($column['grid']) .' spb_column'. $col_class .' smk_clearfix">' . SMK_EOL;
												// echo 'col-' . $column['grid'];

												//Modules
												if(isset($column['column_modules']) && is_array($column['column_modules'])){

													foreach ($column['column_modules'] as $module_key => $module) {
														
														//A module
														if( isset($module['class']) ){
															
															$mod_class = $module['class'];
															$reg_mod   = get_option('smk_page_builder_modules');
															
															if(isset($reg_mod[$mod_class])){
																$final_class = $reg_mod[$mod_class];
																if(class_exists($final_class)){
																	if(isset($module['val']) && !empty($module['val']) ){
																		if( method_exists($final_class, 'render') ){
																			$mod_val = Smk_Data::decodeJsonE( $module['val'] );
																			//Final module output
																			echo '<div class="spb_module">' . SMK_EOL;
																				do_action('smk_pb_module_before');
																				$final_class = new $final_class('load');
																				$final_class->render($mod_val);
																				do_action('smk_pb_module_after');
																			echo '</div><!-- /.spb_module -->' . SMK_EOL;
																			// smk_ppprint($mod_val);
																		}
																	}
																}//class_exists
															}//check if mod is set in options.php

														}//if is set module class

													}//foreach modules
												}//if modules are set

											echo '</div><!-- /.spb_column -->' . SMK_EOL;
										}//grid

										$columns_index++;
									}//foreach columns
								}//columns

								echo '</div>';
							}//foreach $row_sections
						}//if $row_sections

						echo '</div>' . SMK_EOL;//container_12
					echo '</div>' . SMK_EOL;//row
					echo '<!-- Row #'. $row_key .' end -->' . SMK_EOL;
				endif;//$row_disabled

			}
		}
		echo '</div>';
	}
}