<?php
/**
 * Inject page builder styles in wp head
 *
 * Inject page builder styles in wp head of the current page. It will be rendered in
 * wp_head() only if the current instance is single(page.php, single.php, single-cpt.php, etc.)
 *
 * @param $content string Not required because it is passed through a filter(`the_content`) 
 * @return string Final content
 *
 * -------------------------------------------------------------------------------------
 * Author: Smartik
 * Author URI: http://smartik.ws/
 * Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 */
if( ! function_exists('smk_add_pb_styles_to_wp_head') ) {
	function smk_add_pb_styles_to_wp_head() {
		//Check if ID exists and is post. Without this on 404 will return a notice.
		if ( ! get_post() ){
			return false;
		}
		else{
			$all_meta = get_post_meta( get_the_ID() );
			
			if(isset( $all_meta['smk_page_builder_data'] )){
				$data = unserialize($all_meta['smk_page_builder_data'][0]);
				if( is_singular() && is_main_query() ) {
					
					$output = '<style id="smk_page_builder_custom_css">' . SMK_EOL;
					if(isset($data['rows']) && is_array($data['rows'])){
						foreach ($data['rows'] as $row_key => $row) {

							$row_settings = Smk_Get::value( $row, 'row_settings', '');
							if( !empty($row_settings) ){
								$row_settings = Smk_Data::decodeJsonE($row_settings);

								//Row spacing
								$custom_row_spacing = absint( Smk_Get::value( $row_settings, 'custom_row_spacing', 0) );
								$row_spacing = Smk_Get::value( $row_settings, 'row_spacing', '');
								$padding_top = Smk_Get::value( $row_settings, 'padding_top', '');
								$padding_bottom = Smk_Get::value( $row_settings, 'padding_bottom', '');

								// Row style
								$custom_row_styles = absint( Smk_Get::value( $row_settings, 'custom_row_styles', 0) );
								$row_background = Smk_Get::value( $row_settings, 'background', '');

								// Row border
								$custom_row_border = absint( Smk_Get::value( $row_settings, 'custom_row_border', 0) );
								$border = Smk_Get::value( $row_settings, 'border', 'none');
								$border_color = Smk_Get::value( $row_settings, 'border_color', '#ccc');
								$border_width = Smk_Get::value( $row_settings, 'border_width', '1');
								$border_style = Smk_Get::value( $row_settings, 'border_style', 'solid');

								if( 
									($custom_row_spacing != 0) ||
									($custom_row_styles != 0) || 
									($custom_row_border != 0) 
								) :
									$output .= '#' . $row_key . '{' . SMK_EOL;
										if( 'custom' == $row_spacing && $custom_row_spacing != 0 ){
											$output .= ( !empty( $padding_top ) ) ? ' padding-top: '. trim($padding_top) .'px;' : '';
											$output .= ( !empty( $padding_bottom ) ) ? ' padding-bottom: '. trim($padding_bottom) .'px;' : '';
										}
										if( $custom_row_border != 0 ){
											switch ($border) {
												case 'top':
													$output .= ( isset( $border_color ) && Smk_Check::is_hex_color($border_color) ) ? 'border-top: '. $border_width .'px '. $border_style .' '. $border_color .';' : '';
													break;
												case 'bottom':
													$output .= ( isset( $border_color ) && Smk_Check::is_hex_color($border_color) ) ? 'border-bottom: '. $border_width .'px '. $border_style .' '. $border_color .';' : '';
													break;
												case 'both':
													$output .= ( isset( $border_color ) && Smk_Check::is_hex_color($border_color) ) ? 'border-top: '. $border_width .'px '. $border_style .' '. $border_color .';' : '';
													$output .= ( isset( $border_color ) && Smk_Check::is_hex_color($border_color) ) ? 'border-bottom: '. $border_width .'px '. $border_style .' '. $border_color .';' : '';
													break;
											}
										}
										if( !empty( $row_background ) && $custom_row_styles != 0 ){
											$row_b_image = Smk_Get::value( $row_background, 'image', '');
											$row_b_color = Smk_Get::value( $row_background, 'background-color', '');
											$row_b_position = Smk_Get::value( $row_background, 'background-position', '');
											$row_b_repeat = Smk_Get::value( $row_background, 'background-repeat', '');
											$row_b_attachment = Smk_Get::value( $row_background, 'background-attachment', '');
											$row_b_size = Smk_Get::value( $row_background, 'background-size', '');

											if( !empty($row_b_color) ) $output .= 'background-color: '. $row_b_color .';';
											if( !empty($row_b_image) ) {
												$output .= 'background-image: url('. $row_b_image .');';
												if( !empty($row_b_position) ) $output .= 'background-position: '. $row_b_position .';';
												if( !empty($row_b_repeat) ) $output .= 'background-repeat: '. $row_b_repeat .';';
												if( !empty($row_b_attachment) ) $output .= 'background-attachment: '. $row_b_attachment .';';
												if( !empty($row_b_size) ) $output .= 'background-size: '. $row_b_size .';';
											}
										}
									$output .= '}' . SMK_EOL;
								endif;

							}

						}
					}
					$output .= '</style>' . SMK_EOL;

					echo $output;

				}
			}
		}
		
	}
add_action( 'wp_head', 'smk_add_pb_styles_to_wp_head', 11);
}