<?php
/**
 * Module initialization
 *
 * Initialize page builder modules, register, load data, etc.
 *
 * -------------------------------------------------------------------------------------
 * Author: Smartik
 * Author URI: http://smartik.ws/
 * Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 */
if( ! class_exists('Smk_PageBuilder_ModuleInit') ){
	class Smk_PageBuilder_ModuleInit{

		public function __construct(){

			// add_action( 'smk_register', array(&$this, 'register') );

		}
		
		################################################################################
		
		/**
		 * Register page builder modules
		 *
		 * Add modules to database 
		 *
		 * @param array Modules list key_id => class_name
		 * @return void
		 */
		
		public function register($modules = false){
			if( is_array($modules) && count($modules) > 0 ){
				$old = get_option('smk_page_builder_modules');
				$new = false;

				foreach( $modules as $mid => $mclass ){
					if( class_exists($mclass) && !is_numeric($mid) ){
						if( !in_array($mclass, (array) $old) ){
							$new[$mid] = $mclass;
						}
						
					}
				}

				if(isset($old) && is_array($old) && !empty($old)){
					$final = wp_parse_args( $new, $old );
				}
				else{
					$final = $new;
				}
				if($final){
					update_option('smk_page_builder_modules', $final);
				}

			}
		}//register

		################################################################################

		/**
		 * De-register page builder module
		 *
		 * Remove modules from database 
		 *
		 * @param  array $key_id Modules list key_id
		 * @return void
		 */
		public function deregister($key_id = false){
			$old = get_option('smk_page_builder_modules');
			
			if(isset($old) && is_array($old) && count($old) > 0){
				if( is_array($key_id) ){
					foreach ($key_id as $id) {
						unset($old[$id]);
					}
				}
				elseif( is_string($key_id) ){
					unset($old[$key_id]);
				}
			}
			
			$final = ( isset($old) ) ? $old : array();
			update_option('smk_page_builder_modules', $final);
		}


	}//Smk_PageBuilder_ModuleInit class
}//class_exists 'Smk_PageBuilder_ModuleInit'

################################################################################

/**
 * Init all page builder modules
 * - call all registered modules, it checks if the class exists and
 *   if it does, call it.
 * 
 * @todo Include it in `Smk_PageBuilder_ModuleInit` class
 * @return void
 */
function smk_init_all_pb_modules(){
	$reg_modules = get_option('smk_page_builder_modules');
	if(isset($reg_modules) && is_array($reg_modules) && !empty($reg_modules)){
		foreach ($reg_modules as $key => $value) {
			if(class_exists($value)){
				new $value('create');//If the class exists, call it.
			}
			else{
				$this_module = new Smk_PageBuilder_ModuleInit();
				$this_module->deregister($key);//If the class dos not exist anymore, remove it from DB.
			}
		}
	}
}
add_action('smk_display', 'smk_init_all_pb_modules');