<?php
/**
 * Row Form Fields
 *
 * The fields array that create the row settings form for Page Builder 
 *
 * -------------------------------------------------------------------------------------
 * Author: Smartik
 * Author URI: http://smartik.ws/
 * Copyright: (c) 2014 Smartik. All rights reserved
 * -------------------------------------------------------------------------------------
 *
 */
function smk_page_builder_row_settings_fields(){
	return array(
		/*
		--------------------------------------------------------------------------------
		Row spacing
		--------------------------------------------------------------------------------
		*/
		array(
			'id' 	=> 'force_fullwidth',
			'type' 	=> 'switch',
			'std' 	=> 0,
			'label' => __('Force full width', 'smk_toolkit'),
			'desc' 	=> __('Force full width if posible. It will ignore the grid width if the theme allows it.', 'smk_toolkit'),
			'set'   => array(
				'grid' => 4,
				'grid_pos' => 'first',
			),
		),
		array(
			'id' 	=> 'remove_grid_margins',
			'type' 	=> 'switch',
			'std' 	=> 0,
			'label' => __('Force grid margins remove', 'smk_toolkit'),
			'desc' 	=> __('Force to remove the grid margins for first and last column.', 'smk_toolkit'),
			'set'   => array(
				'grid' => 4,
				'grid_pos' => 'last',
			),
		),
		array(
			'id' 	=> 'custom_row_spacing',
			'type' 	=> 'switch',
			'std' 	=> 0,
			'label' => __('Custom row spacing:', 'smk_toolkit'),
			'desc' 	=> __('Optionaly adjust current row spacing(padding top/bottom).', 'smk_toolkit'),
		),
		array(
			'id' 	=> 'row_spacing',
			'type' 	=> 'select',
			'label' => __('Row Spacing', 'smk_toolkit'),
			'options' => apply_filters('smk_page_builder_row_settings_spacing', array(
				'default' => __('Default', 'smk_toolkit'),
				'custom' => __('Custom - Adjust the following slider values', 'smk_toolkit'),
			)),
			'std' 	=> 'default',
			'set'   => array(
				'grid' => 4,
				'grid_pos' => 'first',
			),
			'fold'  => 'custom_row_spacing',
			'desc' 	=> __('Select `Default` to not apply anything to this row and use the default defined by this theme.
							If you select `Custom`, then you can adjust the values in the next two sliders.', 'smk_toolkit'),
		),
		array(
			'id' 	=> 'padding_top',
			'type' 	=> 'sliderui',
			'label' => __('Padding Top', 'smk_toolkit'),
			'min' 	=> '0',
			'max' 	=> '200',
			'std' 	=> '15',
			'set'   => array(
				'grid' => 4,
			),
			'fold'  => 'custom_row_spacing',
			'step' 	=> '5',
		),
		array(
			'id' 	=> 'padding_bottom',
			'type' 	=> 'sliderui',
			'label' => __('Padding Bottom', 'smk_toolkit'),
			'min' 	=> '0',
			'max' 	=> '200',
			'std' 	=> '15',
			'set'   => array(
				'grid' => 4,
				'grid_pos' => 'last',
			),
			'fold'  => 'custom_row_spacing',
			'step' 	=> '5',
		),

		/*
		--------------------------------------------------------------------------------
		Row border
		--------------------------------------------------------------------------------
		*/
		array(
			'id' 	=> 'custom_row_border',
			'type' 	=> 'switch',
			'std' 	=> 0,
			'label' => __('Custom row border:', 'smk_toolkit'),
			'desc' 	=> __('Optionaly adjust current row styles.', 'smk_toolkit'),
			'set'   => array(
				'grid' => 4,
				'grid_pos' => 'first',
			),
		),
		array(
			'id' 	=> 'border',
			'type' 	=> 'visual_select',
			'label' => __('Row border position:', 'smk_toolkit'),
			'desc' 	=> __('Add borders to this row.', 'smk_toolkit'),
			'std'   => 'noborder',
			// 'mode' => 'image',
			'options' => array(
				array(
					'val'   => 'noborder',
					'label' => 'None',
				),
				array(
					'val'   => 'top',
					'label' => 'Top',
				),
				array(
					'val'   => 'bottom',
					'label' => 'Bottom',
				),
				array(
					'val'   => 'both',
					'label' => 'Top and bottom',
				),
			),
			'set'   => array(
				'grid' => 6,
				'grid_pos' => 'last',
			),
			'fold'  => 'custom_row_border',
		),
		array(
			'id' 	=> 'border_color',
			'type' 	=> 'color',
			'label' => __('Border color', 'smk_toolkit'),
			'std' 	=> '',
			'set'   => array(
				'grid' => 4,
				'grid_pos' => 'first',
			),
			'fold'  => 'custom_row_border',
			'desc' 	=> __('If you selected to use borders for this row, you can optionaly set a color. If you leave it empty, default will be used.', 'smk_toolkit'),
		),
		array(
			'id' 	=> 'border_width',
			'type' 	=> 'sliderui',
			'label' => __('Border width:', 'smk_toolkit'),
			// 'desc' 	=> __('', 'smk_toolkit'),
			'std'   => 1,
			'min'   => 1,
			'max'   => 15,
			'step'  => 1,
			'set'   => array(
				'grid' => 4,
			),
			'fold'  => 'custom_row_border',
		),
		array(
			'id' 	=> 'border_style',
			'type' 	=> 'select',
			'label' => __('Border style:', 'smk_toolkit'),
			// 'desc' 	=> __('', 'smk_toolkit'),
			'options'   => array(
				'dotted' => 'dotted',
				'dashed' => 'dashed',
				'solid'  => 'solid',
				'double' => 'double',
				'groove' => 'groove',
				'ridge'  => 'ridge',
				'inset'  => 'inset',
				'outset' => 'outset',
			),
			'set'   => array(
				'grid' => 4,
				'grid_pos' => 'last',
			),
			'fold'  => 'custom_row_border',
		),

		/*
		--------------------------------------------------------------------------------
		Row styles
		--------------------------------------------------------------------------------
		*/
		array(
			'id' 	=> 'custom_row_styles',
			'type' 	=> 'switch',
			'std' 	=> 0,
			'label' => __('Custom row styles:', 'smk_toolkit'),
			'desc' 	=> __('Optionaly adjust current row styles.', 'smk_toolkit'),
		),
		// array(
		// 	'id' 	=> 'row_style',
		// 	'type' 	=> 'select',
		// 	'label' => __('Row Style', 'smk_toolkit'),
		// 	'options' => apply_filters('smk_page_builder_row_settings_style', array(
		// 		'default' => __('Default', 'smk_toolkit'),
		// 	)),
		// 	'std' 	=> 'default',
		// 	'set'   => array(
		// 		'grid' => 4,
		// 		'grid_pos' => 'first',
		// 	),
		// 	'fold'  => 'custom_row_styles',
		// 	'desc' 	=> __('Please select the base style and just after this you can adjust the background in the next field, which is optional by the way.', 'smk_toolkit'),
		// ),
		array(
			'id' 	=> 'row_style',
			'type' 	=> 'visual_select',
			'label' => __('Row Style', 'smk_toolkit'),
			'std'   => 'default',
			'options' => apply_filters('smk_page_builder_row_settings_style', array(
				array(
					'val'   => 'default',
					'color' => '#eee',
					'label' => __('Default Light', 'smk_toolkit'),
				),
			)),
			'set'   => array(
				'grid' => 4,
				'grid_pos' => 'first',
			),
			'fold'  => 'custom_row_styles',
			'mode' => 'color',
			'desc' 	=> __('Please select the base style and just after this you can adjust 
							the background in the next field, which is optional by the way.', 'smk_toolkit'),
		),
		array(
			'id' 	=> 'background',
			'type'  => 'image_select',
			'label' => __('Background', 'smk_toolkit'),
			'images'=> array(),
			'options' => array(
				'show_preview'          => true,
				'allow_upload'          => true,
				'allow_deselect'        => true,
				'background-color'      => true,
				'background-position'   => true,
				'background-repeat'     => true,
				'background-attachment' => true,
				'background-size'       => true,
			),
			'set'   => array(
				'grid' => 8,
				'grid_pos' => 'last',
			),
			'fold'  => 'custom_row_styles',
			'desc' 	=> __('Based on previous field, adjust the background. Leave empty to use default. Note: Sometimes you can have an unexpected result. For example a dark background and dark color. Just make sure to set the right value.', 'smk_toolkit'),
		),
	);
}

//Add default page builder row style
// function smk_page_builder_default_row_settings_styles($styles){
// 	$styles['default'] = __('Default', 'smk_toolkit');
// 	return $styles;
// }
// add_filter('smk_page_builder_row_settings_style', 'smk_page_builder_default_row_settings_styles');

//Add default page builder row spacing
// function smk_page_builder_default_row_settings_spacing($spacing){
// 	$spacing['default'] = __('Default', 'smk_toolkit');
// 	return $spacing;
// }
// add_filter('smk_page_builder_row_settings_spacing', 'smk_page_builder_default_row_settings_spacing');

//Add default page builder row spacing custom
// function smk_page_builder_default_row_settings_spacing_custom($spacing){
// 	$spacing['custom'] = __('Custom - Adjust the following slider values', 'smk_toolkit');
// 	return $spacing;
// }
// add_filter('smk_page_builder_row_settings_spacing', 'smk_page_builder_default_row_settings_spacing_custom', 20);
