<?php
if( ! class_exists('Smk_Sanitize') ){
	class Smk_Sanitize{

		/**
		 * Text. This allow any type of string. HTML is not allowed and will be removed
		 * @option input
		 *
		 * @param string $input The user input to be sanitized
		 * @return string
		 */
		public static function text_field($input){
			return sanitize_text_field( $input );
		}

		################################################################################

		/**
		 * Textarea. HTML is allowed based on $filter value
		 * @option textarea
		 *
		 * @param string $input The user input to be sanitized
		 * @param string $filter How to filter the content. 
		 *               `unfiltered` - do no filtere, not recomended, 
		 *               `post` - act as posts,
		 *               `comment` - act as comments,
		 *               `moderate` - only safe HTML tags are allowed
		 *               `strict` - Only a few inline HTML tags are allowed
		 *               `nohtml` - No HTML allowed at all, all HTML tags will be removed
		 *               `encode` - Encode all special characters(usefull for code display in <pre> ;) )
		 * 
		 * @todo switch $filter to validate on different cases. Right now it use only `post`
		 *
		 * @return string
		 */
		public static function textarea($input, $filter = 'post'){
			global $allowedposttags;
			$output = wp_kses( $input, $allowedposttags);
			return $output;
		}

		################################################################################

		/**
		 * Checkbox. The value should be 1 or 0, reject everything else
		 * @option checkbox
		 *
		 * @param string $input The user input to be sanitized
		 *
		 * @return string
		 */
		public static function checkbox($input){
			$input = absint($input);
			return ( $input && is_numeric($input) ) ? $input : 0;
		}

		################################################################################

		/**
		 * Select. The value should be from $possible_val, else reject it and use the 
		 * first key from $possible_val
		 *
		 * @param string $input The user input to be sanitized
		 * @param array $possible_val Possible values
		 *
		 * @return string
		 */
		public static function select($input, $possible_val = array() ){
			if( in_array($input, $possible_val) ){
				return $input; //this value is valid
			}
			else{
				return ( isset( $possible_val[0] ) ) ? $possible_val[0] : '';//first possible array key
			}
		}

		################################################################################

		/**
		 * Sanitize complete options array
		 *
		 * @param array $input The user input to be sanitized, expects a 
		 * muldimensional array with all value to be sanitized
		 *
		 * @return array
		 */
		public static function options_array($input, $fields_type){
			foreach ($fields_type as $f_id => $f_type) {

				switch ($f_type['type']) {
					case 'input':
							$input[$f_id] = Smk_Sanitize::text_field( $input[$f_id] );
						break;
					
					case 'textarea':
							$input[$f_id] = Smk_Sanitize::textarea( $input[$f_id] );
						break;
						
					case 'checkbox':
							$input[$f_id] = Smk_Sanitize::checkbox( $input[$f_id] );
						break;

					case 'select':
							$input[$f_id] = Smk_Sanitize::select( $input[$f_id], $f_type['possible_val'] );
						break;
					
					// default:
					// 	$input[$f_id] = $input[$f_id];
					// 	break;
				}

			}

			return $input;
		}

	}//class
}//class_exists